<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Unique span numbers -->
    <xsl:variable name="uniqueSpanNumber" select="//Girders/Girder[not (@startSpan = preceding-sibling::Girder/@startSpan)]/@startSpan"/>
    <!-- As-Built Elevations Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">As-Built Elevations Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">As-Built Elevations Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="BridgeProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- As Built Elevation Data -->
                                <table cellspacing="0" style="border-style:solid; border-width:1px; font-size:80%" width="100%">
                                    <xsl:for-each select="BridgeCenterLine">
                                        <br/>
                                        <xsl:for-each select="$uniqueSpanNumber">
                                            <xsl:for-each select="//Girder[@startSpan = current()]">
                                                <tbody>
                                                    <tr>
                                                        <th class="underline" rowspan="3" style="border-right-width:1px" valign="bottom">
                                                            Span<br/><xsl:value-of select="@startSpan"/><br/>
                                                            Beam<br/><xsl:value-of select="@name"/>
                                                        </th>
                                                        <th colspan="10" style="border-style:solid;border-left-width:0px;border-bottom-width:1px;border-right-width:1px;border-top-width:0px" valign="bottom">&#xa0;</th>
                                                        <th class="underline" colspan="2" rowspan="2" style="border-right-width:1px" valign="bottom">
                                                            Bottom Deck Elev
                                                        </th>
                                                        <th class="underline" colspan="2" rowspan="2" style="border-right-width:1px" valign="bottom">
                                                            Haunch
                                                        </th>
                                                        <th class="underline" rowspan="3" style="border-right-width: 1px" valign="bottom">Beam<br/>Defl</th>
                                                        <th class="underline" colspan="3" rowspan="2" style="border-right-width:1px" valign="bottom">
                                                            Left Edge of Beam
                                                        </th>
                                                        <th class="underline" colspan="3" rowspan="2" style="border-right-width:1px" valign="bottom">
                                                            Right Edge of Beam
                                                        </th>
                                                        <th class="underline" rowspan="2" valign="bottom">Girder<br/>Points</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" colspan="5" style="border-right-width:1px" valign="bottom">
                                                            Left Edge of Beam
                                                        </th>
                                                        <th class="underline" colspan="5" style="border-right-width:1px" valign="bottom">
                                                            Right Edge of Beam
                                                        </th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" valign="bottom">Sta</th>
                                                        <th class="underline" valign="bottom">O/S</th>
                                                        <th class="underline" valign="bottom">Profile<br/>Elev</th>
                                                        <th class="underline" valign="bottom">Cross<br/>Slope</th>
                                                        <th class="underline" style="border-right-width:1px" valign="bottom">Deck Elev<br/>Left</th>
                                                        <th class="underline" valign="bottom">Sta</th>
                                                        <th class="underline" valign="bottom">O/S</th>
                                                        <th class="underline" valign="bottom">Profile<br/>Elev</th>
                                                        <th class="underline" valign="bottom">Cross<br/>Slope</th>
                                                        <th class="underline" style="border-right-width:1px" valign="bottom">Deck Elev<br/>Right</th>
                                                        <th class="underline" valign="bottom">Left</th>
                                                        <th class="underline" style="border-right-width:1px" valign="bottom">Right</th>
                                                        <th class="underline" valign="bottom">Left</th>
                                                        <th class="underline" style="border-right-width:1px" valign="bottom">Right</th>
                                                        <th class="underline" valign="bottom">Btm Deck<br/>w/Defl</th>
                                                        <th class="underline" valign="bottom">Beam<br/>Shot</th>
                                                        <th class="underline" style="border-right-width:1px" valign="bottom">Mark<br/>Up</th>
                                                        <th class="underline" valign="bottom">Btm Deck<br/>w/Defl</th>
                                                        <th class="underline" valign="bottom">Beam<br/>Shot</th>
                                                        <th class="underline" style="border-right-width:1px" valign="bottom">Mark<br/>Up</th>
                                                        <th class="underline" valign="bottom">Up Sta</th>
                                                    </tr>
                                                    <xsl:for-each select="*/AsBuiltElevations/AsBuiltElevation">
                                                        <tr>
                                                            <td align="right" style="border-style:solid;border-left-width:0px;border-bottom-width:0px;border-right-width:1px;border-top-width:0px">
                                                                <xsl:value-of select="inr:distanceFormat(number(@distanceAlong), $xslDistancePrecision)"/>
                                                            </td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:stationFormat(number(leftStation/@externalStation), $xslStationFormat, $xslStationPrecision, string(leftStation/@externalStationName))"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:distanceFormat(number(@leftEdgeOffset), $xslDistancePrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@leftEdgeBottomOfGirderElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:gradeFormat(number(@crossSlope), $xslGradeFormat, $xslGradePrecision)"/>
                                                            </td>
                                                            <td align="right" style="border-style:solid;border-left-width:0px;border-bottom-width:0px;border-right-width:1px;border-top-width:0px">
                                                                <xsl:value-of select="inr:elevationFormat(number(@leftEdgeTopOfSlabElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:stationFormat(number(rightStation/@externalStation), $xslStationFormat, $xslStationPrecision, string(rightStation/@externalStationName))"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:distanceFormat(number(@rightEdgeOffset), $xslDistancePrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@rightEdgeBottomOfGirderElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:gradeFormat(number(@crossSlope), $xslGradeFormat, $xslGradePrecision)"/>
                                                            </td>
                                                            <td align="right" style="border-style:solid;border-left-width:0px;border-bottom-width:0px;border-right-width:1px;border-top-width:0px">
                                                                <xsl:value-of select="inr:elevationFormat(number(@rightEdgeTopOfSlabElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@leftEdgeBottomOfSlabElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right" style="border-style:solid;border-left-width:0px;border-bottom-width:0px;border-right-width:1px;border-top-width:0px">
                                                                <xsl:value-of select="inr:elevationFormat(number(@rightEdgeBottomOfSlabElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@leftEdgeHaunchDepth), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right" style="border-style:solid;border-left-width:0px;border-bottom-width:0px;border-right-width:1px;border-top-width:0px">
                                                                <xsl:value-of select="inr:elevationFormat(number(@rightEdgeHaunchDepth), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right" style="border-style:solid;border-left-width:0px;border-bottom-width:0px;border-right-width:1px;border-top-width:0px">
                                                                <xsl:value-of select="inr:elevationFormat(number(@leftEdgeDeflection), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@leftEdgeBottomOfSlabWDeflectionElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@leftEdgeAsBuiltTopOfGirderElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right" style="border-style:solid;border-left-width:0px;border-bottom-width:0px;border-right-width:1px;border-top-width:0px">
                                                                <xsl:value-of select="inr:elevationFormat(number(@leftEdgeMarkUp), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@rightEdgeBottomOfSlabWDeflectionElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@rightEdgeAsBuiltTopOfGirderElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right" style="border-style:solid;border-left-width:0px;border-bottom-width:0px;border-right-width:1px;border-top-width:0px">
                                                                <xsl:value-of select="inr:elevationFormat(number(@rightEdgeMarkUp), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:distanceFormat(number(@distanceAlong), $xslDistancePrecision)"/>
                                                            </td>
                                                        </tr>
                                                    </xsl:for-each>
                                                    <tr><td colspan="23" style="border-style:solid;border-left-width:0px;border-bottom-width:1px;border-right-width:0px;border-top-width:1px">&#xa0;</td></tr>
                                                </tbody>
                                            </xsl:for-each>
                                        </xsl:for-each>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                Please contact Bentley Civil Engineering Products support or development in Huntsville if 
                you wish to use this style sheet.&#xa0; Please see the <em>Bentley InRoads Group Help &gt; 
                Help &gt; How to Reach Bentley</em> help topic for ways to contact Bentley.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
