﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
  <xsl:include href="../cdotformat.xsl" />
  <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory" />
  <!--Horizontal Alignment Legal Description Report-->
  <xsl:template match="/">
    <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
    <html lang="en">
      <head>
        <link rel="stylesheet" type="text/css" href="../_Themes/engineer/theme.css" />
        <link rel="stylesheet" type="text/css" href="_Themes/engineer/theme.css" />
        <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/CDOT/theme.css" />
        <!--link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme-kaw.css"/-->
        <!-- Title displayed in browser Title Bar -->
        <!--title>Horizontal Alignment Legal Description</title-->
      </head>
      <body>
        <xsl:for-each select="InRoads">
          <p lang="en">
            <!-- Report Title -->
            <!--h2>Horizontal Alignment Legal Description</h2-->
            <xsl:for-each select="GeometryProject">
              <xsl:variable name="ProjNum">
                <xsl:value-of select="@name" />
              </xsl:variable>
              <xsl:variable name="PC">
                <xsl:value-of select="@description" />
              </xsl:variable>
              <xsl:for-each select="HorizontalAlignment">
                <xsl:variable name="Date">
                  <xsl:value-of select="@lastRevisedDate" />
                </xsl:variable>
                <xsl:variable name="ParNum">
                  <xsl:value-of select="@name" />
                </xsl:variable>
                <h3>
                  <center>
                    <b>EXHIBIT "A"</b>
                    <br />
                    <br />
								PROJECT NUMBER: <xsl:value-of select="$ProjNum" /><br />
								AIR RIGHTS EASEMENT NUMBER: <xsl:value-of select="$ParNum" /><br />
								PROJECT CODE: <xsl:value-of select="$PC" /><br />
								<xsl:value-of select="inr:MDY(string($Date))" /><br /><th class="underline" lang="en">DESCRIPTION</th></center>
                </h3>
                <br />
                <left>An Air Rights Easement No.  <xsl:value-of select="$ParNum" /> containing all airspace at and above a horizontal plane existing at an elevation of XXXX feet above sea level of land described as 				<xsl:value-of select="$ParNum" /> of the Department of Transportation, State of Colorado Project No. 
									<xsl:value-of select="$ProjNum" /> containing <xsl:value-of select="inr:acreFormat(number(@area), 0)" /> sq. ft. 
									(<xsl:value-of select="inr:acreFormat(number(@area) div 43560, 3)" /> acres), more or less, in Section XX, Township X X, Range X X, of the 
									X Principal Meridian, in X County, Colorado, Air Rights Easement being more particularly described as follows:
									<br /><br />
									Commencing at a point, whence XXXX, said point also being the POINT OF BEGINNING;<br /><br /><xsl:apply-templates />
									The above described Air Rights Easement contains <xsl:value-of select="inr:acreFormat(number(@area), 0)" /> sq. ft. 
									(<xsl:value-of select="inr:acreFormat(number(@area) div 43560, 3)" /> acres), more or less.  The land surface and airspace below said easement will remain the property of the fee owner(s) and may be used by them, their successors and assigns, for any lawful purpose, provided such use does not have any adverse affect upon the use of the above described Air Rights Easement.<br /><br />
									The purpose of the above-described Air Rights Easement is for the ....<br /><br />
									Basis of Bearings: All bearings are based on a line between .....
								</left>
              </xsl:for-each>
            </xsl:for-each>
          </p>
        </xsl:for-each>
      </body>
    </html>
  </xsl:template>
  <!-- Horizontal Line -->
  <xsl:template match="HorizontalLine">
    <xsl:choose>
      <xsl:when test="position() = 1">
        <blockquote>
          <xsl:number count="HorizontalLine | HorizontalCircle | HorizontalSpiral" />.  Thence 
				<xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)" />, 
				a distance of 
				<xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)" /> 
				feet;
				</blockquote>

      </xsl:when>
      <xsl:when test="position() = last()">
        <blockquote>
          <xsl:number count="HorizontalLine | HorizontalCircle | HorizontalSpiral" />. Thence 
				<xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)" />,
				a distance of 
				<xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)" /> 
				feet, more or less, to the POINT OF BEGINNING.
				</blockquote>

      </xsl:when>
      <xsl:otherwise>
        <blockquote>
          <xsl:number count="HorizontalLine | HorizontalCircle | HorizontalSpiral" />.  Thence 
				<xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)" />,
				a distance of 
				<xsl:value-of select="inr:distanceFormat(number(@length),$xslDistancePrecision)" /> 
				feet;
				</blockquote>

      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!-- Horizontal Circle -->
  <xsl:template match="HorizontalCircle">
    <xsl:choose>
      <xsl:when test="position() = 1">
        <blockquote>
          <xsl:number count="HorizontalLine | HorizontalCircle | HorizontalSpiral" />.  Thence on the arc of a curve to the 
				<xsl:if test="@rotationDirection='ccw'">
                         left, 
                    </xsl:if><xsl:if test="@rotationDirection='cw'">
                         right, 
                </xsl:if>
                a radius of
				<xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)" />
				feet, a central angle of
				<xsl:value-of select="inr:angularFormat(number(@delta),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)" />,
				a distance of
				<xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)" /> 
				feet, (a chord bearing 
				<xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)" />,
				a distance of
				<xsl:value-of select="inr:distanceFormat(number(@chord), $xslDistancePrecision)" />
				feet);
				</blockquote>

      </xsl:when>
      <xsl:when test="position() = last()">
        <blockquote>
          <xsl:number count="HorizontalLine | HorizontalCircle | HorizontalSpiral" />.  Thence on the arc of a curve to the 
				<xsl:if test="@rotationDirection='ccw'">
                         left, 
                    </xsl:if><xsl:if test="@rotationDirection='cw'">
                         right, 
                </xsl:if>
				a radius of
				<xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)" />
				feet, a central angle of
				<xsl:value-of select="inr:angularFormat(number(@delta),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)" />,                
				a distance of 
				<xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)" />
				feet, (a chord bearing
				<xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)" />,
				a distance of
				<xsl:value-of select="inr:distanceFormat(number(@chord), $xslDistancePrecision)" />
				feet), more or less, to the TRUE POINT OF BEGINNING.<br /></blockquote>

      </xsl:when>
      <xsl:otherwise>
        <blockquote>
          <xsl:number count="HorizontalLine | HorizontalCircle | HorizontalSpiral" />.  Thence on the arc of a curve to the 
				<xsl:if test="@rotationDirection='ccw'">
                         left, 
                    </xsl:if><xsl:if test="@rotationDirection='cw'">
                         right, 
                </xsl:if>
				a radius of
				<xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)" />
				feet, a central angle of
				<xsl:value-of select="inr:angularFormat(number(@delta),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)" />,                
				a distance of 
				<xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)" />
				feet, (a chord bearing 
				<xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)" />,
				a distance of
				<xsl:value-of select="inr:distanceFormat(number(@chord), $xslDistancePrecision)" />
				feet);
				</blockquote>
        <br />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!-- Horizontal Spiral -->
  <xsl:template match="HorizontalSpiral">
    <xsl:choose>
      <xsl:when test="position() = 1">
        <blockquote>
          <xsl:number count="HorizontalLine | HorizontalCircle | HorizontalSpiral" />.  Thence on the arc of a  
					<xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)" />
					foot spiral curve to the
					<xsl:if test="@rotationDirection='ccw'">
                         left, 
                    </xsl:if><xsl:if test="@rotationDirection='cw'">
                         right, 
					</xsl:if>
					a beginning radius of 
					<xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)" />
					feet, an ending radius of
					<xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)" />
					feet, a Theta angle of
					<xsl:value-of select="inr:angularFormat(number(@thetaAngle),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)" />,   
					(a chord bearing
					<xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)" />,
					a distance of
					<xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)" />
					feet);<br /><br /></blockquote>
      </xsl:when>
      <xsl:when test="position() = last()">
        <blockquote>
          <xsl:number count="HorizontalLine | HorizontalCircle | HorizontalSpiral" />.  Thence on the arc of a  
					<xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)" />
					foot spiral curve to the
					<xsl:if test="@rotationDirection='ccw'">
                         left, 
                    </xsl:if><xsl:if test="@rotationDirection='cw'">
                         right, 
					</xsl:if>
					a beginning radius of 
					<xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)" />
					feet, an ending radius of
					<xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)" />
					feet, a Theta angle of
					<xsl:value-of select="inr:angularFormat(number(@thetaAngle),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)" />,   
					(a chord bearing
					<xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)" />,
					a distance of
					<xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)" />
					feet), more or less, to the TRUE POINT OF BEGINNING.
				</blockquote>

      </xsl:when>
      <xsl:otherwise>
        <blockquote>
          <xsl:number count="HorizontalLine | HorizontalCircle | HorizontalSpiral" />.  Thence on the arc of a  
					<xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)" />
					foot spiral curve to the
					<xsl:if test="@rotationDirection='ccw'">
						left, 
                    </xsl:if><xsl:if test="@rotationDirection='cw'">
						right, 
					</xsl:if>
					a beginning radius of 
					<xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)" />
					feet, an ending radius of
					<xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)" />
					feet, a Theta angle of
					<xsl:value-of select="inr:angularFormat(number(@thetaAngle),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)" />,   
					(a chord bearing
					<xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)" />,
					a distance of
					<xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)" />
					feet);
				</blockquote>

      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>