<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Variables to hold range point names.  You must change these to match your data. -->
    <!-- Superelevation ASCII Import Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/RoadwayDesignProject/CrossSlopeOptimizationExistingInput">
                    <xsl:text>Existing Ground Data:  Type - </xsl:text>
                    <xsl:value-of select="@type"/>
                    <xsl:text>   Pivot - </xsl:text>
                    <xsl:value-of select="@pivot"/>
                    <xsl:text>   Superelevated - </xsl:text>
                    <xsl:value-of select="@superelevated"/>
                    <xsl:text>&#xd;</xsl:text>
                </xsl:for-each>
                <xsl:for-each select="InRoads/RoadwayDesignProject/CrossSlopeOptimizationDesignInput">
                    <xsl:text>Design Data:   Type - </xsl:text>
                    <xsl:value-of select="@type"/>
                    <xsl:if test="@type = 'Control Line'">
                        <xsl:text>   Control Line - </xsl:text>
                        <xsl:value-of select="@controlLine"/>
                    </xsl:if>
                    <xsl:if test="@type = 'Constant'">
                        <xsl:text>   Design Cross Slope - </xsl:text>
                        <xsl:value-of select="@fixedValue"/>
                    </xsl:if>
                    <xsl:text>&#xd;</xsl:text>
                </xsl:for-each>
                <xsl:for-each select="InRoads/RoadwayDesignProject/CrossSlopeOptimizationParameters">
                    <xsl:text>Optimization Parameters:   Tolerance Type - </xsl:text>
                    <xsl:value-of select="@toleranceType"/>
                    <xsl:if test="@toleranceType = 'Slope'">
                        <xsl:text>   Slope Tolerance - </xsl:text>
                        <xsl:value-of select="@toleranceValue"/>
                     </xsl:if>
                     <xsl:if test="@toleranceType = 'Elevation'">
                         <xsl:text>   Elevation Tolerance - </xsl:text>
                         <xsl:value-of select="@toleranceValue"/>
                      </xsl:if>
                    <xsl:text>&#xd;</xsl:text>
                </xsl:for-each>
                <xsl:for-each select="InRoads/RoadwayDesignProject/CrossSlopeOptimizationStations">
                    <xsl:text/>
                    <xsl:text>Station, Existing Slope, Exisiting Elevation, Design Slope, Design Elevation, Slope Difference, Elevation Difference, Corrected Slope, Corrected Elevation, Delta G&#xd;</xsl:text>
                    <xsl:for-each select="CrossSlopeOptimizationStation">
                            <xsl:value-of select="inr:stationFormat(number(@externalStation), $xslStationFormat, $xslStationPrecision, string(@externalStationName))"/>
                            <xsl:text>, </xsl:text>
                            <xsl:value-of select="@existingGroundSlope"/>
                            <xsl:text>, </xsl:text>
                            <xsl:value-of select="@existingGroundElevationDelta"/>
                            <xsl:text>, </xsl:text>
                            <xsl:value-of select="@designSlope"/>
                            <xsl:text>, </xsl:text>
                            <xsl:value-of select="@designElevationDelta"/>
                            <xsl:text>, </xsl:text>
                            <xsl:value-of select="@slopeDifference"/>
                            <xsl:text>, </xsl:text>
                            <xsl:value-of select="@elevationDifference"/>
                            <xsl:text>, </xsl:text>
                            <xsl:value-of select="@correctedSlope"/>
                            <xsl:text>, </xsl:text>
                            <xsl:value-of select="@correctedElevationDelta"/>
                            <xsl:text>, </xsl:text>
                            <xsl:value-of select="@deltaG"/>
                            <xsl:text>&#xd;</xsl:text>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>   You must have created cross slope optimization results by&#xd;</xsl:text>
        <xsl:text>   selecting the Calculate Correction button from the&#xd;</xsl:text>
        <xsl:text>   Modeler&gt;Roadway Designer&gt;Overlay Tools&gt;&#xd;</xsl:text>
        <xsl:text>   Cross Slope Optimization command.&#xd;</xsl:text>
        <xsl:text>Copyright 2007 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
