<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Trimble Alignment DC Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>00NMSC V10-70       0000</xsl:text>
                    <xsl:value-of select="inr:DCdate()"/><xsl:text> </xsl:text>
                    <xsl:value-of select="inr:DCtime()"/><xsl:text> 1</xsl:text>
                    <xsl:choose>
                        <xsl:when test="//@linearUnits = 'Metric'"><xsl:text>1</xsl:text></xsl:when>
                        <xsl:otherwise><xsl:text>2</xsl:text></xsl:otherwise>
                    </xsl:choose>
                    <xsl:text>3111&#xd;</xsl:text>
                    <xsl:text>10NM</xsl:text>
                    <xsl:choose>
                        <xsl:when test="string-length(@name) &gt; 16">
                            <xsl:value-of select="substring(@name, 1, 16)"/>
                        </xsl:when>
                        <xsl:when test="string-length(@name) &lt; 16">
                            <xsl:value-of select="@name"/>
                            <xsl:value-of select="substring('                ', 1, 16 - string-length(@name))"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="@name"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:text>121111&#xd;</xsl:text>
                    <xsl:text>78KI11&#xd;</xsl:text>
                    <xsl:choose>
                        <xsl:when test="//@linearUnits = 'Metric'"><xsl:text></xsl:text>65KI6378137.00000  </xsl:when>
                        <xsl:otherwise>
                            <xsl:text>65KI20925646.32546  </xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:text>298.257222933&#xd;</xsl:text>
                    <xsl:text>64KI1&#xd;</xsl:text>
                    <xsl:text>49KI1&#xd;</xsl:text>
                    <xsl:text>50KI&#xd;</xsl:text>
                    <xsl:text>81KI1&#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:text>28NM</xsl:text>
                        <xsl:choose>
                            <xsl:when test="string-length(@name) &gt; 16">
                                <xsl:value-of select="substring(@name, 1, 16)"/>
                            </xsl:when>
                            <xsl:when test="string-length(@name) &lt; 16">
                                <xsl:value-of select="@name"/>
                                <xsl:value-of select="substring('                ', 1, 16 - string-length(@name))"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="@name"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:text>1&#xd;</xsl:text>
                        <xsl:for-each select="HorizontalElements">
                            <xsl:apply-templates/>
                        </xsl:for-each>
                        <xsl:for-each select="VerticalAlignment">
                            <xsl:for-each select="VerticalElements">
                                <xsl:apply-templates/>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="HorizontalLine">
        <xsl:if test="position() = 1">
            <xsl:text>84NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(Start/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnFormatLeft(string(inr:directionFormat(number(@direction), 2, 9, 3, 1)), 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(Start/@northing), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(Start/@easting), 5, 16)"/>
            <xsl:text>0.00000&#xd;</xsl:text>
        </xsl:if>
        <xsl:text>31NM</xsl:text>
        <xsl:value-of select="inr:columnFormatLeft(string(inr:directionFormat(number(@direction), 2, 9, 3, 1)), 16)"/>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(@length), 5, 16)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template match="HorizontalCircle">
        <xsl:if test="position() = 1">
            <xsl:text>84NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(Start/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnFormatLeft(string(inr:directionFormat(number(@tangentialDirectionStart), 2, 9, 3, 1)), 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(Start/@northing), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(Start/@easting), 5, 16)"/>
            <xsl:text>0.00000&#xd;</xsl:text>
        </xsl:if>
        <xsl:text>32NM</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(@length), 5, 16)"/>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">
                <xsl:value-of select="inr:columnDoubleFormatLeft(number(-1 * @radius), 5, 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormatLeft(number(@radius), 5, 16)"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template match="HorizontalSpiral">
        <xsl:if test="position() = 1">
            <xsl:text>84NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(Start/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnFormatLeft(string(inr:directionFormat(number(@tangentialDirectionStart), 2, 9, 3, 1)), 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(Start/@northing), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(Start/@easting), 5, 16)"/>
            <xsl:text>0.00000&#xd;</xsl:text>
        </xsl:if>
        <xsl:text>33NM</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(@length), 5, 16)"/>
        <xsl:choose>
            <xsl:when test="@startRadius = 0.0000">
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:value-of select="inr:columnDoubleFormatLeft(number(-1 * @endRadius), 5, 16)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:columnDoubleFormatLeft(number(@endRadius), 5, 16)"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:value-of select="inr:columnDoubleFormatLeft(number(-1 * @startRadius), 5, 16)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:columnDoubleFormatLeft(number(@startRadius), 5, 16)"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template match="VerticalLine">
        <xsl:if test="position() = 1">
            <xsl:text>34NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalStart/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalStart/@elevation), 5, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:if test="position() = last()">
            <xsl:text>37NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalEnd/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalEnd/@elevation), 5, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template match="VerticalSymmetricalParabola">
        <xsl:if test="position() = 1">
            <xsl:text>34NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalStart/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalStart/@elevation), 5, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:text>36NM</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(PVI/station/@internalStation), 5, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(PVI/@elevation), 5, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(@verticalCurveLength), 5, 16)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>37NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalEnd/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalEnd/@elevation), 5, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template match="VerticalUnsymmetricalParabola">
        <xsl:if test="position() = 1">
            <xsl:text>34NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalStart/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalStart/@elevation), 5, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:text>B8NM</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(PVI/station/@internalStation), 5, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(PVI/@elevation), 5, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(@startVerticalCurveLength), 5, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(@endVerticalCurveLength), 5, 16)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>37NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalEnd/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalEnd/@elevation), 5, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template match="VerticalCircle">
        <xsl:if test="position() = 1">
            <xsl:text>34NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalStart/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalStart/@elevation), 5, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:text>35NM</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(PVI/station/@internalStation), 5, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormatLeft(number(PVI/@elevation), 5, 16)"/>
        <xsl:choose>
            <xsl:when test="@radius &lt; 0.0">
                <xsl:value-of select="inr:columnDoubleFormatLeft(number(-1 * @radius), 5, 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormatLeft(number(@radius), 5, 16)"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>37NM</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalEnd/station/@internalStation), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormatLeft(number(VerticalEnd/@elevation), 5, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt; Geometry&#xd;</xsl:text>
        <xsl:text>    command to get results from this report.  If you wish&#xd;</xsl:text>
        <xsl:text>    to report vertical alignment data, you must also toggle&#xd;</xsl:text>
        <xsl:text>    on the Include Vertical Alignments option and select&#xd;</xsl:text>
        <xsl:text>    Active.&#xd;&#xd;</xsl:text>
        <xsl:text>    Note:  Vertical alignment data is required for a&#xd;</xsl:text>
        <xsl:text>    complete report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must toggle off the Include Angular Suffix option&#xd;</xsl:text>
        <xsl:text>    on the Tools &gt; Format Options dialog in the Report&#xd;</xsl:text>
        <xsl:text>    Browser.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2007 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function gets the current date and formats it for Trimble DC Format
            function DCdate()
            {
                var today = new Date();
                var monthName = new Array ("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec");
                var dayOfMonth = today.getDate();
                var year = today.getFullYear();
                if (dayOfMonth < 10)
                {
                    dayOfMonth = "0" + dayOfMonth;
                }
                year = year - 2000;
                if (year < 10)
                {
                    year = "0" + year;
                }
                return dayOfMonth + "-" + monthName[today.getMonth()] + "-" + year;
            }
            // This function gets the current time and formats it for Trimble DC Format
            function DCtime()
            {
                var today = new Date();
                var hours = today.getHours();
                var minutes = today.getMinutes();
                if (minutes < 10)
                {
                    minutes = "0" + minutes;
                }
                return hours + ":" + minutes;
            }
            // This function formats a left-justified string with a length and pads with spaces on the
            // right
            function columnFormatLeft(strString, nLength)
            {
                var i = 0;
                var nBlanks = nLength - strString.length;
                for( i = 0; i < nBlanks; i++ )
                    strString = strString + " ";
                return strString;
            }
            // This function sets precision for a double, converts it to a left-justified string with a
            // length and pads with spaces on the right
            function columnDoubleFormatLeft( dNum, nPrecision, nLength )
            {
                var i = 0, j = 0;
                var strResult = formatNumber(dNum, nPrecision)
                if( strResult.indexOf( decSep ) == -1 )
                    strResult += decSep;
                var nCount = strResult.length - strResult.indexOf( decSep ) - 1;
                for( j = 0; j < (nPrecision - nCount); j++ )
                    strResult += "0";
                var nBlanks = nLength - strResult.length;
                for( i = 0; i < nBlanks; i++ )
                    strResult = strResult + " ";
                return strResult;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
