<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Unique cross section surfaces -->
    <xsl:variable name="uniqueSurfaceName" select="//CrossSectionSurfaces/CrossSectionSurface[not (@name = preceding::CrossSectionSurface/@name)]/@name"/>
    <!-- Slope Stake Listing -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/document.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Slope Stake Listing</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h6 lang="en">SLOPE STAKE LISTING</h6>
                                <p lang="en">
                                    <xsl:value-of select="inr:longDate()"/>&#xa0; <xsl:value-of select="inr:longTime()"/>
                                </p>
                            </center>
                            <!-- Cross Section Set Data -->
                            <xsl:for-each select="CrossSectionSet">
                                <table class="margin">
                                    <tbody>
                                        <tr>
                                            <td lang="en">Set Name:&#xa0; </td>
                                            <td><xsl:value-of select="@setName"/></td>
                                        </tr>
                                        <tr>
                                            <td lang="en">Project Units:&#xa0; </td>
                                            <td lang="en">
                                                <xsl:if test="//@linearUnits = 'Imperial'">US Survey Feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">Metric</xsl:if>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td lang="en">Contract No.:&#xa0; </td>
                                            <td>&#xa0;</td>
                                        </tr>
                                        <tr>
                                            <td lang="en">Co./Rte./PM:&#xa0; </td>
                                            <td>&#xa0;</td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Cross Section Point Data -->
                                <table class="margin" width="90%">
                                    <xsl:for-each select="$uniqueSurfaceName[../@type = 1]">
                                        <xsl:for-each select="//CrossSectionSurface[@name = current()]">
                                            <xsl:for-each select="CrossSectionPoints">
                                                <!-- Alignment Name -->
                                                <tr>
                                                    <th colspan="11" lang="en">
                                                        Alignment Chain:&#xa0; <xsl:value-of select="../../../../../@alignmentName"/>
                                                    </th>
                                                </tr>
                                                <!-- Station -->
                                                <tr>
                                                    <th colspan="11" lang="en">
                                                        Station:&#xa0; <xsl:value-of select="inr:stationFormat(number(../../../Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../../../Station/@externalStationName))"/>
                                                    </th>
                                                </tr>
                                                <!-- Feature Name -->
                                                <tr>
                                                    <xsl:for-each select="CrossSectionPoint[position() = 1][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <th>CP</th>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name] | CrossSectionPoint[not (CrossSectionFeatures/CrossSectionFeature/@name) and (@offset &gt; -0.0001 and @offset &lt; 0.0001)]">
                                                        <th>
                                                            <xsl:value-of select="CrossSectionFeatures/CrossSectionFeature/@name"/>
                                                        </th>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[position() = last()][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <th>CP</th>
                                                    </xsl:for-each>
                                                </tr>
                                                <!-- Offset -->
                                                <tr>
                                                    <xsl:for-each select="CrossSectionPoint[position() = 1][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:value-of select="inr:distanceFormat(number(@offset), $xslDistancePrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name] | CrossSectionPoint[not (CrossSectionFeatures/CrossSectionFeature/@name) and (@offset &gt; -0.0001 and @offset &lt; 0.0001)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:value-of select="inr:distanceFormat(number(@offset), $xslDistancePrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[position() = last()][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:value-of select="inr:distanceFormat(number(@offset), $xslDistancePrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                </tr>
                                                <!-- Elevation -->
                                                <tr>
                                                    <xsl:for-each select="CrossSectionPoint[position() = 1][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name] | CrossSectionPoint[@offset &gt; -0.0001 and @offset &lt; 0.0001]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[position() = last()][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                </tr>
                                                <!-- Slope -->
                                                <tr>
                                                    <xsl:for-each select="CrossSectionPoint[position() = 1][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:value-of select="inr:alternateGradeFormat(number(CrossSectionSegment/@slope), $xslGradeFormat, $xslGradePrecision, $xslIfSlopeExceeds, $xslAlternateSlopeFormat, $xslAlternateSlopePrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name] | CrossSectionPoint[not (CrossSectionFeatures/CrossSectionFeature/@name) and (@offset &gt; -0.0001 and @offset &lt; 0.0001)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:value-of select="inr:alternateGradeFormat(number(CrossSectionSegment/@slope), $xslGradeFormat, $xslGradePrecision, $xslIfSlopeExceeds, $xslAlternateSlopeFormat, $xslAlternateSlopePrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[position() = last()][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:value-of select="inr:alternateGradeFormat(number(CrossSectionSegment/@slope), $xslGradeFormat, $xslGradePrecision, $xslIfSlopeExceeds, $xslAlternateSlopeFormat, $xslAlternateSlopePrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                </tr>
                                                <!-- Cut/Fill Depth -->
                                                <tr>
                                                    <xsl:for-each select="CrossSectionPoint[position() = 1][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:choose>
                                                                <xsl:when test="CrossSectionSegment/@height &gt; 0.0">
                                                                    <xsl:text>C </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:when>
                                                                <xsl:when test="CrossSectionSegment/@height &lt; 0.0">
                                                                    <xsl:text>F </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(-1 * CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <xsl:text> </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name][CrossSectionSegment][@offset &lt; 0]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:choose>
                                                                <xsl:when test="CrossSectionSegment/@height &gt; 0.0">
                                                                    <xsl:text>C </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:when>
                                                                <xsl:when test="CrossSectionSegment/@height &lt; 0.0">
                                                                    <xsl:text>F </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(-1 * CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <xsl:text> </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name][@offset &gt; -0.0001 and @offset &lt; 0.0001] | CrossSectionPoint[@offset &gt; -0.0001 and @offset &lt; 0.0001]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">&#xa0;</td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name][CrossSectionSegment][@offset &gt; 0]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:choose>
                                                                <xsl:when test="CrossSectionSegment/@height &gt; 0.0">
                                                                    <xsl:text>C </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:when>
                                                                <xsl:when test="CrossSectionSegment/@height &lt; 0.0">
                                                                    <xsl:text>F </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(-1 * CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <xsl:text> </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[position() = last()][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:choose>
                                                                <xsl:when test="CrossSectionSegment/@height &gt; 0.0">
                                                                    <xsl:text>C </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:when>
                                                                <xsl:when test="CrossSectionSegment/@height &lt; 0.0">
                                                                    <xsl:text>F </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(-1 * CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <xsl:text> </xsl:text>
                                                                    <xsl:value-of select="inr:elevationFormat(number(CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </td>
                                                    </xsl:for-each>
                                                </tr>
                                                <!-- Distance from Previous Point -->
                                                <tr>
                                                    <xsl:for-each select="CrossSectionPoint[position() = 1][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:text>@ </xsl:text>
                                                            <xsl:value-of select="inr:distanceFormat(number(CrossSectionSegment/@width), $xslDistancePrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name][CrossSectionSegment][@offset &lt; 0]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:text>@ </xsl:text>
                                                            <xsl:value-of select="inr:distanceFormat(number(CrossSectionSegment/@width), $xslDistancePrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name][@offset &gt; -0.0001 and @offset &lt; 0.0001] | CrossSectionPoint[@offset &gt; -0.0001 and @offset &lt; 0.0001]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">&#xa0;</td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name][CrossSectionSegment][@offset &gt; 0]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:text>@ </xsl:text>
                                                            <xsl:value-of select="inr:distanceFormat(number(CrossSectionSegment/@width), $xslDistancePrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                    <xsl:for-each select="CrossSectionPoint[position() = last()][not (CrossSectionFeatures/CrossSectionFeature/@name)]">
                                                        <td align="center" style="padding-left:5px;padding-right:5px;white-space:nowrap;">
                                                            <xsl:text>@ </xsl:text>
                                                            <xsl:value-of select="inr:distanceFormat(number(CrossSectionSegment/@width), $xslDistancePrecision)"/>
                                                        </td>
                                                    </xsl:for-each>
                                                </tr>
                                                <tr><td>&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </xsl:for-each>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function gets the current date.
            function longDate()
            {
                var today = new Date();
                var month = today.getMonth();
                var monthName = new Array("January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December");
                var dayOfMonth = today.getDate();
                if (dayOfMonth < 10)
                {
                    dayOfMonth = "0" + dayOfMonth;
                }
                var year = today.getFullYear();
                return monthName[today.getMonth()] + " " + dayOfMonth + ", " + year;
            }
            // This function gets the current time.
            function longTime()
            {
                var today = new Date();
                var hours = today.getHours();
                var setting = "";
                if (hours == 12)
                {
                    setting = "PM";
                }
                if (hours == 24)
                {
                    setting = "AM";
                }
                if (hours < 12)
                {
                    setting = "AM";
                }
                if (hours > 12)
                {
                    setting = "PM";
                    hours = hours - 12;
                }
                var minutes = today.getMinutes();
                if (minutes < 10)
                {
                    minutes = "0" + minutes;
                }
                var seconds = today.getSeconds();
                if (seconds < 10)
                {
                    seconds = "0" + seconds;
                    }
                return hours + ":" + minutes + ":" + seconds + " " + setting;
            }
        ]]>
    </msxsl:script>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have created cross sections along your alignment and the cross section set must 
                have the surfaces and features upon which you wish to report displayed.
            </p>
            <p class="normal1" lang="en">
                You can create the XML data file from the <em>Evaluation &gt; Cross Section &gt; Cross 
                Section Report</em> command or from the <em>End-Area Volumes</em> leaf of the <em>
                Evaluation &gt; Cross Section &gt; Cross Sections</em> command by toggling on the <em>
                Create XML Report</em> option on the <em>General</em> leaf.
            </p>
            <p class="normal1" lang="en">
                This report works only with surfaces whose <em>Type</em> on the <em>Main</em> tab of the 
                <em>Surface &gt; Surface Properties</em> command is set to <em>Design</em>.&#xa0; It works 
                best if all features (except the catchpoints) included in the XML data file have 
                names.&#xa0; There should also be a point at the center line for best results.&#xa0; 
                Components are not reported.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2010 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
