<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Vertical Alignment .3% Grade Report -->
    <!-- This report lists the stations where a grade of .3% has been reached   -->
    <!-- for drainage purposes and can be modified for other slopes by changing -->
    <!-- the variable below.                                                    -->
    <xsl:variable name="targetSlope" select="0.003"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Vertical Alignment Three Percent Grade Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Vertical Alignment .3% Grade Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <xsl:for-each select="HorizontalAlignment[VerticalAlignment]">
                                    <table class="margin" width="60%">
                                        <tbody>
                                            <tr>
                                                <th align="right" colspan="2" lang="en"><br/>Horizontal Alignment:&#xa0; </th>
                                                <td align="left" colspan="2" valign="bottom"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Horizontal Description:&#xa0; </th>
                                                <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                            </tr>
                                            <!-- Vertical Alignment Data -->
                                            <xsl:for-each select="VerticalAlignment">
                                                <tr>
                                                    <th align="right" colspan="2" lang="en"><br/>Vertical Alignment:&#xa0; </th>
                                                    <td align="left" colspan="2" valign="bottom"><xsl:value-of select="@name"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" colspan="2" lang="en">Vertical Description:&#xa0; </th>
                                                    <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                                </tr>
                                                <tr><td colspan="4">&#xa0;</td></tr>
                                                <tr>
                                                    <th class="underline" lang="en">Low Point<br/>Station</th>
                                                    <th class="underline" lang="en">Elevation</th>
                                                    <th class="underline" lang="en">
                                                        Back Station<br/>at
                                                        <xsl:value-of select="inr:gradeFormat(number($targetSlope), $xslGradeFormat, $xslGradePrecision)"/>
                                                    </th>
                                                    <th class="underline" lang="en">
                                                        Ahead Station<br/>at
                                                        <xsl:value-of select="inr:gradeFormat(number($targetSlope), $xslGradeFormat, $xslGradePrecision)"/>
                                                    </th>
                                                </tr>
                                                <xsl:apply-templates/>
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola[TurningPoint/@pointType = 'VLOW']">
        <tr>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation - ((10000 * $targetSlope) div @rateOfChange)), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation + ((10000 * $targetSlope) div @rateOfChange)), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="VerticalUnsymmetricalParabola[TurningPoint/@pointType = 'VLOW']">
        <tr>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation - ((10000 * $targetSlope) div @startRateOfChange)), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td class="sidepad" align="right">
                <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation + ((10000 * $targetSlope) div @endRateOfChange)), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                You must also toggle on the <em>Include Vertical Alignments</em> option and 
                select either <em>All</em> or <em>Active</em>.
            </p>
            <p class="normal1" lang="en">
                Your vertical alignment must contain at least one sag curve for a complete report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
