<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- ICS Audit Trail Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>* Geometry File Name: </xsl:text><xsl:value-of select="@file"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>* Geometry Project Name: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>* Geometry Project Description: </xsl:text><xsl:value-of select="@description"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>* Date: </xsl:text><xsl:value-of select="inr:date()"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>* Time: </xsl:text><xsl:value-of select="inr:time()"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>SET SEQUENCE NE&#xd;</xsl:text>
                    <xsl:text>SET PARAMETER 1&#xd;</xsl:text>
                    <xsl:text>SET REFERENCE z&#xd;</xsl:text>
                    <xsl:text>SET TOLERANCE 0.0001&#xd;</xsl:text>
                    <xsl:text>COMBINED GRID FACTOR 1. 1.&#xd;</xsl:text>
                    <xsl:text>SET PROTECTION 0&#xd;</xsl:text>
                    <!-- Cogo Points -->
                    <xsl:for-each select="CogoPoints">
                        <xsl:for-each select="GeometryPoint">
                            <xsl:text>STORE </xsl:text>
                            <xsl:value-of select="inr:columnFormat(string(@name), 6)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@northing), 6, 15)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@easting), 6, 15)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), 6, 12)"/>
                            <xsl:text>! </xsl:text>
                            <xsl:value-of select="@style"/>
                            <xsl:text> * </xsl:text>
                            <xsl:value-of select="@description"/>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                    </xsl:for-each>
                    <!-- Horizontal Alignments -->
                    <xsl:for-each select="HorizontalAlignment[HorizontalElements/*]">
                        <xsl:text>&#xd;</xsl:text>
        	             <xsl:text>AUTO PLOT 0 ! </xsl:text><xsl:value-of select="@style"/><xsl:text>&#xd;</xsl:text>
                        <xsl:for-each select="HorizontalElements">
                            <xsl:apply-templates mode="point"/>
                            <xsl:text>STORE </xsl:text>
                            <xsl:value-of select="inr:columnFormat(string(*[position() = last()]/End/@name), 6)"/>
                            <xsl:text> </xsl:text>
                            <xsl:value-of select="inr:columnDoubleFormat(number(*[position() = last()]/End/@northing), 6, 14)"/>
                            <xsl:text> </xsl:text>
                            <xsl:value-of select="inr:columnDoubleFormat(number(*[position() = last()]/End/@easting), 6, 14)"/>
                            <xsl:text> </xsl:text>
                            <xsl:value-of select="inr:columnDoubleFormat(number(*[position() = last()]/End/@elevation), 6, 11)"/>
                            <xsl:text> ! </xsl:text>
                            <xsl:value-of select="*[position() = last()]/End/@style"/>
                            <xsl:text> * </xsl:text>
                            <xsl:value-of select="*[position() = last()]/End/@description"/>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                        <xsl:text>DELETE FIGURE [ </xsl:text><xsl:value-of select="@name"/><xsl:text> ]&#xd;</xsl:text>
                        <xsl:text>STORE FIGURE </xsl:text>
                        <xsl:value-of select="@name"/>
                        <xsl:for-each select="HorizontalElements">
                            <xsl:variable name="fmtStartStation" select="inr:stationFormat(number(*[position() = 1]/Start/station/@externalStation), $xslStationFormat, 6, string(*[position() = 1]/Start/station/@externalStationName))"/>
                            <xsl:apply-templates mode="figure"/>
                            <xsl:value-of select="*[position() = 1]/Start/@name"/>
                            <xsl:text> </xsl:text>
                            <xsl:value-of select="inr:columnFormat(string($fmtStartStation), 16)"/>
                            <xsl:text>&#xd;</xsl:text>
        		              <xsl:text>FIGURE DESCRIPTION [ </xsl:text><xsl:value-of select="../@name"/><xsl:text> ] * </xsl:text><xsl:value-of select="../@description"/><xsl:text>&#xd;</xsl:text>
        		              <xsl:text>SET ALIGNMENT </xsl:text><xsl:value-of select="../@name"/>
                            <xsl:text>&#xd;</xsl:text>
                            <xsl:for-each select="*/StationEquation">
                                <xsl:variable name="fmtBackStation" select="inr:stationFormat(number(@backStation), $xslStationFormat, 6, string(@backEquation))"/>
                                <xsl:variable name="fmtAheadStation" select="inr:stationFormat(number(@aheadStation), $xslStationFormat, 6, string(@aheadEquation))"/>
                                <xsl:text>STATION EQUATION </xsl:text>
                                <xsl:value-of select="inr:columnFormat(string($fmtBackStation), 16)"/>
                                <xsl:value-of select="inr:columnFormat(string($fmtAheadStation), 16)"/>
                                <xsl:text>&#xd;</xsl:text>
                            </xsl:for-each>
                        </xsl:for-each>
                        <xsl:for-each select="VerticalAlignment">
                            <xsl:apply-templates mode="vertical"/>
                        </xsl:for-each>
                        <xsl:text>CLEAR ALIGNMENT </xsl:text><xsl:text>&#xd;</xsl:text>
                    </xsl:for-each>
                    <xsl:text>SET PROTECTION 1&#xd;</xsl:text>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Element Point Data -->
    <xsl:template match="Start | HorizontalLine/PI | HorizontalSpiral/PI | Center" mode="point">
        <xsl:text>STORE </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(@name), 6)"/><xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@northing), 6, 14)"/><xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@easting), 6, 14)"/><xsl:text> </xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), 6, 11)"/><xsl:text> </xsl:text>
        <xsl:text>! </xsl:text>
        <xsl:value-of select="@style"/>
        <xsl:text> * </xsl:text>
        <xsl:value-of select="@description"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine" mode="figure">
        <xsl:if test="position() = 1">
            <xsl:text> ( </xsl:text>
        </xsl:if>
        <xsl:value-of select="Start/@name"/>
        <xsl:choose>
            <xsl:when test="position() mod 8 = 0">
                <xsl:text>&#xd; </xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text> </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="position() = last()">
            <xsl:value-of select="End/@name"/>
            <xsl:text> ) </xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle" mode="figure">
        <xsl:if test="position() = 1">
            <xsl:text> ( </xsl:text>
        </xsl:if>
        <xsl:value-of select="Start/@name"/>
        <xsl:text> C</xsl:text>
        <xsl:value-of select="Center/@name"/>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">L</xsl:when>
            <xsl:otherwise>R</xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="position() mod 8 = 0">
                <xsl:text>&#xd; </xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text> </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="position() = last()">
            <xsl:value-of select="End/@name"/>
            <xsl:text> ) </xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="HorizontalSpiral" mode="figure">
        <xsl:if test="position() = 1">
            <xsl:text> ( </xsl:text>
        </xsl:if>
        <xsl:value-of select="Start/@name"/>
        <xsl:text> S</xsl:text>
        <xsl:value-of select="PI/@name"/>
        <xsl:choose>
            <xsl:when test="position() mod 8 = 0">
                <xsl:text>&#xd; </xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text> </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="position() = last()">
            <xsl:value-of select="End/@name"/>
            <xsl:text> ) </xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Line Data -->
    <xsl:template match="VerticalLine" mode="vertical">
        <xsl:variable name="fmtStartStation" select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, 6, string(VerticalStart/station/@externalStationName))"/>
        <xsl:if test="position() = 1 or preceding-sibling::*[1][name() = 'VerticalLine']">
            <xsl:text>VERTICAL START </xsl:text>
            <xsl:value-of select="inr:columnFormat(string($fmtStartStation), 16)"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="format-number(number(VerticalStart/@elevation), '#0.000000')"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:if test="position() = last()">
            <xsl:variable name="fmtEndStation" select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, 6, string(VerticalEnd/station/@externalStationName))"/>
            <xsl:text>VERTICAL END </xsl:text>
            <xsl:value-of select="inr:columnFormat(string($fmtEndStation), 18)"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="format-number(number(VerticalEnd/@elevation), '#0.000000')"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="../../@name"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola" mode="vertical">
        <xsl:variable name="fmtStartStation" select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, 6, string(VerticalStart/station/@externalStationName))"/>
        <xsl:text>VERTICAL START </xsl:text>
            <xsl:value-of select="inr:columnFormat(string($fmtStartStation), 16)"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="format-number(number(PVI/@elevation), '#0.000000')"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="format-number(number(@verticalCurveLength), '#0.000000')"/>
            <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Unsymmetrical Parabola Data -->
    <xsl:template match="VerticalUnsymmetricalParabola" mode="vertical">
        <xsl:variable name="fmtStartStation" select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, 6, string(VerticalStart/station/@externalStationName))"/>
        <xsl:text>VERTICAL START </xsl:text>
            <xsl:value-of select="inr:columnFormat(string($fmtStartStation), 16)"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="format-number(number(PVI/@elevation), '#0.000000')"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="format-number(number(@startVerticalCurveLength), '#0.000000')"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="format-number(number(@endVerticalCurveLength), '#0.000000')"/>
            <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    If your alignment points do not have names, this report&#xd;</xsl:text>
        <xsl:text>    will produce unusable results for ICS input.&#xd;&#xd;</xsl:text>
        <xsl:text>    Cogo point names and alignment point names must follow&#xd;</xsl:text>
        <xsl:text>    the strict ICS naming conventions for this report to be&#xd;</xsl:text>
        <xsl:text>    usable as an ICS input file.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must toggle on the Include Vertical Alignments&#xd;</xsl:text>
        <xsl:text>    option and select either All or Active if you wish to&#xd;</xsl:text>
        <xsl:text>    include them in this report.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
