<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- LandXML Horizontal Alignment Review ASCII Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="LandXML">
                    <xsl:text/>
                    <xsl:text>* BENTLEY LANDXML HORIZONTAL ALIGNMENT REVIEW&#xd;</xsl:text>
                    <xsl:text>* &#xd;</xsl:text>
                    <!-- Horizontal Alignment Data -->
                    <xsl:for-each select="Alignments/Alignment/CoordGeom">
                        <xsl:text>* Alignment name: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment description: </xsl:text><xsl:value-of select="@desc"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment style: </xsl:text><xsl:value-of select="*/Feature/Property[@label = 'style']/@value"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Input Factor: </xsl:text><xsl:value-of select="//Project/Feature/Property[@label = 'GridScaleFactor']/@value"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* &#xd;</xsl:text>
                        <xsl:value-of select="inr:columnFormat('STATION',47)"/>
                        <xsl:value-of select="inr:columnFormat('NORTHING',20)"/>
                        <xsl:value-of select="inr:columnFormat('EASTING',20)"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:apply-templates/>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Linear Data -->
    <xsl:template match="Line">
        <xsl:text>Element: linear</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(Start/@code), 15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(Start/@name), 10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@staStart), $xslStationFormat, $xslStationPrecision, ''), 20)"/>
        <xsl:call-template name="outputYCoord">
            <xsl:with-param name="list" select="Start"/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(End/@code), 15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(End/@name), 10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@staStart + @length), $xslStationFormat, $xslStationPrecision, ''), 20)"/>
        <xsl:call-template name="outputYCoord">
            <xsl:with-param name="list" select="End"/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangential Direction:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@dir), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangential Length:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Horizontal Circular Data -->
    <xsl:template match="Curve">
        <xsl:text>Element: circular</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(Start/@code), 15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(Start/@name), 10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@staStart), $xslStationFormat,$xslStationPrecision, ''), 20)"/>
        <xsl:call-template name="outputYCoord">
            <xsl:with-param name="list" select="Start"/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(Center/@code), 14)"/>
        <xsl:text> (</xsl:text><xsl:value-of select="inr:columnFormat(string(Center/@name), 10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat('', 20)"/>
        <xsl:call-template name="outputYCoord">
            <xsl:with-param name="list" select="Center"/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(End/@code), 15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(End/@name), 10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@staStart + @length), $xslStationFormat, $xslStationPrecision, ''), 20)"/>
        <xsl:call-template name="outputYCoord">
            <xsl:with-param name="list" select="End"/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Radius:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@radius), $xslDistancePrecision), 20)"/>
        <xsl:if test="@rot = 'cw'"><xsl:text> Right</xsl:text></xsl:if>
        <xsl:if test="@rot = 'ccw'"><xsl:text> Left</xsl:text></xsl:if>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Length:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Chord:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@chord), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="Spiral">
        <xsl:text>Element: </xsl:text><xsl:value-of select="@spiType"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(Start/@code), 15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(Start/@name), 10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@staStart), $xslStationFormat,$xslStationPrecision, ''), 20)"/>
        <xsl:call-template name="outputYCoord">
            <xsl:with-param name="list" select="Start"/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(PI/@type), 15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(PI/@name), 10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat('', 20)"/>
        <xsl:call-template name="outputYCoord">
            <xsl:with-param name="list" select="PI"/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(End/@code), 15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(End/@name), 10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@staStart + @length), $xslStationFormat, $xslStationPrecision, ''), 20)"/>
        <xsl:call-template name="outputYCoord">
            <xsl:with-param name="list" select="End"/>
        </xsl:call-template>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Entrance Radius:', 27)"/>
        <xsl:choose>
            <xsl:when test="string(number(@radiusStart)) = 'NaN'">
                <xsl:value-of select="inr:columnFormat('INF', 20)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@radiusStart), $xslDistancePrecision), 20)"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Exit Radius:', 27)"/>
        <xsl:choose>
            <xsl:when test="string(number(@radiusEnd)) = 'NaN'">
                <xsl:value-of select="inr:columnFormat('INF', 20)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@radiusEnd), $xslDistancePrecision), 20)"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Length:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Angle:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:angularFormat(number(@theta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod), 20)"/>
        <xsl:if test="@rot = 'cw'"><xsl:text> Right</xsl:text></xsl:if>
        <xsl:if test="@rot = 'ccw'"><xsl:text> Left</xsl:text></xsl:if>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Constant:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@constant), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Long Tangent:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@tanLong), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Short Tangent:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@tanShort), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Xs:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@totalX), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Ys:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@totalY), $xslDistancePrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangent Direction Start:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@dirStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangent Direction End:', 27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@dirEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Coordinates -->
    <xsl:template name="outputYCoord">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <xsl:variable name="rest" select="substring-after($nList, ' ')"/>
        <xsl:value-of select="inr:columnFormat(inr:northingFormat(number($first), $xslNorthingPrecision), 20)"/>
        <xsl:if test="$rest">
            <xsl:call-template name="outputXCoord">
                <xsl:with-param name="list" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="outputXCoord">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number($first), $xslEastingPrecision), 20)"/>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in the&#xd;</xsl:text>
        <xsl:text>    Include field on the Export Alignment tab of the File &gt;&#xd;</xsl:text>
        <xsl:text>    Translators &gt; LandXML Translator command to get results from&#xd;</xsl:text>
        <xsl:text>    this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must also edit the file produced by the LandXML Translator&#xd;</xsl:text>
        <xsl:text>    command to remove the following attributes from the LandXML&#xd;</xsl:text>
        <xsl:text>    element at the top:&#xd;&#xd;</xsl:text>
        <xsl:text>       xmlns="http://www.landxml.org/schema/LandXML-1.1"&#xd;&#xd;</xsl:text>
        <xsl:text>       xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"&#xd;&#xd;</xsl:text>
        <xsl:text>       xsi:schemaLocation="http://www.landxml.org/schema/LandXML-1.1&#xd;</xsl:text>
        <xsl:text>         http://www.landxml.org/schema/landxml-1.1/LandXML-1.1.xsd"&#xd;&#xd;</xsl:text>
        <xsl:text>    The LandXML element should now resemble the following, where the&#xd;</xsl:text>
        <xsl:text>    version, date and time are replaced with your actual values:&#xd;&#xd;</xsl:text>
        <xsl:text>       &lt;LandXML version="1.1" date="2009-11-16" time="12:29:43"&gt;&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2009 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
