<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- LandXML List Coordinates Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">LandXML List Coordinates Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="LandXML">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">LandXML List Coordinates Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <table class="margin" cellpadding="2" width="90%">
                                <tbody>
                                    <tr>
                                        <th align="right" lang="en">Project:&#xa0; </th>
                                        <td align="left" colspan="2"><xsl:value-of select="Project/@name"/></td>
                                    </tr>
                                    <tr>
                                        <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                        <td align="left" style="font-size: 80%">
                                            <xsl:value-of select="Project/Feature/Property[@label = 'GridScaleFactor']/@value" />
                                        </td>
                                        <td align="right" lang="en" style="font-size: 80%">
                                            <strong>Note:&#xa0; </strong>All units in this report are in
                                            <xsl:if test="Units[Imperial]">feet</xsl:if>
                                            <xsl:if test="Units[Metric]">meters</xsl:if>
                                            unless specified otherwise.
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <hr/>
                            <!-- Horizontal Alignment Data -->
                            <xsl:for-each select="Alignments/Alignment/CoordGeom">
                                <table class="margin" cellpadding="2" cellspacing="5" width="90%">
                                    <colgroup span="5">
                                        <col width="16%"/>
                                        <col width="21%"/>
                                        <col width="21%"/>
                                        <col width="21%"/>
                                        <col width="21%"/>
                                    </colgroup>
                                    <tbody>
                                        <tr>
                                            <td align="left" colspan="5" lang="en" valign="bottom">
                                                <br/><strong>Alignment Name:&#xa0; </strong>
                                                <xsl:value-of select="@name"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th class="underline" lang="en">Point<br />Name</th>
                                            <th class="underline" lang="en">Type</th>
                                            <th class="underline" lang="en">Northing</th>
                                            <th class="underline" lang="en">Easting</th>
                                            <th class="underline" lang="en">Elevation</th>
                                        </tr>
                                        <xsl:apply-templates/>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                            <!-- Cogo Point Data -->
                            <xsl:for-each select="CgPoints">
                                <table class="margin" cellpadding="4" cellspacing="5" width="90%">
                                    <colgroup span="5">
                                        <col width="16%"/>
                                        <col width="21%"/>
                                        <col width="21%"/>
                                        <col width="21%"/>
                                        <col width="21%"/>
                                    </colgroup>
                                    <thead>
                                        <tr><th align="left" colspan="5" lang="en">Cogo Points</th></tr>
                                        <tr>
                                            <th class="underline" lang="en">Point<br />Name</th>
                                            <th class="underline" lang="en">Type</th>
                                            <th class="underline" lang="en">Northing</th>
                                            <th class="underline" lang="en">Easting</th>
                                            <th class="underline" lang="en">Elevation</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="CgPoint">
                                            <tr>
                                                <td align="center"><xsl:value-of select="@name"/></td>
                                                <td align="center"><xsl:value-of select="@code"/></td>
                                                <xsl:call-template name="outputYCoord">
                                                    <xsl:with-param name="list" select="."/>
                                                </xsl:call-template>
                                            </tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Element Point Data -->
    <xsl:template match="Start | PI | Center | End[@code = 'POE']">
        <tr>
            <td align="center"><xsl:value-of select="@name"/></td>
            <td align="center"><xsl:value-of select="@code"/></td>
            <xsl:call-template name="outputYCoord">
                <xsl:with-param name="list" select="."/>
            </xsl:call-template>
        </tr>
    </xsl:template>
    <xsl:template match="End[@code != 'POE']"/>
    <!-- Coordinates -->
    <xsl:template name="outputYCoord">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <xsl:variable name="rest" select="substring-after($nList, ' ')"/>
        <td align="right"><xsl:value-of select="inr:northingFormat(number($first), $xslNorthingPrecision)"/></td>
        <xsl:if test="$rest">
            <xsl:call-template name="outputXCoord">
                <xsl:with-param name="list" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="outputXCoord">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <xsl:variable name="rest" select="substring-after($nList, ' ')"/>
        <td align="right"><xsl:value-of select="inr:eastingFormat(number($first), $xslEastingPrecision)"/></td>
        <xsl:if test="$rest">
            <xsl:call-template name="outputZCoord">
                <xsl:with-param name="list" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="outputZCoord">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <xsl:variable name="rest" select="substring-after($nList, ' ')"/>
        <td align="right"><xsl:value-of select="inr:elevationFormat(number($first), $xslElevationPrecision)"/></td>
        <xsl:if test="$rest">
            <xsl:call-template name="outputXCoord">
                <xsl:with-param name="list" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field or toggle 
                on the <em>Include All Cogo Points</em> option on the <em>Export Alignment</em> tab of the 
                <em>File &gt; Translators &gt; LandXML Translator</em> command to get results from this 
                report.
            </p>
            <p class="normal1" lang="en">
                You must also edit the file produced by the <em>LandXML Translator</em> command to remove 
                the following attributes from the LandXML element at the top:
            </p>
            <ul style="list-style-type:none">
                <li>xmlns="http://www.landxml.org/schema/LandXML-1.1"</li>
                <li>xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"</li>
                <li>
                    xsi:schemaLocation="http://www.landxml.org/schema/LandXML-1.1 
                    http://www.landxml.org/schema/landxml-1.1/LandXML-1.1.xsd"
                </li>
            </ul>
            <p class="normal1" lang="en">
                The LandXML element should now resemble the following, where the version, date and time are 
                replaced with your actual values:
            </p>
            <ul style="list-style-type:none">
                <li>&lt;LandXML version="1.1" date="2009-11-16" time="12:29:43"&gt;</li>
            </ul>
            <p class="small" lang="en">
                <em>&#xa9; 2009 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
