<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Variable to hold unit string -->
    <xsl:variable name="unit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'"> feet</xsl:when>
            <xsl:otherwise> meters</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Property Description Report (extended to fully spell out North, East, West and South) -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html lang="en">
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title>Property Description</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2>Property Description</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <div style="margin-left:0.5in;margin-right:0.5in">
                                    <xsl:for-each select="HorizontalAlignment">
                                        <table cellpadding="2">
                                            <tbody>
                                                <tr>
                                                    <th align="right" valign="bottom"><br/>Alignment Name:&#xa0; </th>
                                                    <td align="left" valign="bottom"><xsl:value-of select="@name"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" valign="top">Alignment Description:&#xa0; </th>
                                                    <td align="left" valign="top"><xsl:value-of select="@description"/><br/>&#xa0;</td>
                                                </tr>
                                            </tbody>
                                        </table>
                                        <xsl:apply-templates/>
                                        <br/><br/>
                                        <xsl:if test="@area > 0">
                                            The above described parcel contains 
                                            <xsl:if test="//@linearUnits = 'Imperial'">
                                                <xsl:value-of select="inr:acreFormat(number(@area) div 43560, $xslAcrePrecision)"/> acres
                                                (<xsl:value-of select="inr:areaFormat(number(@area), $xslAreaPrecision)"/> sq. ft.)
                                            </xsl:if>
                                            <xsl:if test="//@linearUnits = 'Metric'">
                                                <xsl:value-of select="inr:acreFormat(number(@area) div 10000, $xslAcrePrecision)"/> hectares
                                                (<xsl:value-of select="inr:areaFormat(number(@area), $xslAreaPrecision)"/> sq. m.)
                                            </xsl:if>
                                        </xsl:if>
                                        <br style="line-height:200%"/>&#xa0;
                                    </xsl:for-each>
                                </div>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Alignment Linear Data -->
    <xsl:template match="HorizontalLine">
        <xsl:choose>
            <xsl:when test="position() = 1">
                Beginning at a point
                <xsl:if test="Start/legalReference">
                    <xsl:if test="Start/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(Start/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="Start/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - Start/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="Start/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="Start/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="Start/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(Start/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/legalReference/station/@externalStationName))"/>
                </xsl:if>
                thence
                <xsl:value-of select="inr:fullDirectionFormat(number(@direction), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                a distance of
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="End/legalReference">
                    to a point
                    <xsl:if test="End/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="End/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="End/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/legalReference/station/@externalStationName))"/>
                </xsl:if>
            </xsl:when>
            <xsl:when test="position() = last()">
                thence <xsl:value-of select="inr:fullDirectionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                a distance of
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="End/legalReference">
                    to a point
                    <xsl:if test="End/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="End/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="End/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/legalReference/station/@externalStationName))"/>
                </xsl:if>
                <xsl:if test="../../@area > 0"> and the POINT OF BEGINNING.</xsl:if>
            </xsl:when>
            <xsl:otherwise>
                thence <xsl:value-of select="inr:fullDirectionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                a distance of
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="End/legalReference">
                    to a point
                    <xsl:if test="End/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="End/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="End/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/legalReference/station/@externalStationName))"/>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Alignment Circular Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:choose>
            <xsl:when test="position() = 1">
                Beginning at a point
                <xsl:if test="Start/legalReference">
                    <xsl:if test="Start/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(Start/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="Start/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - Start/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="Start/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="Start/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="Start/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(Start/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/legalReference/station/@externalStationName))"/>
                </xsl:if>
                thence along an arc
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="@rotationDirection = 'cw'"> to the right, </xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'"> to the left, </xsl:if>
                having a radius of
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>,
                the chord of which is
                <xsl:value-of select="inr:fullDirectionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                for a distance of
                <xsl:value-of select="inr:distanceFormat(number(@chord), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>,
                <xsl:if test="End/legalReference">
                    to a point
                    <xsl:if test="End/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="End/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="End/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/legalReference/station/@externalStationName))"/>
                </xsl:if>
            </xsl:when>
            <xsl:when test="position() = last()">
                thence along an arc
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="@rotationDirection = 'cw'"> to the right, </xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'"> to the left, </xsl:if>
                having a radius of
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>,
                the chord of which is
                <xsl:value-of select="inr:fullDirectionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                for a distance of
                <xsl:value-of select="inr:distanceFormat(number(@chord), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="../../@area > 0"> and the POINT OF BEGINNING.</xsl:if>
            </xsl:when>
            <xsl:otherwise>
                thence along an arc
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="@rotationDirection = 'cw'"> to the right, </xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'"> to the left, </xsl:if>
                having a radius of
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>,
                the chord of which is
                <xsl:value-of select="inr:fullDirectionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                for a distance of
                <xsl:value-of select="inr:distanceFormat(number(@chord), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>,
                <xsl:if test="position() = last()"> and the POINT OF BEGINNING.</xsl:if>
                <xsl:if test="End/legalReference">
                    to a point
                    <xsl:if test="End/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="End/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="End/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/legalReference/station/@externalStationName))"/>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Alignment Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <xsl:choose>
            <xsl:when test="position() = 1">
                Beginning at a point
                <xsl:if test="Start/legalReference">
                    <xsl:if test="Start/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(Start/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="Start/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - Start/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="Start/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="Start/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="Start/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(Start/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/legalReference/station/@externalStationName))"/>
                </xsl:if>
                thence along a spiral
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="@rotationDirection = 'cw'"> to the right, </xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'"> to the left, </xsl:if>
                the chord of which is <xsl:value-of select="inr:fullDirectionFormat(number(@chordDirection), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                for a distance of
                <xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>,
                <xsl:if test="End/legalReference">
                    to a point
                    <xsl:if test="End/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="End/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="End/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/legalReference/station/@externalStationName))"/>
                </xsl:if>
            </xsl:when>
            <xsl:when test="position() = last()">
                thence along a spiral
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="@rotationDirection = 'cw'"> to the right, </xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'"> to the left, </xsl:if>
                the chord of which is <xsl:value-of select="inr:fullDirectionFormat(number(@chordDirection), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                for a distance of
                <xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>,
                <xsl:if test="End/legalReference">
                    to a point
                    <xsl:if test="End/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="End/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="End/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/legalReference/station/@externalStationName))"/>
                </xsl:if>
                <xsl:if test="../../@area > 0"> and the POINT OF BEGINNING.</xsl:if>
            </xsl:when>
            <xsl:otherwise>
                thence along a spiral
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="@rotationDirection = 'cw'"> to the right, </xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'"> to the left, </xsl:if>
                the chord of which is <xsl:value-of select="inr:fullDirectionFormat(number(@chordDirection), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                for a distance of
                <xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>,
                <xsl:if test="position() = last()"> and the POINT OF BEGINNING.</xsl:if>
                <xsl:if test="End/legalReference">
                    to a point
                    <xsl:if test="End/legalReference/@offset >= 0">
                        <xsl:value-of select="inr:distanceFormat(number(End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0">
                        <xsl:value-of select="inr:distanceFormat(number(0 - End/legalReference/@offset), $xslDistancePrecision)"/>
                    </xsl:if>
                    <xsl:value-of select="$unit"/>
                    <xsl:if test="End/legalReference/@offset >= 0"> right </xsl:if>
                    <xsl:if test="End/legalReference/@offset &lt; 0"> left </xsl:if>
                    of <xsl:value-of select="End/legalReference/@referenceAlignment"/>
                    at Station
                    <xsl:value-of select="inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/legalReference/station/@externalStationName))"/>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Legal Description</em> or the <em>Tools &gt; XML Reports 
                &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                This report works with or without a reference alignment specified in the <em>Reference 
                Alignments &gt; Include</em> field on the <em>Tools &gt; XML Reports &gt; Legal 
                Description</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function sets the format of directional information with
            // North, East, South and West spelled out fully.
            // n - value from XML
            // format - (1 - "ddd^mm'ss.s", 2 - "ddd.ddd")
            // precision - the number of digits after the decimal point
            // mode - (1 - Bearing, 2 - Bearings from North Only,
            //         3 - North Azimuth, 4 - South Azimuth)
            function fullDirectionFormat(n, format, precision, mode, method)
            {
                // Make sure we have a valid number
                if (!isNaN(n))
                {   
                    // this adds 360 to a negative number until it
                    // becomes positive
                    while (n < 0)
                    {
                        n += (2 * Math.PI);
                    }
                    // this subtracts 360 if the number is greater
                    // than 360
                    while (n >= (2 * Math.PI))
                    {
                        n -= (2 * Math.PI);
                    }
                    
                    //mode 1 - Bearing, mode 2 - North Bearing
                    if (mode == 1 || mode == 2)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        
                        //identifies the quadrant
                        if (decdeg <= 90)
                        {
                            var strAngle = angularFormat(n, format, precision, method);
                            return "North " + strAngle + " East";
                        }
                        //identifies the quadrant
                        if (90 < decdeg && decdeg <= 180)
                        {
                            n = Math.PI - n;
                            var strAngle = angularFormat(n, format, precision, method);
                            if(mode == 1)
                            {
                                return "South " + strAngle + " East";
                            }
                            else
                            {
                                return "North " + strAngle + " West";
                            }
                        }
                        //identifies the quadrant 
                        if (180 < decdeg && decdeg < 270)
                        {
                            n -= Math.PI;
                            var strAngle = angularFormat(n, format, precision, method);
                            if(mode == 1)
                            {
                                return "South " + strAngle + " West";
                            }
                            else
                            {
                                return "North " + strAngle + " East";
                            }
                        }
                        //identifies the quadrant
                        if (270 <= decdeg && decdeg < 360)
                        {
                            n = (2.0 * Math.PI) - n;
                            var strAngle = angularFormat(n, format, precision, method);
                            return "North " + strAngle + " West";
                        }
                    }
                    // mode 3 - North Azimuth
                    if (mode == 3)
                    {
                        var strAngle = angularFormat(n, format, precision, method);
                        return strAngle;
                    }
                    // mode 4 - South Azimuth
                    if (mode == 4)
                    {
                        n = n + Math.PI;
                        if ( n >= (2.0 * Math.PI) )
                        {
                            n = n - (2.0 * Math.PI);
                        }
                        var strAngle = angularFormat(n, format, precision, method);
                        return strAngle;
                     }
                }
                return "";
             }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
