<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!--GENIO Cross Section String-->
    <xsl:variable name="uniqueStations" select="//StationOffsetPoint/centerLinePoint/point/station[not(@internalStation = preceding-sibling::centerLinePoint/point/station/@internalStation)]/@internalStation"/>
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <xsl:for-each select="GeometryProject">
                        <xsl:text/>
                        <xsl:text>MOSS&#xd;</xsl:text>
                        <xsl:for-each select="HorizontalAlignment">
                            <xsl:text>GENIO,XS</xsl:text><xsl:value-of select="@name"/><xsl:text>,DESIGN&#xd;</xsl:text>
                            <xsl:text>082,</xsl:text><xsl:value-of select="@name"/><xsl:text>,,T&#xd;</xsl:text>
                            <xsl:for-each select="$uniqueStations">
                                <xsl:variable name="countAtStation" select="count(//StationOffsetPoint[centerLinePoint/point/station/@internalStation=current()])"/>
                                <xsl:value-of select="format-number(., '#####0.000')"/><xsl:text> &#xa0; &#xa0;</xsl:text><xsl:value-of select="format-number($countAtStation, '#0')"/><xsl:text>&#xd;</xsl:text>
                                <xsl:for-each select="//StationOffsetPoint[centerLinePoint/point/station/@internalStation=current()]">
                                    <xsl:sort select="@firstOffset" data-type="number"/>
                                    <xsl:if test="not((position() mod 4) - 1)">
                                        <xsl:text>&#xa0; &#xa0; &#xa0; &#xa0; &#xa0;</xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="inr:distanceFormat(number(@firstOffset), $xslDistancePrecision)"/><xsl:text> </xsl:text><xsl:value-of select="inr:elevationFormat(number(offsetPoint/@elevation), $xslElevationPrecision)"/><xsl:text> &#xd;</xsl:text>
                                </xsl:for-each>
                            </xsl:for-each>
                            <xsl:text>999999.999&#xd;</xsl:text>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must create station offset points for this report&#xd;</xsl:text>
        <xsl:text>    by selecting either Tools &gt; XML Reports &gt; Station Base&#xd;</xsl:text>
        <xsl:text>    or Tools &gt; XML Reports &gt; Station Offset.  You must&#xd;</xsl:text>
        <xsl:text>    include at least one horizontal alignment or one&#xd;</xsl:text>
        <xsl:text>    feature on the General leaf in the From fields.  You&#xd;</xsl:text>
        <xsl:text>    must also include at least one horizontal alignment on&#xd;</xsl:text>
        <xsl:text>    the Horizontal Alignments leaf or one feature on the&#xd;</xsl:text>
        <xsl:text>    Features leaf.  You must choose at least one option on&#xd;</xsl:text>
        <xsl:text>    the Include leaf (Horizontal On-Alignment Points,&#xd;</xsl:text>
        <xsl:text>    Horizontal Event Points, Vertical On-Alignment Points,&#xd;</xsl:text>
        <xsl:text>    Vertical Event Points or Interval.)&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>

