<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Roadway Visibility ASCII Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <xsl:text/>
                    <xsl:text>Roadway Visibility Report&#xd;&#xd;</xsl:text>
                    <xsl:for-each select="RoadwayVisibility">
                        <xsl:text>Surface(s):          </xsl:text>
                        <xsl:for-each select="VisibilitySurfaces/VisibilitySurface">
                            <xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:for-each select="VisibilityParameters">
                            <xsl:text>Alignment:           </xsl:text>
                            <xsl:value-of select="@alignmentName"/>
                            <xsl:text>&#xd;Start Station:       </xsl:text>
                            <xsl:value-of select="inr:stationFormat(number(StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StartStation/@externalStationName))"/>
                            <xsl:text>&#xd;Stop Station:        </xsl:text>
                            <xsl:value-of select="inr:stationFormat(number(StopStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StopStation/@externalStationName))"/>
                            <xsl:text>&#xd;Interval:            </xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(@interval), $xslDistancePrecision)"/>
                            <xsl:text>&#xd;&#xd;Sight Distance:      </xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(@sightDistance), $xslDistancePrecision)"/>
                            <xsl:text>&#xd;Relaxed Distance:    </xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(@relaxedDistance), $xslDistancePrecision)"/>
                            <xsl:text>&#xd;&#xd;Eye Position:        </xsl:text>
                            <xsl:value-of select="@eyePosition"/>
                            <xsl:text>&#xd;Eye Height:          </xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(@eyeHeight), $xslDistancePrecision)"/>
                            <xsl:text>&#xd;Eye Offset:          </xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(@eyeOffset), $xslDistancePrecision)"/>
                            <xsl:text>&#xd;&#xd;Object Position:     </xsl:text>
                            <xsl:value-of select="@objectPosition"/>
                            <xsl:text>&#xd;Object Height:       </xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(@objectHeight), $xslDistancePrecision)"/>
                            <xsl:text>&#xd;Object Offset:       </xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(@objectOffset), $xslDistancePrecision)"/>
                        </xsl:for-each>
                        <xsl:text>&#xd;&#xd;</xsl:text>
                        <xsl:for-each select="Visibilities/Visibility">
                            <xsl:text>                        Station    Offset     Elevation</xsl:text>
                            <xsl:text>&#xd;Eye Position:        </xsl:text>
                            <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(EyeStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(EyeStation/@externalStationName))), 10)"/>
                            <xsl:value-of select="inr:columnFormat(string(inr:distanceFormat(number(@eyeOffset), $xslDistancePrecision)), 10)"/>
                            <xsl:value-of select="inr:columnFormat(string(inr:elevationFormat(number(@eyeElevation), $xslElevationPrecision)), 14)"/>
                            <xsl:text>&#xd;Object Position:     </xsl:text>
                            <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(ObjectStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(ObjectStation/@externalStationName))), 10)"/>
                            <xsl:value-of select="inr:columnFormat(string(inr:distanceFormat(number(@objectOffset), $xslDistancePrecision)), 10)"/>
                            <xsl:value-of select="inr:columnFormat(string(inr:elevationFormat(number(@objectElevation), $xslElevationPrecision)), 14)"/>
                            <xsl:text>&#xd;Obstruction:         </xsl:text>
                            <xsl:choose>
                                <xsl:when test="@isNoObstruction = 'true'"><xsl:text>  No Obstruction</xsl:text></xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(ObstructionStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(ObstructionStation/@externalStationName))), 10)"/>
                                    <xsl:value-of select="inr:columnFormat(string(inr:distanceFormat(number(@obstructionOffset), $xslDistancePrecision)), 10)"/>
                                    <xsl:value-of select="inr:columnFormat(string(inr:elevationFormat(number(@obstructionElevation), $xslElevationPrecision)), 14)"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:text>&#xd;Sight Distance:      </xsl:text>
                            <xsl:choose>
                                <xsl:when test="@isUnlimited = 'true'"><xsl:text>  Unlimited</xsl:text></xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="inr:columnFormat(string(inr:distanceFormat(number(@sightDistance), $xslDistancePrecision)), 10)"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:text>&#xd;&#xd;</xsl:text>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one surface in the Surfaces&#xd;</xsl:text>
        <xsl:text>    list on the Evaluation &gt; Sight Visibility &gt; Roadway&#xd;</xsl:text>
        <xsl:text>    Visibility command and you must toggle on the Create&#xd;</xsl:text>
        <xsl:text>    XML Report option to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2007 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
