<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Blunder Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Blunder Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <xsl:for-each select="AdjustmentNet">
                                <center>
                                    <!-- Report Title -->
                                    <h2 lang="en">Blunder Report</h2>
                                    <p lang="en">
                                        Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                        Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                    </p>
                                </center>
                                <hr/>
                                <xsl:choose>
                                    <xsl:when test="@adjustmentConverges='true'">
                                        <!-- Observation Data -->
                                        <table class="margin" cellpadding="1" cellspacing="1" width="35%">
                                            <tbody>
                                                <tr>
                                                    <xsl:choose>
                                                        <xsl:when test="@blundersExist='true'">
                                                            <th align="left" lang="en" style="color:FF0000">Possible blunder.</th>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <th align="left" lang="en" style="color:FF0000">No blunder detected.</th>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </tr>
                                                <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                                <tr>
                                                    <th align="left" lang="en" nowrap="nowrap">Reference Standard Deviation:&#xa0; </th>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:distanceFormat(number(@standardDeviation), $xslDistancePrecision)"/>
                                                    </td>
                                                </tr>
                                                <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                                <tr>
                                                    <th align="left" lang="en">Azimuths:&#xa0; </th>
                                                    <td align="right" style="white-space: nowrap">
                                                        <xsl:value-of select="@numberAzimuthObservations"/>
                                                        <xsl:if test="@numberAzimuthObservationsIgnored != 0">
                                                            (<xsl:value-of select="@numberAzimuthObservationsIgnored"/>)
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en" style="white-space: nowrap">Horizontal Angles:&#xa0; </th>
                                                    <td align="right" style="white-space: nowrap">
                                                        <xsl:value-of select="@numberHorizontalAngleObservations"/>
                                                        <xsl:if test="@numberHorizontalAngleObservationsIgnored != 0">
                                                            (<xsl:value-of select="@numberHorizontalAngleObservationsIgnored"/>)
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                                <tr>
                                                    <th align="left" lang="en" style="white-space: nowrap">Vertical Angles:&#xa0; </th>
                                                    <td align="right" style="white-space: nowrap">
                                                        <xsl:value-of select="@numberVerticalAngleObservations"/>
                                                        <xsl:if test="@numberVerticalAngleObservationsIgnored != 0">
                                                            (<xsl:value-of select="@numberVerticalAngleObservationsIgnored"/>)
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en" style="white-space: nowrap">Zenith Angles:&#xa0; </th>
                                                    <td align="right" style="white-space: nowrap">
                                                        <xsl:value-of select="@numberZenithAngleObservations"/>
                                                        <xsl:if test="@numberZenithAngleObservationsIgnored != 0">
                                                            (<xsl:value-of select="@numberZenithAngleObservationsIgnored"/>)
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en" style="white-space: nowrap">Horizontal Distances:&#xa0; </th>
                                                    <td align="right" style="white-space: nowrap">
                                                        <xsl:value-of select="@numberHorizontalDistanceObservations"/>
                                                        <xsl:if test="@numberHorizontalDistanceObservationsIgnored != 0">
                                                            (<xsl:value-of select="@numberHorizontalDistanceObservationsIgnored"/>)
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                                <tr>
                                                    <th align="left" lang="en" style="white-space: nowrap">Slope Distances:&#xa0; </th>
                                                    <td align="right" style="white-space: nowrap">
                                                        <xsl:value-of select="@numberSlopeDistanceObservations"/>
                                                        <xsl:if test="@numberSlopeDistanceObservationsIgnored != 0">
                                                            (<xsl:value-of select="@numberSlopeDistanceObservationsIgnored"/>)
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en" style="white-space: nowrap">Height Differences:&#xa0; </th>
                                                    <td align="right" style="white-space: nowrap">
                                                        <xsl:value-of select="@numberHeightDifferenceObservations"/>
                                                        <xsl:if test="@numberHeightDifferenceObservationsIgnored != 0">
                                                            (<xsl:value-of select="@numberHeightDifferenceObservationsIgnored"/>)
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr><td>&#xa0;</td></tr>
                                                <tr>
                                                    <th align="left" lang="en">Total:&#xa0; </th>
                                                    <td align="right">
                                                        <xsl:value-of select="@totalNumberObservations"/>
                                                        <xsl:if test="@totalNumberObservationsIgnored != 0">
                                                            (<xsl:value-of select="@totalNumberObservationsIgnored"/>)
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                        <hr/>
                                        <table cellpadding="1" cellspacing="1" width="100%">
                                            <thead style="display:table-header-group">
                                                <tr>
                                                    <th class="underline" lang="en" valign="bottom">Type</th>
                                                    <th class="underline" lang="en" valign="bottom">Backsight</th>
                                                    <th class="underline" lang="en" valign="bottom">Occupied</th>
                                                    <th class="underline" lang="en" valign="bottom">Foresight</th>
                                                    <th class="underline" lang="en" valign="bottom">Adjusted<br/>Observation</th>
                                                    <th class="underline" lang="en" valign="bottom">Residual</th>
                                                    <th class="underline" lang="en" valign="bottom">Standardized<br/>Residual</th>
                                                    <th class="underline" lang="en" valign="bottom">Redundancy<br/>Number</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <xsl:for-each select="Observations/Observation/ObservationData">
                                                    <xsl:variable name="style">
                                                        <xsl:choose>
                                                            <xsl:when test="@ignore='true'">
                                                                text-decoration: line-through;
                                                            </xsl:when>
                                                            <xsl:when test="@standardResidual=//@greatestStandardResidual">
                                                                color:FF0000
                                                            </xsl:when>
                                                        </xsl:choose>
                                                    </xsl:variable>
                                                    <tr style="{$style}">
                                                        <td align="center"><xsl:value-of select="../@type"/></td>
                                                        <th>
                                                            <xsl:value-of select="../@backsightPointName"/>
                                                        </th>
                                                        <th>
                                                            <xsl:value-of select="../@occupiedPointName"/>
                                                        </th>
                                                        <th>
                                                            <xsl:value-of select="../@foresightPointName"/>
                                                        </th>
                                                        <xsl:choose>
                                                            <xsl:when test="../@type != 'Horizontal Distance' and ../@type != 'Slope Distance' and ../@type != 'Height Difference'">
                                                                <td align="center">
                                                                    <xsl:value-of select="inr:angularFormat(number(@adjustedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                </td>
                                                                <td align="center">
                                                                    <xsl:value-of select="inr:angularFormat(number(@residual), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                </td>
                                                            </xsl:when>
                                                            <xsl:otherwise>
                                                                <td align="center">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@adjustedValue), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td align="center">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@residual), $xslDistancePrecision)"/>
                                                                </td>
                                                            </xsl:otherwise>
                                                        </xsl:choose>
                                                        <td align="center">
                                                            <xsl:value-of select="inr:distanceFormat(number(@standardResidual), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td align="center">
                                                            <xsl:value-of select="inr:distanceFormat(number(@redundancyNumber), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <tr style="line-height:10%"><td>&#xa0;</td></tr>
                                                </xsl:for-each>
                                            </tbody>
                                        </table>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <p lang="en">
                                            A network least squares solution has not been obtained for the 
                                            active network.&#xa0; Blunder (error ellipse) reporting is 
                                            unavailable.
                                        </p>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have a survey network and you must also have run the <em>Survey &gt; Network &gt; 
                Least Squares Adjustment</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
