<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Level Route Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Level Route Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <xsl:for-each select="AdjustmentNet">
                                <center>
                                    <!-- Report Title -->
                                    <h2 lang="en">Level Route Report</h2>
                                    <p lang="en">
                                        Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                        Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                    </p>
                                </center>
                                <p lang="en" style="text-align:right;font-size:80%">
                                    <strong>Note:&#xa0; </strong>All units in this report are in 
                                    <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                    <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                    unless specified otherwise.
                                </p>
                                <hr/>
                                <!-- Error Anaysis Data -->
                                <xsl:choose>
                                    <xsl:when test="@levelAdjustment = 'true'">
                                        <center><h4>Error Analysis (End Elevation)</h4></center>
                                        <hr size="1px"/>
                                        <table class="margin" cellpadding="1" cellspacing="1" width="50%">
                                            <colgroup span="2">
                                                <col width="50%"/>
                                                <col width="50%"/>
                                            </colgroup>
                                            <xsl:for-each select="LevelPoints">
                                                <tbody>
                                                    <tr>
                                                        <th align="left">Fixed:&#xa0;</th>
                                                        <td>
                                                            <xsl:value-of select="inr:distanceFormat(number(@levelTotalFixed), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <th align="left">Computed:&#xa0;</th>
                                                        <td>
                                                            <xsl:value-of select="inr:distanceFormat(number(@levelTotalComputed), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <th align="left">Error:&#xa0;</th>
                                                        <td>
                                                            <xsl:value-of select="inr:distanceFormat(number(@levelTotalError), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <tr><td>&#xa0;</td></tr>
                                                </tbody>
                                            </xsl:for-each>
                                        </table>
                                        <hr size="1px"/>
                                        <!-- Level Route Data -->
                                        <center><h4>Level Route Data</h4></center>
                                        <hr size="1px"/>
                                        <xsl:if test="@areaDefined != 'false'">
                                            <table class="margin" cellpadding="1" cellspacing="1" width="50%">
                                                <colgroup span="2">
                                                    <col width="50%"/>
                                                    <col width="50%"/>
                                                </colgroup>
                                                <tbody>
                                                    <tr>
                                                        <th align="left">Area:&#xa0;</th>
                                                        <td>
                                                            <xsl:value-of select="inr:areaFormat(number(@area), $xslAreaPrecision)"/> (Sq <xsl:value-of select="//@linearUnits"/>)
                                                            <xsl:if test="@traverseAdjustment='true'">
                                                                , <span style="color:FF0000"><xsl:value-of select="inr:areaFormat(number(@adjustedArea), $xslAreaPrecision)"/> (Sq <xsl:value-of select="//@linearUnits"/>)</span>
                                                            </xsl:if>
                                                        </td>
                                                    </tr>
                                                    <tr><td>&#xa0;</td></tr>
                                                </tbody>
                                            </table>
                                            <br/>
                                        </xsl:if>
                                        <table class="margin" cellpadding="1" cellspacing="3" width="85%">
                                            <xsl:for-each select="LevelPoints">
                                                <thead style="display:table-header-group">
                                                    <tr>
                                                        <th class="underline" align="center" rowspan="2" valign="bottom">Point</th>
                                                        <th class="underline" align="center" rowspan="2" valign="bottom">Horizontal<br/>Distance</th>
                                                        <th class="underline" align="center" rowspan="2" valign="bottom">Height<br/>Difference</th>
                                                        <th align="center" colspan="3" valign="bottom">- - - - - - - Elevation - - - - - - -</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" align="center" valign="bottom">Original</th>
                                                        <th class="underline" align="center" valign="bottom">Adjusted</th>
                                                        <th class="underline" align="center" valign="bottom">Difference</th>
                                                    </tr>
                                                    <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                                </thead>
                                                <xsl:for-each select="LevelPoint">
                                                    <tbody>
                                                        <tr>
                                                            <xsl:call-template name="displayPointName">
                                                                <xsl:with-param name="name" select="@levelPointName"/>
                                                                <xsl:with-param name="type" select="@levelOccupiedType"/>
                                                            </xsl:call-template>
                                                            <td class="sidepad" align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:distanceFormat(number(@levelHorizontalDistance), $xslDistancePrecision)"/>
                                                            </td>
                                                            <td class="sidepad" align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:distanceFormat(number(@levelHeightDifference), $xslDistancePrecision)"/>
                                                            </td>
                                                            <td class="sidepad" align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:distanceFormat(number(@levelUnadjustedElevation), $xslDistancePrecision)"/>
                                                            </td>
                                                            <xsl:choose>
                                                                <xsl:when test="@levelOccupiedType='Fixed'">
                                                                    <td class="sidepad" align="right">---</td>
                                                                    <td class="sidepad" align="right">---</td>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@levelAdjustedElevation), $xslDistancePrecision)"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@levelElevationDifference), $xslDistancePrecision)"/>
                                                                    </td>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </tr>
                                                        <xsl:if test="position() = last()">
                                                            <tr>
                                                                <xsl:call-template name="displayPointName">
                                                                    <xsl:with-param name="name" select="@levelHeightDifferenceForesightName"/>
                                                                    <xsl:with-param name="type" select="@levelForesightType"/>
                                                                </xsl:call-template>
                                                                <td class="sidepad" align="right">---</td>
                                                                <td class="sidepad" align="right">---</td>
                                                                <td class="sidepad" align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@levelOriginalForesightElevation), $xslDistancePrecision)"/>
                                                                </td>
                                                                <xsl:choose>
                                                                    <xsl:when test="@levelForesightType='Fixed'">
                                                                        <td class="sidepad" align="right">---</td>
                                                                        <td class="sidepad" align="right">---</td>
                                                                    </xsl:when>
                                                                    <xsl:otherwise>
                                                                        <td class="sidepad" align="right" nowrap="nowrap">
                                                                            <xsl:value-of select="inr:distanceFormat(number(@levelAdjustedForesightElevation), $xslDistancePrecision)"/>
                                                                        </td>
                                                                        <td class="sidepad" align="right" nowrap="nowrap">
                                                                            <xsl:value-of select="inr:distanceFormat(number(@levelDifferenceForesightElevation), $xslDistancePrecision)"/>
                                                                        </td>
                                                                    </xsl:otherwise>
                                                                </xsl:choose>
                                                            </tr>
                                                        </xsl:if>
                                                        <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                                    </tbody>
                                                </xsl:for-each>
                                                <tr><td>&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </table>
                                        <hr size="1px"/>
                                        <!-- Observation Data -->
                                        <center><h4>Observations</h4></center>
                                        <hr size="1px"/>
                                        <table class="margin" cellpadding="1" cellspacing="1" width="50%">
                                            <colgroup span="2">
                                                <col width="50%"/>
                                                <col width="50%"/>
                                            </colgroup>
                                            <tbody>
                                                <tr>
                                                    <th align="left" nowrap="nowrap">Horizontal Distances:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@numberHorizontalDistanceObservations"/>
                                                        <xsl:if test="@numberHorizontalDistanceObservationsIgnored != '0'"> (
                                                            <xsl:value-of select="@numberHorizontalDistanceObservationsIgnored"/>)
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left">Height Differences:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@numberHeightDifferenceObservations"/>
                                                        <xsl:if test="@numberHeightDifferenceObservationsIgnored != '0'"> (
                                                            <xsl:value-of select="@numberHeightDifferenceObservationsIgnored"/>)
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr><td>&#xa0;</td></tr>
                                            </tbody>
                                        </table>
                                        <br/>
                                        <table class="margin" cellpadding="1" cellspacing="3" width="95%">
                                            <thead style="display:table-header-group">
                                                <tr>
                                                    <th class="underline">Type</th>
                                                    <th class="underline">Occupied</th>
                                                    <th class="underline">Foresight</th>
                                                    <th class="underline">Observation</th>
                                                    <th class="underline">Adjusted</th>
                                                    <th class="underline">Difference</th>
                                                </tr>
                                                <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                            </thead>
                                            <xsl:for-each select="Observations/Observation/ObservationData">
                                                <tbody>
                                                    <tr>
                                                        <td align="center" nowrap="nowrap"><xsl:value-of select="../@type"/></td>
                                                        <th nowrap="nowrap">
                                                            <xsl:value-of select="../@occupiedPointName"/>
                                                        </th>
                                                        <th nowrap="nowrap">
                                                            <xsl:value-of select="../@foresightPointName"/>
                                                        </th>
                                                        <xsl:choose>
                                                            <xsl:when test="../@type != 'Slope Distance' and ../@type != 'Height Difference' and ../@type != 'Horizontal Distance'">
                                                                <td class="sidepad" align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:angularFormat(number(@observedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                </td>
                                                                <td class="sidepad" align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:angularFormat(number(@adjustedValue),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                </td>
                                                                <td class="sidepad" align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:angularFormat(number(@residualValue),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                </td>
                                                            </xsl:when>
                                                            <xsl:otherwise>
                                                                <td class="sidepad" align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@observedValue), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td class="sidepad" align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@adjustedValue), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td class="sidepad" align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@residualValue), $xslDistancePrecision)"/>
                                                                </td>
                                                            </xsl:otherwise>
                                                        </xsl:choose>
                                                    </tr>
                                                    <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                                </tbody>
                                            </xsl:for-each>
                                            <tr><td>&#xa0;</td></tr>
                                        </table>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <p lang="en">
                                            The active network is not a level route.&#xa0; Please use another 
                                            report.
                                        </p>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!--Start Templates-->
    <xsl:template name="displayPointName">
        <xsl:param name="name"/>
        <xsl:param name="type" select="'Fixed'"/>
        <th align="left" nowrap="nowrap">
            <xsl:choose>
                <xsl:when test="$type='Fixed'">
                    <img src="{$xslRootDirectory}/Images/SrvFixed.png" alt="Fixed"/>&#xa0;
                </xsl:when>
                <xsl:when test="$type='Free'">
                    <img src="{$xslRootDirectory}/Images/SrvFree.png" alt="Free"/>&#xa0;
                </xsl:when>
                <xsl:otherwise>
                    <img src="{$xslRootDirectory}/Images/SrvAzimuth.png" alt="Azimuth"/>&#xa0;
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="$name"/>
        </th>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have a survey network and you must also have run the <em>Survey &gt; Network &gt; 
                Level Adjustment</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
