<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Horizontal Element ASCII Tabling -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/HorizontalAnnotationTable">
                    <xsl:text/>
                    <xsl:text>Horizontal Element Tabling&#xd;</xsl:text>
                    <xsl:text>Report Created:  </xsl:text><xsl:value-of select="inr:date()"/><xsl:text> </xsl:text>
                    <xsl:value-of select="inr:time()"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>Input Grid Factor:  </xsl:text><xsl:value-of select="../@inputGridScaleFactor"/>
                    <xsl:text>  Note:  All units in this report are in </xsl:text>
                    <xsl:if test="//@linearUnits = 'Imperial'"><xsl:text>feet</xsl:text></xsl:if>
                    <xsl:if test="//@linearUnits = 'Metric'"><xsl:text>meters</xsl:text></xsl:if>
                    <xsl:text> unless specified otherwise.&#xd;&#xd;&#xd;</xsl:text>
                    <xsl:if test="//TableLine">
                        <xsl:text>                 Line Table&#xd;</xsl:text>
                        <xsl:text>  Name      Length       Direction&#xd;</xsl:text>
                        <xsl:text>--------  ---------  ----------------&#xd;</xsl:text>
                        <xsl:for-each select="TableLine/HorizontalLine">
                            <xsl:variable name="fmtDirection" select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                            <xsl:choose>
                                <xsl:when test="string-length(../@name) &gt; 8">
                                    <xsl:value-of select="substring(@name, 1, 8)"/>
                                </xsl:when>
                                <xsl:when test="string-length(../@name) &lt; 8">
                                    <xsl:value-of select="../@name"/>
                                    <xsl:value-of select="substring('    ', 1, 8 - string-length(../@name))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="../@name"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 11)"/>
                            <xsl:value-of select="inr:columnFormat(string($fmtDirection), 18)"/>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                        <xsl:text>&#xd;&#xd;</xsl:text>
                    </xsl:if>
                    <xsl:if test="TableCircle">    
                        <xsl:text>                                      Curve Table&#xd;</xsl:text>
                        <xsl:text>                        Arc       Chord     Tangent    Middle   External       Chord&#xd;</xsl:text>
                        <xsl:text>  Name      Radius     Length     Length     Length   Ordinate  Distance     Direction&#xd;</xsl:text>
                        <xsl:text>--------  ---------  ---------  ---------  ---------  --------  --------  ----------------&#xd;</xsl:text>
                        <xsl:for-each select="TableCircle/HorizontalCircle">
                            <xsl:variable name="fmtChordDirection" select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                            <xsl:choose>
                                <xsl:when test="string-length(../@name) &gt; 8">
                                    <xsl:value-of select="substring(@name, 1, 8)"/>
                                </xsl:when>
                                <xsl:when test="string-length(../@name) &lt; 8">
                                    <xsl:value-of select="../@name"/>
                                    <xsl:value-of select="substring('    ', 1, 8 - string-length(../@name))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="../@name"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@radius), $xslDistancePrecision, 11)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 11)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@chord), $xslDistancePrecision, 11)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@tangentLength), $xslDistancePrecision, 11)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@middleOrdinate), $xslDistancePrecision, 10)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@externalDistance), $xslDistancePrecision, 10)"/>
                            <xsl:value-of select="inr:columnFormat(string($fmtChordDirection), 18)"/>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                        <xsl:text>&#xd;&#xd;</xsl:text>
                    </xsl:if>
                    <xsl:if test="TableSpiral">
                        <xsl:text>                                              Spiral Table&#xd;</xsl:text>
                        <xsl:text>  Name         Theta      Entrance Radius  Spiral Length   Long Tangent    Xs    Long Chord   P&#xd;</xsl:text>
                        <xsl:text>          Chord Direction   Exit Radius   Spiral Constant Short Tangent    Ys                 Ks&#xd;</xsl:text>
                        <xsl:text>-------- ---------------- --------------- --------------- ------------- -------- ---------- ------&#xd;</xsl:text>
                        <xsl:for-each select="TableSpiral/HorizontalSpiral">
                            <xsl:variable name="fmtTheta" select="inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                            <xsl:variable name="fmtChordDirection" select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                            <xsl:choose>
                                <xsl:when test="string-length(../@name) &gt; 8">
                                    <xsl:value-of select="substring(@name, 1, 8)"/>
                                </xsl:when>
                                <xsl:when test="string-length(../@name) &lt; 8">
                                    <xsl:value-of select="../@name"/>
                                    <xsl:value-of select="substring('        ', 1, 8 - string-length(../@name))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="../@name"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:value-of select="inr:columnFormat(string($fmtTheta), 17)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@startRadius), $xslDistancePrecision, 15)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 16)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@longTangent), $xslDistancePrecision, 15)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@xs), $xslDistancePrecision, 11)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@longChord), $xslDistancePrecision, 10)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@p), $xslDistancePrecision, 8)"/>
                            <xsl:text>&#xd;</xsl:text>
                            <xsl:value-of select="inr:columnFormat(string($fmtChordDirection), 25)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@endRadius), $xslDistancePrecision, 15)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@aConstant), $xslDistancePrecision, 16)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@shortTangent), $xslDistancePrecision, 15)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@ys), $xslDistancePrecision, 11)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@p), $xslDistancePrecision, 18)"/>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                        <xsl:text>&#xd;&#xd;</xsl:text>
                    </xsl:if>
                    <xsl:if test="TablePoint">
                        <xsl:text>                                      Point Table&#xd;</xsl:text>
                        <xsl:text>  Name      Northing       Easting    Elevation  Description       Style&#xd;</xsl:text>
                        <xsl:text>--------  ------------  ------------  ---------  ----------------  ----------------&#xd;</xsl:text>
                        <xsl:for-each select="TablePoint/GeometryPoint">
                            <xsl:choose>
                                <xsl:when test="string-length(../@name) &gt; 8">
                                    <xsl:value-of select="substring(@name, 1, 8)"/>
                                </xsl:when>
                                <xsl:when test="string-length(../@name) &lt; 8">
                                    <xsl:value-of select="../@name"/>
                                    <xsl:value-of select="substring('    ', 1, 8 - string-length(../@name))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="../@name"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@northing), $xslNorthingPrecision, 14)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@easting), $xslEastingPrecision, 14)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), $xslEastingPrecision, 11)"/>
                            <xsl:text> &#xa0;</xsl:text>
                            <xsl:choose>
                                <xsl:when test="string-length(@description) &gt; 16">
                                    <xsl:value-of select="substring(@name, 1, 16)"/>
                                </xsl:when>
                                <xsl:when test="string-length(@description) &lt; 16">
                                    <xsl:value-of select="@description"/>
                                    <xsl:value-of select="substring('                ', 1, 16 - string-length(@description))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="@description"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:text> &#xa0;</xsl:text>
                            <xsl:choose>
                                <xsl:when test="string-length(@style) &gt; 16">
                                    <xsl:value-of select="substring(@name, 1, 16)"/>
                                </xsl:when>
                                <xsl:when test="string-length(@style) &lt; 16">
                                    <xsl:value-of select="@style"/>
                                    <xsl:value-of select="substring('                ', 1, 16 - string-length(@style))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="@style"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                        <xsl:text>&#xd;&#xd;</xsl:text>
                    </xsl:if>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment or&#xd;</xsl:text>
        <xsl:text>    one Cogo point on the Main tab of the Geometry &gt; View&#xd;</xsl:text>
        <xsl:text>    Geometry &gt; Horizontal Annotation command.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must select Assigned or Active in the Apply Style&#xd;</xsl:text>
        <xsl:text>    group and the selected style, regardless of whether it&#xd;</xsl:text>
        <xsl:text>    is the assigned style or the active, must have the&#xd;</xsl:text>
        <xsl:text>    Allow Tabling option toggled on for the element type&#xd;</xsl:text>
        <xsl:text>    you wish to table.  For example, if you wish to table&#xd;</xsl:text>
        <xsl:text>    spirals, select the Tools &gt; Style Manager command and&#xd;</xsl:text>
        <xsl:text>    find your style.  Select the Edit button and navigate&#xd;</xsl:text>
        <xsl:text>    to the Geometry Feature &gt; Spirals &gt; Alternate leaf and&#xd;</xsl:text>
        <xsl:text>    toggle on the Allow Tabling option.  Do this for each&#xd;</xsl:text>
        <xsl:text>    element type in each feature style that you plan to&#xd;</xsl:text>
        <xsl:text>    table.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must select either Basic Element Information or All&#xd;</xsl:text>
        <xsl:text>    Element Information on the Tabling tab of the Geometry&#xd;</xsl:text>
        <xsl:text>    &gt; View Geometry &gt; Horizontal Annotation command to get&#xd;</xsl:text>
        <xsl:text>    results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>Tips&#xd;&#xd;</xsl:text>
        <xsl:text>    You can place the results of your report into your&#xd;</xsl:text>
        <xsl:text>    MicroStation design file by highlighting the text you&#xd;</xsl:text>
        <xsl:text>    wish to copy in the Report Browser, keying in CTRL+C,&#xd;</xsl:text>
        <xsl:text>    and then keying in CTRL+V in your design file.&#xd;&#xd;</xsl:text>
        <xsl:text>    You may have to edit the text once placed in your&#xd;</xsl:text>
        <xsl:text>    design file to correct the alignment.  You will have&#xd;</xsl:text>
        <xsl:text>    better results if you select a "text only" style sheet&#xd;</xsl:text>
        <xsl:text>    and choose a monospaced font in MicroStation.&#xd;&#xd;</xsl:text>
        <xsl:text>    Also, many of the fonts delivered within the&#xd;</xsl:text>
        <xsl:text>    MicroStation resource file have mapped the degree&#xd;</xsl:text>
        <xsl:text>    symbol (&#xb0;) to something else.  You can either edit the&#xd;</xsl:text>
        <xsl:text>    text and replace whatever it mapped to with the caret&#xd;</xsl:text>
        <xsl:text>    (^), which will then display properly as the degree&#xd;</xsl:text>
        <xsl:text>    symbol, or you can select a standard TrueType font.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
