<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Unique named symbologies -->
    <xsl:variable name="uniqueNamedSymbologies" select="//*/NamedSymbologyName[not (@Name = preceding::NamedSymbologyName/@Name)]/@Name"/>
    <!-- Missing Named Symbologies Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Missing Named Symbologies Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="CivilIni">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Missing Named Symbologies Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <hr/>
                        </xsl:for-each>
                        <table class="margin" cellpadding="1" cellspacing="2" width="90%">
                            <thead style="display:table-header-group">
                                <tr>
                                    <th class="underline" lang="en">Missing Named Symbology</th>
                                    <th class="underline" lang="en">Used By</th>
                                    <th class="underline" lang="en">Type</th>
                                </tr>
                            </thead>
                            <tbody>
                                <xsl:for-each select="$uniqueNamedSymbologies">
                                    <xsl:choose>
                                        <xsl:when test="not(//NamedSymbology/@ItemName = current())">
                                            <xsl:for-each select="//NamedSymbologyName[@Name = current()]">
                                                <tr>
                                                    <td><xsl:value-of select="@Name"/></td>
                                                    <xsl:choose>
                                                        <xsl:when test="ancestor::*[name() = 'FeatureStyleCollection']">
                                                            <td><xsl:value-of select="ancestor::*/@ItemName"/></td>
                                                            <td><xsl:value-of select="name(ancestor::*[@ItemName])"/></td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td><xsl:value-of select="ancestor::*/@ItemName"/></td>
                                                            <td><xsl:value-of select="name(ancestor::*[@ItemName])"/> Preference</td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </tr>
                                            </xsl:for-each>
                                        </xsl:when>
                                        <xsl:otherwise/>
                                    </xsl:choose>
                                </xsl:for-each>
                            </tbody>
                        </table>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must open a Preferences file by selecting <em>File &gt; Open</em> on the <em>Report 
                Browser</em> menu and setting the <em>Files of type</em> field to <em>Preferences 
                (*.xin)</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
