<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Unique span numbers -->
    <xsl:variable name="uniqueSpanNumber" select="//Girders/Girder[not (@startSpan = preceding-sibling::Girder/@startSpan)]/@startSpan"/>
    <!-- Screed Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Screed Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Screed Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="BridgeProject">
                                <table cellpadding="2" class="margin" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Screed Data -->
                                <table class="margin" width="80%">
                                    <xsl:for-each select="BridgeCenterLine">
                                        <tbody>
                                            <xsl:for-each select="$uniqueSpanNumber">
                                                <xsl:if test="../@stopSpan = ../@startSpan">
                                                    <tr>
                                                        <th align="left" colspan="9" lang="en">Span <xsl:value-of select="../@startSpan"/></th>
                                                    </tr>
                                                </xsl:if>
                                                <xsl:if test="../@stopSpan != ../@startSpan">
                                                    <tr>
                                                        <th align="left" colspan="9" lang="en">
                                                            Spans <xsl:value-of select="../@startSpan"/> to <xsl:value-of select="../@stopSpan"/>
                                                        </th>
                                                    </tr>
                                                </xsl:if>
                                                <tr>
                                                    <th class="underline" lang="en" valign="bottom">Station</th>
                                                    <th class="underline" lang="en" valign="bottom">Offset</th>
                                                    <th class="underline" lang="en" valign="bottom">Northing</th>
                                                    <th class="underline" lang="en" valign="bottom">Easting</th>
                                                    <th class="underline" lang="en" valign="bottom">Top of<br/>Slab</th>
                                                    <th class="underline" lang="en" valign="bottom">Screed<br/>Elevation</th>
                                                    <th class="underline" lang="en" valign="bottom">Delta</th>
                                                </tr>
                                                <xsl:for-each select="//Girder[@startSpan = current()]">
                                                    <tr>
                                                        <td align="left" colspan="7" lang="en">
                                                            <strong>Girder:&#xa0; </strong>
                                                            <xsl:value-of select="@name"/>
                                                            <strong>&#xa0; Type:&#xa0; </strong>
                                                            <xsl:value-of select="@type"/>
                                                        </td>
                                                    </tr>
                                                    <xsl:for-each select="*/ScreedElevations/ScreedElevation">
                                                        <tr>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:stationFormat(number(station/@externalStation), $xslStationFormat, $xslStationPrecision, string(@externalStationName))"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:distanceFormat(number(@offset), $xslDistancePrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@topOfSlabElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@screedElevation), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@screed), $xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                    </xsl:for-each>
                                                    <tr><td>&#xa0;</td></tr>
                                                </xsl:for-each>
                                                <tr><td>&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                Your active alignment must be a bridge alignment and you must have created slab fascia, 
                abutments/piers, bearing lines, girders and verticals for the bridge.
            </p>
            <p class="normal1" lang="en">
                You must specify the <em>Bridge Surface</em> on the <em>Main</em> tab of the <em>Bridge 
                &gt; Bridge Reports</em> command.&#xa0; You must also toggle on the <em>Include Screed 
                Elevations </em> option on the <em>Screed Elevations</em> tab to get results from this 
                report.
            </p>
            <p class="normal1" lang="en">An alternate alignment is required for a complete report.</p>
            <p class="normal1" lang="en">This report is not suitable for U-Beams.</p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
