<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Cant List Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Cant List Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Cant List Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!--Project Data-->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor"/>
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <xsl:for-each select="HorizontalAlignment[*/CantAlignment]">
                                    <table class="margin" cellpadding="1">
                                        <tr>
                                            <th align="right" lang="en"><br/>Horizontal Alignment:&#xa0; </th>
                                            <td align="left" valign="bottom"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Horizontal Description:&#xa0; </th>
                                            <td align="left"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Horizontal Style:&#xa0; </th>
                                            <td align="left"><xsl:value-of select="@style"/></td>
                                        </tr>
                                        <!-- Cant Point Data -->
                                        <xsl:for-each select="Superelevation/CantAlignment[Cant/CantPoint]">
                                            <tr>
                                                <xsl:choose>
                                                    <xsl:when test="//@linearUnits = 'Imperial'">
                                                        <th class="underline" lang="en" valign="bottom">Station</th>
                                                        <th class="underline" lang="en" valign="bottom">Cant<br/>(in)</th>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <th class="underline" lang="en" valign="bottom">Station</th>
                                                        <th class="underline" lang="en" valign="bottom">Cant<br/>(mm)</th>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </tr>
                                            <xsl:for-each select="Cant[position() != last()]">
                                                <xsl:for-each select="CantPoint">
                                                    <tr>
                                                        <td align="right" style="white-space:nowrap;">
                                                            <xsl:value-of select="inr:stationFormat(number(GeometryPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(GeometryPoint/station/@externalStationName))"/>
                                                        </td>
                                                        <xsl:choose>
                                                            <xsl:when test="@leftCant != 0">
                                                                <xsl:choose>
                                                                    <xsl:when test="//@linearUnits = 'Imperial'">
                                                                        <td align="right">
                                                                            <xsl:value-of select="inr:distanceFormat(number(@leftCant * 12), $xslDistancePrecision)"/>
                                                                        </td>
                                                                    </xsl:when>
                                                                    <xsl:otherwise>
                                                                        <td align="right">
                                                                            <xsl:value-of select="inr:distanceFormat(number(@leftCant * 1000), $xslDistancePrecision)"/>
                                                                        </td>
                                                                    </xsl:otherwise>
                                                                </xsl:choose>
                                                            </xsl:when>
                                                            <xsl:when test="@rightCant != 0">
                                                                <xsl:choose>
                                                                    <xsl:when test="//@linearUnits = 'Imperial'">
                                                                        <td align="right">
                                                                            <xsl:value-of select="inr:distanceFormat(number(@rightCant * 12), $xslDistancePrecision)"/>
                                                                        </td>
                                                                    </xsl:when>
                                                                    <xsl:otherwise>
                                                                        <td align="right">
                                                                            <xsl:value-of select="inr:distanceFormat(number(@rightCant * 1000), $xslDistancePrecision)"/>
                                                                        </td>
                                                                    </xsl:otherwise>
                                                                </xsl:choose>
                                                            </xsl:when>
                                                            <xsl:otherwise>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number(0), $xslDistancePrecision)"/>
                                                                </td>
                                                            </xsl:otherwise>
                                                        </xsl:choose>
                                                    </tr>
                                                </xsl:for-each>
                                            </xsl:for-each>
                                        </xsl:for-each>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command.
            </p>
            <p class="normal1" lang="en">
                You must also toggle on the <em>Include Cant Alignments</em> option and select either 
                <em>All</em> or <em>Active</em> to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2009 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
