<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Feature Clearance Report -->
    <xsl:key name="featureName" match="ClearancePoint" use="@clearanceAlignmentName"/>
    <xsl:variable name="surfaceFile">site.xml</xsl:variable>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Feature Clearance Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Feature Clearance Report</h2>
                                <p lang="en">
                                    Report Created: &#xa0;<xsl:value-of select="inr:date()"/><br/>
                                    Time: &#xa0;<xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr />
                                <!-- Clearance Point Data -->
                                <xsl:for-each select="HorizontalAlignment">
                                    <table width="90%">
                                        <tbody>
                                            <xsl:for-each select="//ClearancePoint[generate-id() = generate-id(key('featureName', @clearanceAlignmentName)[1])]">
                                                <xsl:variable name="curFtr" select="@clearanceAlignmentName"/>
                                                <tr>
                                                    <xsl:for-each select="document($surfaceFile)">
                                                        <td valign="bottom"><br /><xsl:value-of select="//Surface[Features/Feature/@name = $curFtr]/@name"/></td>
                                                    </xsl:for-each>
                                                    <td align="right" valign="bottom"><xsl:value-of select="@clearanceAlignmentName"/></td>
                                                    <xsl:for-each select="document($surfaceFile)">
                                                        <td align="right" valign="bottom"><xsl:value-of select="//Feature[@name = $curFtr]/@style"/></td>
                                                        <td align="right" valign="bottom"><xsl:value-of select="inr:distanceFormat(number(//Feature[@name = $curFtr]/@length), $xslDistancePrecision)"/></td>
                                                        <td align="right" valign="bottom"><xsl:value-of select="//Feature[@name = $curFtr]/@numberPoints"/></td>
                                                    </xsl:for-each>
                                                    <td align="right" valign="bottom"><xsl:value-of select="../../@name"/></td>
                                                </tr>
                                                <xsl:for-each select="key('featureName', @clearanceAlignmentName)">
                                                    <tr>
                                                        <td><xsl:value-of select="position()"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(offsetPoint/@easting), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(offsetPoint/@northing), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(offsetPoint/@elevation), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right" nowrap="nowrap">
                                                            <xsl:value-of select="inr:stationFormat(number(centerLinePoint/point/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(centerLinePoint/point/station/@externalStationName))"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@firstOffset), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                </xsl:for-each>
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Workflow</h4>
            <p class="normal1" lang="en">
                This workflow requires a horizontal alignment or feature as the active alignment, and a
                surface containing one or more features to be reported.
            </p>
            <ol>
                <li class="list1number" lang="en">
                    On the <em>General</em> leaf of the <em>Tools &gt; XML Reports &gt; Clearance</em> 
                    command, select the horizontal alignment or feature that represents your active 
                    alignment in the <em>From</em> group.&#xa0; Select the features you wish to include in 
                    the report on the <em>Features</em> leaf and select <em>Apply</em>.
                </li>
                <li class="list1number" lang="en">
                    When the report is displayed in the <em>Report Browser</em>, select the <span 
                    class="directory">raw-xml.xsl</span> style sheet in the root directory and save the XML 
                    data file.
                </li>
                <li class="list1number" lang="en">
                    Select the <em>Tools &gt; XML Reports &gt; Surfaces</em> command and choose the same 
                    surface and features as you chose in the first step.&#xa0; Toggle on the <em>Include 
                    Feature Points</em> option and select <em>Apply</em>.
                </li>
                <li class="list1number" lang="en">
                    When the report is displayed in the <em>Report Browser</em>, select the <span 
                    class="directory">raw-xml.xsl</span> style sheet in the root directory and save the XML 
                    data file to the same location as the previous file, giving it the name <span 
                    class="directory">site.xml</span>.<br/><br style="line-height:50%"/>
                    <strong>Note:</strong>&#xa0; This style sheet is looking for a surface XML data file 
                    called <span class="directory">site.xml</span>.&#xa0; If you decide to name your file 
                    something different, you must change the value in the <code>surfaceFile</code> variable 
                    near the top of the style sheet.
                </li>
                <li class="list1number" lang="en">
                    In the <em>Report Browser</em>, select <em>File &gt; Open</em> and select the first XML 
                    data file which you created in Step 2.&#xa0; Select <span class="directory">Custom/
                    FeatureClearance.xsl</span> as the style sheet, and your report will now be displayed.
                </li>
            </ol>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
