<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:variable name="pi" select="inr:setPI()"/>
    <!-- Variable to hold unit string -->
    <xsl:variable name="unit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'"> feet</xsl:when>
            <xsl:otherwise> meters</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Georgia DOT Deed Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject/HorizontalAlignment">
                    <xsl:text/>
                    <xsl:text>LIST </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;&#xd;&#xd;</xsl:text>
                    <xsl:text> </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;&#xd;&#xd;</xsl:text>
                    <xsl:text>-----------------------------------------------------------------&#xd;</xsl:text>
                    <xsl:text>    LAYOUT POINTS FROM CHAIN </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>  TO                    OFFSET&#xd;</xsl:text>
                    <xsl:text> POINT    STATION      DISTANCE&#xd;</xsl:text>
                    <xsl:text> ------ ------------  ----------&#xd;</xsl:text>
                    <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(HorizontalElements/*[1]/Start/legalReference/station/@externalStation), $xslStationFormat, 2, string(HorizontalElements/*[1]/Start/legalReference/station/@externalStationName))), 18)"/>
                    <xsl:choose>
                        <xsl:when test="//legalReference">
                            <xsl:choose>
                                <xsl:when test="HorizontalElements/*[1]/Start/legalReference/@offset &lt; 0.0">
                                    <xsl:value-of select="inr:columnDoubleFormat(number(-1 * HorizontalElements/*[1]/Start/legalReference/@offset), 2, 13)"/>
                                    <xsl:text>L</xsl:text>
                                </xsl:when>
                                <xsl:when test="HorizontalElements/*[1]/Start/legalReference/@offset &gt; 0.0">
                                    <xsl:value-of select="inr:columnDoubleFormat(number(HorizontalElements/*[1]/Start/legalReference/@offset), 2, 13)"/>
                                    <xsl:text>R</xsl:text>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="inr:columnDoubleFormat(number(HorizontalElements/*[1]/Start/legalReference/@offset), 2, 13)"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text>&#xd;*** This report is invalid since no reference alignment was selected. ***&#xd;</xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:text>&#xd;&#xd;</xsl:text>
                    <xsl:text> DESCRIPTION OF </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;;</xsl:text>
                    <xsl:for-each select="HorizontalElements">
                        <xsl:apply-templates/>
                    </xsl:for-each>
                    <xsl:text>&#xd;</xsl:text>
                    <xsl:if test="@area &gt; 0.0">
                        <xsl:text>Containing </xsl:text>
                        <xsl:if test="//@linearUnits = 'Imperial'">
                            <xsl:value-of select="inr:acreFormat(number(@area div 43560), 3)"/>
                            <xsl:text> acres more or less.&#xd;</xsl:text>
                        </xsl:if>
                        <xsl:if test="//@linearUnits = 'Metric'">
                            <xsl:value-of select="inr:acreFormat(number(@area div 10000), 3)"/>
                            <xsl:text> hectares more or less.&#xd;</xsl:text>
                        </xsl:if>
                    </xsl:if>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine">
        <xsl:choose>
            <xsl:when test="position() = last()">
                <xsl:text> thence </xsl:text>
                <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, 1, $xslDirectionModeFormat, $xslAngularMethod)"/>
                <xsl:text> a distance of </xsl:text>
                <xsl:value-of select="inr:distanceFormat(number(@length), 2)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="../../@area &gt; 0">
                    <xsl:text> back to the point of beginning</xsl:text>
                </xsl:if>
                <xsl:text>.</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test="position() = 1">
                    <xsl:text> running</xsl:text>
                </xsl:if>
                <xsl:text> thence </xsl:text>
                <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, 1, $xslDirectionModeFormat, $xslAngularMethod)"/>
                <xsl:text> a distance of </xsl:text>
                <xsl:value-of select="inr:distanceFormat(number(@length), 2)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="End/legalReference">
                    <xsl:text> to a point </xsl:text>
                    <xsl:choose>
                        <xsl:when test="End/legalReference/@offset &lt; 0">
                            <xsl:value-of select="inr:distanceFormat(number(-1 * End/legalReference/@offset), 2)"/>
                            <xsl:value-of select="$unit"/>
                            <xsl:text> left of and opposite station </xsl:text>
                        </xsl:when>
                        <xsl:when test="End/legalReference/@offset &gt; 0">
                            <xsl:value-of select="inr:distanceFormat(number(End/legalReference/@offset), 2)"/>
                            <xsl:value-of select="$unit"/>
                            <xsl:text> right of and opposite station </xsl:text>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text> at station </xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:value-of select="inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, 2, string(End/legalReference/station/@externalStationName))"/>
                    <xsl:text> on said construction centerline laid out for </xsl:text>
                    <xsl:choose>
                        <xsl:when test="End/legalReference/@referenceAlignmentDescription">
                            <xsl:value-of select="End/legalReference/@referenceAlignmentDescription"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="End/legalReference/@referenceAlignment"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:text>;</xsl:text>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:choose>
            <xsl:when test="position() = last()">
                <xsl:text> thence </xsl:text>
                <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, 1, $xslDirectionModeFormat, $xslAngularMethod)"/>
                <xsl:text> a distance of </xsl:text>
                <xsl:value-of select="inr:distanceFormat(number(@length), 2)"/>
                <xsl:value-of select="$unit"/>
                <xsl:if test="../../@area &gt; 0">
                    <xsl:text> back to the point of beginning</xsl:text>
                </xsl:if>
                <xsl:text>.</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test="position() = 1">
                    <xsl:text> running</xsl:text>
                </xsl:if>
                <xsl:text> thence </xsl:text>
                <xsl:choose>
                    <xsl:when test="@tangentialDirectionStart &gt; 0.0 and @tangentialDirectionStart &lt; 0.5 * $pi">
                        <xsl:text>northeasterly </xsl:text>
                    </xsl:when>
                    <xsl:when test="@tangentialDirectionStart = 0.5 * $pi">
                        <xsl:text>easterly </xsl:text>
                    </xsl:when>
                    <xsl:when test="@tangentialDirectionStart &gt; 0.5 * $pi and @tangentialDirectionStart &lt; $pi">
                        <xsl:text>southeasterly </xsl:text>
                    </xsl:when>
                    <xsl:when test="@tangentialDirectionStart &gt; $pi and @tangentialDirectionStart &lt; 1.5 * $pi">
                        <xsl:text>southwesterly </xsl:text>
                    </xsl:when>
                    <xsl:when test="@tangentialDirectionStart = 1.5 * $pi">
                        <xsl:text>westerly </xsl:text>
                    </xsl:when>
                    <xsl:when test="@tangentialDirectionStart &gt; 1.5 * $pi and @tangentialDirectionStart &lt; 2.0 * $pi">
                        <xsl:text>northwesterly </xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>northerly </xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:value-of select="inr:distanceFormat(number(@length), 2)"/>
                <xsl:value-of select="$unit"/>
                <xsl:text> along the arc of a curve (said curve having a radius of </xsl:text>
                <xsl:value-of select="inr:distanceFormat(number(@radius), 2)"/>
                <xsl:value-of select="$unit"/>
                <xsl:text> and a chord distance of </xsl:text>
                <xsl:value-of select="inr:distanceFormat(number(@chord), 2)"/>
                <xsl:value-of select="$unit"/>
                <xsl:text> on a bearing of </xsl:text>
                <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, 1, $xslDirectionModeFormat, $xslAngularMethod)"/>
                <xsl:text>)</xsl:text>
                <xsl:if test="End/legalReference">
                    <xsl:text> to the point </xsl:text>
                    <xsl:choose>
                        <xsl:when test="End/legalReference/@offset &lt; 0">
                            <xsl:value-of select="inr:distanceFormat(number(-1 * End/legalReference/@offset), 2)"/>
                            <xsl:value-of select="$unit"/>
                            <xsl:text> left of and opposite station </xsl:text>
                        </xsl:when>
                        <xsl:when test="End/legalReference/@offset &gt; 0">
                            <xsl:value-of select="inr:distanceFormat(number(End/legalReference/@offset), 2)"/>
                            <xsl:value-of select="$unit"/>
                            <xsl:text> right of and opposite station </xsl:text>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text> at station </xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:value-of select="inr:stationFormat(number(End/legalReference/station/@externalStation), $xslStationFormat, 2, string(End/legalReference/station/@externalStationName))"/>
                    <xsl:text> on said construction centerline laid out for </xsl:text>
                    <xsl:choose>
                        <xsl:when test="End/legalReference/@referenceAlignmentDescription">
                            <xsl:value-of select="End/legalReference/@referenceAlignmentDescription"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="End/legalReference/@referenceAlignment"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:text>;</xsl:text>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include only one horizontal alignment in the&#xd;</xsl:text>
        <xsl:text>    Include field on the Tools &gt; XML Reports &gt; Legal&#xd;</xsl:text>
        <xsl:text>    Description command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    This report requires at least one reference alignment&#xd;</xsl:text>
        <xsl:text>    to be specified in the Reference Alignments &gt; Include&#xd;</xsl:text>
        <xsl:text>    field on the Tools &gt; XML Reports &gt; Legal Description&#xd;</xsl:text>
        <xsl:text>    command for a complete report.  Reference alignment(s)&#xd;</xsl:text>
        <xsl:text>    must contain descriptions.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2007 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function sets the format of angular information.  It is copied here from format.xsl so 
            // that the degrees symbol can be output as "^".
            // n - value from xml
            // format - (1 - "ddd^mm'ss.s", 2 - "ddd.ddd")
            // formatMethod - (1 - Degrees, 2 - Grads, 3 - Radians, 4 - Mils)
            // precision - the number of digits after the decimal point
            function angularFormat(n, format, precision, formatMethod)
            {
                // Checking to see if the number is valid
                if(!isNaN(n))
                {
                    // converts from Radians to Degrees and formats the value
                    if(formatMethod == 1)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        // format 1 - this converts the number to "ddd^mm'ss.s"
                        if(format == 1)
                        {
                            // takes only the whole number (ddd)
                            deg = Math.floor(Math.abs(decdeg));
                            // multiplies the decimal portion time 60 to get the minutes
                            var decmin = (Math.abs(decdeg) - deg) * 60;
                            // takes only the whole part of that number (mm')
                            var min = Math.floor(decmin);
                            // multiplies the decimal portion time 60 to get the seconds.
                            var decsec = (decmin - min) * 60;
                            // this calls the function that gives the number the correct precision
                            var str = formatNumber(decsec, precision);
                            if(str.substring(0, 2) == "60")
                            {
                                decsec = 0;
                                str = formatNumber(decsec, precision);
                                min = min+1;
                                if(min == 60)
                                {
                                    min = 0;
                                    deg = deg + 1;
                                }
                            }
                            if(min < 10)
                            {
                                min = "0" + min;
                            }
                            var sec = str;
                            if(sec < 10)
                            {
                                sec = "0" + sec;
                            }
                            var msg;
                            if(decdeg >= 0 || decdeg <= -1)
                            {
                                if(decdeg < 0)
                                    msg =  "-" + deg + "^" + min + "'" + sec + '"';
                                else
                                    msg =  deg + "^" + min + "'" + sec + '"';
                            }
                            else
                                msg =  "-0" + "^" + min + "'" + sec + '"';
                            return msg;
                        }
                        // format 2 - "ddd.ddd"
                        if(format == 2)
                        {
                            // this calls the function that gives the number the correct precision
                            var str = formatNumber(decdeg, precision);
                            str = str + "^";
                            return str;
                        }
                    }
                    //converts Radians to Grads
                    if(formatMethod == 2)
                    {
                        var radtograd = (n * 200) / Math.PI;
                        var grad = formatNumber(radtograd, precision);
                        if (gradSuffix == true)
                        {
                            grad = grad + "g";
                        }
                        return grad;
                    }
                    // value in Radians needs to be formated
                    if(formatMethod == 3)
                    {
                        // this calls the function that gives the number the correct precision
                        var radian = formatNumber(n, precision);
                        if(radSuffix == true)
                        {
                            radian = radian + "r";
                        }
                        return radian;
                    }
                    //converts Radians to Mils
                    if(formatMethod == 4 )
                    {
                         var radtomils = n * (6400.0 / (2.0 * Math.PI));
                         var mils = formatNumber(radtomils, precision);
                         return mils;
                    }
                }
                return NaN;
             }
            function setPI()
            {
                var strPI = Math.PI;
                return strPI;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
