<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- GDOT Surface Check Report -->
    <xsl:template match="/">
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!--Title displayed in browser Title Bar-->
                <title lang="en">GDOT Surface Check Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!--Report Title-->
                                <h2 lang="en">GDOT Surface Check Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="Surfaces/Surface">
                                <table class="margin" cellpadding="2" width="95%">
                                    <thead style="display:table-header-group">
                                        <tr>
                                            <td>
                                                <table width="55%">
                                                <tr>
                                                    <th align="left" lang="en">Project Units</th>
                                                    <th align="left"><xsl:value-of select="../../@linearUnits"/></th>
                                                    <th align="left" lang="en">TOL1=</th>
                                                    <th align="left">
                                                        <xsl:value-of select="inr:elevationFormat(number(DTMCheckPoints/DTMCheckPointSummary/@tolerance1), $xslElevationPrecision)"/>
                                                    </th>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en">DTM Name</th>
                                                    <th align="left"><xsl:value-of select="@name"/></th>
                                                    <th align="left" lang="en">TOL2=</th>
                                                    <th align="left">
                                                        <xsl:value-of select="inr:elevationFormat(number(DTMCheckPoints/DTMCheckPointSummary/@tolerance2), $xslElevationPrecision)"/>
                                                    </th>
                                                </tr>
                                                <tr>
                                                    <th colspan="4">&#xa0;</th>
                                                </tr>
                                                </table>
                                            </td>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <td colspan="4">
                                                <table border="1" cellpadding="1" cellspacing="0" width="100%">
                                                    <colgroup>
                                                        <col width="10%"/>
                                                        <col width="10%"/>
                                                        <col width="10%"/>
                                                        <col width="10%"/>
                                                        <col width="10%"/>
                                                        <col width="10%"/>
                                                        <col width="10%"/>
                                                        <col width="10%"/>
                                                        <col width="10%"/>
                                                        <col width="10%"/>
                                                    </colgroup>
                                                    <thead style="display:table-header-group">
                                                        <tr style="background-color:silver;">
                                                            <th lang="en">POINT</th>
                                                            <th lang="en">X</th>
                                                            <th lang="en">Y</th>
                                                            <th lang="en">Field Z</th>
                                                            <th lang="en">DTM Z</th>
                                                            <th lang="en">Z Diff</th>
                                                            <th lang="en">Location</th>
                                                            <th lang="en">ABS Value</th>
                                                            <th lang="en">TOL</th>
                                                            <th lang="en">Feature</th>
                                                        </tr>
                                                    </thead>
                                                    <tbody>
                                                        <xsl:for-each select="DTMCheckPoints/DTMCheckPoint">
                                                            <xsl:variable name="style">
                                                                <xsl:choose>
                                                                    <xsl:when test="@inTolerance = 'true'"/>
                                                                    <xsl:otherwise>
                                                                        background-color:aqua;
                                                                    </xsl:otherwise>
                                                                </xsl:choose>
                                                            </xsl:variable>
                                                            <tr style="{$style}">
                                                                <td align="center"><xsl:value-of select="@name"/></td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:elevationFormat(number(@pointZ), $xslElevationPrecision)"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:elevationFormat(number(@surfaceZ), $xslElevationPrecision)"/>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:elevationFormat(number(@zDifference), $xslElevationPrecision)"/>
                                                                </td>
                                                                <td align="center">
                                                                    <xsl:choose>
                                                                        <xsl:when test="@isAbove = 'true'">ABOVE</xsl:when>
                                                                        <xsl:otherwise>BELOW</xsl:otherwise>
                                                                    </xsl:choose>
                                                                </td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:elevationFormat(number(@zDifferenceAbsolute), $xslElevationPrecision)"/>
                                                                </td>
                                                                <td align="center">
                                                                    <xsl:choose>
                                                                        <xsl:when test="@inTolerance = 'true'">IN</xsl:when>
                                                                        <xsl:otherwise>OUT</xsl:otherwise>
                                                                    </xsl:choose>
                                                                </td>
                                                                <td><xsl:value-of select="@style"/></td>
                                                            </tr>
                                                        </xsl:for-each>
                                                    </tbody>
                                                </table>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td colspan="4">&#xa0;</td>
                                        </tr>
                                        <tr>
                                            <td colspan="4">
                                                <xsl:for-each select="DTMCheckPoints/DTMCheckPointSummary">
                                                    <table border="1" cellpadding="1" cellspacing="0" width="100%">
                                                        <colgroup>
                                                            <col width="10%"/>
                                                            <col width="10%"/>
                                                            <col width="10%"/>
                                                            <col width="10%"/>
                                                            <col width="10%"/>
                                                            <col width="10%"/>
                                                            <col width="10%"/>
                                                            <col width="10%"/>
                                                            <col width="10%"/>
                                                            <col width="10%"/>
                                                        </colgroup>
                                                        <tr>
                                                            <th align="left" colspan="10" lang="en">Points Outside of DTM</th>
                                                        </tr>
                                                        <xsl:call-template name="pointsOutsideDTM">
                                                            <xsl:with-param name="list" select="DTMCheckPointsNotOnSurface"/>
                                                        </xsl:call-template>
                                                        <tr>
                                                            <td colspan="10">&#xa0;</td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" colspan="2" lang="en">Total Points Outside</th>
                                                            <th><xsl:value-of select="@nPointsOutsideDTM"/></th>
                                                            <th colspan="8">&#xa0;</th>
                                                        </tr>
                                                    </table>
                                                </xsl:for-each>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td colspan="4">&#xa0;</td>
                                        </tr>
                                        <tr>
                                            <td colspan="4">
                                                <xsl:for-each select="DTMCheckPoints/DTMCheckPointSummary">
                                                    <table border="1" cellpadding="1" cellspacing="0" width="30%">
                                                        <tr>
                                                            <th colspan="3" lang="en">Summary</th>
                                                        </tr>
                                                        <tr>
                                                            <th colspan="3">&#xa0;</th>
                                                        </tr>
                                                        <tr style="background-color:silver;">
                                                            <th>&#xa0;</th>
                                                            <th lang="en">
                                                                Group 1<br/>
                                                                TOL= <xsl:value-of select="inr:elevationFormat(number(@tolerance1), $xslElevationPrecision)"/>
                                                            </th>
                                                            <th lang="en">
                                                                Group 2<br/>
                                                                TOL= <xsl:value-of select="inr:elevationFormat(number(@tolerance2), $xslElevationPrecision)"/>
                                                            </th>
                                                        </tr>
                                                        <tr>
                                                            <th lang="en">Points</th>
                                                            <td align="center">
                                                                <xsl:value-of select="@nPointsOfTolerance1"/>
                                                            </td>
                                                            <td align="center">
                                                                <xsl:value-of select="@nPointsOfTolerance2"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th lang="en">In Tol</th>
                                                            <td align="center">
                                                                <xsl:value-of select="@nPointsOfTolerance1InTolerance"/>
                                                            </td>
                                                            <td align="center">
                                                                <xsl:value-of select="@nPointsOfTolerance2InTolerance"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th lang="en">Out of Tol</th>
                                                            <td align="center">
                                                                <xsl:value-of select="number(@nPointsOfTolerance1 - @nPointsOfTolerance1InTolerance)"/>
                                                            </td>
                                                            <td align="center">
                                                                <xsl:value-of select="number(@nPointsOfTolerance2 - @nPointsOfTolerance2InTolerance)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th lang="en">% In Tol</th>
                                                            <td align="center">
                                                                <xsl:value-of select="format-number((@nPointsOfTolerance1InTolerance div @nPointsOfTolerance1) * 100, '0.##')"/>%
                                                            </td>
                                                            <td align="center">
                                                                <xsl:value-of select="format-number((@nPointsOfTolerance2InTolerance div @nPointsOfTolerance2) * 100, '0.##')"/>%
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th lang="en">% Out Tol</th>
                                                            <td align="center">
                                                                <xsl:value-of select="format-number(((@nPointsOfTolerance1 - @nPointsOfTolerance1InTolerance) div @nPointsOfTolerance1) * 100, '0.##')"/>%
                                                            </td>
                                                            <td align="center">
                                                                <xsl:value-of select="format-number(((@nPointsOfTolerance2 - @nPointsOfTolerance2InTolerance) div @nPointsOfTolerance2) * 100, '0.##')"/>%
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th lang="en">Max Above</th>
                                                            <td align="center">
                                                                <xsl:value-of select="inr:elevationFormat(number(@tolerance1MaxAbove), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="center">
                                                                <xsl:value-of select="inr:elevationFormat(number(@tolerance2MaxAbove), $xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th lang="en">Max Below</th>
                                                            <td align="center">
                                                                <xsl:value-of select="inr:elevationFormat(number(@tolerance1MaxBelow), $xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="center">
                                                                <xsl:value-of select="inr:elevationFormat(number(@tolerance2MaxBelow), $xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                </xsl:for-each>
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="pointsOutsideDTM">
        <xsl:param name="list"/>
        <xsl:variable name="listNormal">
            <xsl:value-of select="concat(normalize-space($list), ' ')"/>
        </xsl:variable>
        <xsl:variable name="point1" select="substring-before($listNormal, ' ')"/>
        <xsl:variable name="restAfterPoint1" select="substring-after($listNormal, ' ')"/>
        <tr style="background-color:yellow;">
            <th>
                <xsl:choose>
                    <xsl:when test="$point1"><xsl:value-of select="$point1"/></xsl:when>
                    <xsl:otherwise>&#xa0;</xsl:otherwise>
                </xsl:choose>
            </th>
            <xsl:choose>
                <xsl:when test="$restAfterPoint1">
                    <xsl:variable name="point2" select="substring-before($restAfterPoint1, ' ')"/>
                    <xsl:variable name="restAfterPoint2" select="substring-after($restAfterPoint1, ' ')"/>
                    <th>
                        <xsl:choose>
                            <xsl:when test="$point2"><xsl:value-of select="$point2"/></xsl:when>
                            <xsl:otherwise>&#xa0;</xsl:otherwise>
                        </xsl:choose>
                    </th>
                    <xsl:choose>
                        <xsl:when test="$restAfterPoint2">
                            <xsl:variable name="point3" select="substring-before($restAfterPoint2, ' ')"/>
                            <xsl:variable name="restAfterPoint3" select="substring-after($restAfterPoint2, ' ')"/>
                            <th>
                                <xsl:choose>
                                    <xsl:when test="$point3"><xsl:value-of select="$point3"/></xsl:when>
                                    <xsl:otherwise>&#xa0;</xsl:otherwise>
                                </xsl:choose>
                            </th>
                            <xsl:choose>
                                <xsl:when test="$restAfterPoint3">
                                    <xsl:variable name="point4" select="substring-before($restAfterPoint3, ' ')"/>
                                    <xsl:variable name="restAfterPoint4" select="substring-after($restAfterPoint3, ' ')"/>
                                    <th>
                                        <xsl:choose>
                                            <xsl:when test="$point4"><xsl:value-of select="$point4"/></xsl:when>
                                            <xsl:otherwise>&#xa0;</xsl:otherwise>
                                        </xsl:choose>
                                    </th>
                                    <xsl:choose>
                                        <xsl:when test="$restAfterPoint4">
                                            <xsl:variable name="point5" select="substring-before($restAfterPoint4, ' ')"/>
                                            <xsl:variable name="restAfterPoint5" select="substring-after($restAfterPoint4, ' ')"/>
                                            <th>
                                                <xsl:choose>
                                                    <xsl:when test="$point5"><xsl:value-of select="$point5"/></xsl:when>
                                                    <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                </xsl:choose>
                                            </th>
                                            <xsl:choose>
                                                <xsl:when test="$restAfterPoint5">
                                                    <xsl:variable name="point6" select="substring-before($restAfterPoint5, ' ')"/>
                                                    <xsl:variable name="restAfterPoint6" select="substring-after($restAfterPoint5, ' ')"/>
                                                    <th>
                                                        <xsl:choose>
                                                            <xsl:when test="$point6"><xsl:value-of select="$point6"/></xsl:when>
                                                            <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                        </xsl:choose>
                                                    </th>
                                                    <xsl:choose>
                                                        <xsl:when test="$restAfterPoint6">
                                                            <xsl:variable name="point7" select="substring-before($restAfterPoint6, ' ')"/>
                                                            <xsl:variable name="restAfterPoint7" select="substring-after($restAfterPoint6, ' ')"/>
                                                            <th>
                                                                <xsl:choose>
                                                                    <xsl:when test="$point7"><xsl:value-of select="$point7"/></xsl:when>
                                                                    <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                                </xsl:choose>
                                                            </th>
                                                            <xsl:choose>
                                                                <xsl:when test="$restAfterPoint7">
                                                                    <xsl:variable name="point8" select="substring-before($restAfterPoint7, ' ')"/>
                                                                    <xsl:variable name="restAfterPoint8" select="substring-after($restAfterPoint7, ' ')"/>
                                                                    <th>
                                                                        <xsl:choose>
                                                                            <xsl:when test="$point8"><xsl:value-of select="$point8"/></xsl:when>
                                                                            <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                                        </xsl:choose>
                                                                    </th>
                                                                    <xsl:choose>
                                                                        <xsl:when test="$restAfterPoint8">
                                                                            <xsl:variable name="point9" select="substring-before($restAfterPoint8, ' ')"/>
                                                                            <xsl:variable name="restAfterPoint9" select="substring-after($restAfterPoint8, ' ')"/>
                                                                            <th>
                                                                                <xsl:choose>
                                                                                    <xsl:when test="$point9"><xsl:value-of select="$point9"/></xsl:when>
                                                                                    <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                                                </xsl:choose>
                                                                            </th>
                                                                            <xsl:choose>
                                                                                <xsl:when test="$restAfterPoint9">
                                                                                    <xsl:variable name="point10" select="substring-before($restAfterPoint9, ' ')"/>
                                                                                    <xsl:variable name="restAfterPoint10" select="substring-after($restAfterPoint9, ' ')"/>
                                                                                    <th>
                                                                                        <xsl:choose>
                                                                                            <xsl:when test="$point10"><xsl:value-of select="$point10"/></xsl:when>
                                                                                            <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                                                        </xsl:choose>
                                                                                    </th>
                                                                                    <xsl:if test="$restAfterPoint10">
                                                                                        <xsl:call-template name="pointsOutsideDTM">
                                                                                            <xsl:with-param name="list" select="$restAfterPoint10"/>
                                                                                        </xsl:call-template>
                                                                                    </xsl:if>
                                                                                </xsl:when>
                                                                                <xsl:otherwise>
                                                                                    <th>&#xa0;</th>
                                                                                </xsl:otherwise>
                                                                            </xsl:choose>
                                                                        </xsl:when>
                                                                        <xsl:otherwise>
                                                                            <th>&#xa0;</th>
                                                                            <th>&#xa0;</th>
                                                                        </xsl:otherwise>
                                                                    </xsl:choose>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <th>&#xa0;</th>
                                                                    <th>&#xa0;</th>
                                                                    <th>&#xa0;</th>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <th>&#xa0;</th>
                                                            <th>&#xa0;</th>
                                                            <th>&#xa0;</th>
                                                            <th>&#xa0;</th>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <th>&#xa0;</th>
                                                    <th>&#xa0;</th>
                                                    <th>&#xa0;</th>
                                                    <th>&#xa0;</th>
                                                    <th>&#xa0;</th>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <th>&#xa0;</th>
                                            <th>&#xa0;</th>
                                            <th>&#xa0;</th>
                                            <th>&#xa0;</th>
                                            <th>&#xa0;</th>
                                            <th>&#xa0;</th>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:when>
                                <xsl:otherwise>
                                    <th>&#xa0;</th>
                                    <th>&#xa0;</th>
                                    <th>&#xa0;</th>
                                    <th>&#xa0;</th>
                                    <th>&#xa0;</th>
                                    <th>&#xa0;</th>
                                    <th>&#xa0;</th>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:otherwise>
                            <th>&#xa0;</th>
                            <th>&#xa0;</th>
                            <th>&#xa0;</th>
                            <th>&#xa0;</th>
                            <th>&#xa0;</th>
                            <th>&#xa0;</th>
                            <th>&#xa0;</th>
                            <th>&#xa0;</th>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <xsl:otherwise>
                    <th>&#xa0;</th>
                    <th>&#xa0;</th>
                    <th>&#xa0;</th>
                    <th>&#xa0;</th>
                    <th>&#xa0;</th>
                    <th>&#xa0;</th>
                    <th>&#xa0;</th>
                    <th>&#xa0;</th>
                    <th>&#xa0;</th>
                </xsl:otherwise>
            </xsl:choose>
        </tr>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one cogo point in the <em>First Check Points Include</em> field 
                and at least one cogo point in the <em>Second Check Points Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Surface Check</em> command to get complete results from 
                this report.&#xa0; Ideally, the points in each list will have the same style to which the 
                <em>Tolerances</em> below each list will apply.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2007 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
