<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Name of Feature Table XML file-->
    <xsl:variable name="featureTableList" select="document('SurveyFeature.xml')"/>
    <!-- Alignment Style to Survey Numeric Code -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>*    FILE NAME: </xsl:text><xsl:value-of select="@file"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>*         DATE: </xsl:text><xsl:value-of select="inr:date()"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>* PROJECT NAME: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>*  DESCRIPTION: </xsl:text><xsl:value-of select="@description"/><xsl:text>&#xd;</xsl:text>
                    <xsl:text>*        UNITS: </xsl:text>
                    <xsl:choose>
                        <xsl:when test="//@linearUnits = 'Imperial'">
                            <xsl:text>ENGLISH</xsl:text>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text>METRIC</xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:text>*&#xd;</xsl:text>
                    <xsl:text>*PT NO.   EASTING        NORTHING     ELEVATION   NUMERIC CODE&#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:apply-templates/>
                    </xsl:for-each>
                    <xsl:for-each select="CogoPoints">
                        <xsl:apply-templates/>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Point Data -->
    <xsl:template match="HorizontalLine | HorizontalCircle | HorizontalSpiral">
        <xsl:apply-templates/>
        <xsl:if test="position() = last()">
            <xsl:variable name="parentStyle" select="ancestor::*/@style"/>
            <xsl:variable name="numericCode">
                <xsl:choose>
                    <xsl:when test="End/@style">
                        <xsl:value-of select="$featureTableList/*/SurveyFeature[@style = current()/End/@style]/@numericCode"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$featureTableList/*/SurveyFeature[@style = $parentStyle]/@numericCode"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <xsl:choose>
                <xsl:when test="End/@name">
                    <xsl:value-of select="inr:columnFormat(string(End/@name), 5)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="pntNumber"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), 5, 15)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), 5, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@elevation), 5, 11)"/>
            <xsl:text>&#xa0; &#xa0;</xsl:text><xsl:value-of select="$numericCode"/>
            <xsl:choose>
                <xsl:when test="End/@description">
                    <xsl:text>S</xsl:text><xsl:value-of select="End/@description"/>
                </xsl:when>
                <xsl:otherwise/>
            </xsl:choose>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template match="Start | CogoPoints/GeometryPoint">
        <xsl:variable name="numericCode" select="$featureTableList/*/SurveyFeature[@style = current()/@style]/@numericCode"/>
        <xsl:choose>
            <xsl:when test="@name">
                <xsl:value-of select="inr:columnFormat(string(@name), 5)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="pntNumber"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnDoubleFormat(number(@easting), 5, 15)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@northing), 5, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), 5, 11)"/>
        <xsl:text>&#xa0; &#xa0;</xsl:text><xsl:value-of select="$numericCode"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template name="pntNumber">
        <xsl:variable name="pointNumber">
            <xsl:number count="Start[not(@name)] | End[not(@name)] | CogoPoints/GeometryPoint[not(@name)] | HorizontalEventPoint/GeometryPoint[not(@name)]" level="any"/>
        </xsl:variable>
        <xsl:value-of select="inr:columnFormat(string($pointNumber), 5)"/>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment or&#xd;</xsl:text>
        <xsl:text>    one cogo point in the Include fields on the Tools &gt; XML&#xd;</xsl:text>
        <xsl:text>    Reports &gt; Geometry command to get results from this&#xd;</xsl:text>
        <xsl:text>    report.&#xd;&#xd;</xsl:text>
        <xsl:text>    This style sheet uses a "look-up table" to select a&#xd;</xsl:text>
        <xsl:text>    numeric code from a separate XML file by finding a&#xd;</xsl:text>
        <xsl:text>    style in it that matches the style attribute of the&#xd;</xsl:text>
        <xsl:text>    alignment or point.  An example XML file called&#xd;</xsl:text>
        <xsl:text>    SurveyFeature.xml is included in the Custom directory.&#xd;</xsl:text>
        <xsl:text>    This file can be modified to suit your needs, or you&#xd;</xsl:text>
        <xsl:text>    can create your own file.  The file name is stored in a&#xd;</xsl:text>
        <xsl:text>    variable near the top of the style sheet, and you&#xd;</xsl:text>
        <xsl:text>    should change this value if you create your own file.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
