<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- STATEMENT OF PROPOSED CURVE -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">STATEMENT OF PROPOSED CURVE</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">STATEMENT OF PROPOSED CURVE</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/>
                                    <br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@name"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@description"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@file"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor"/>
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>



                                <!-- Horizontal Alignment Data -->
                                
                                    <xsl:for-each select="HorizontalAlignment[HorizontalCurveSets]">
                                        <table border="1" cellpadding="2" cellspacing="0" width="100%">
                        <thead>
                            <tr>
                                <th colspan="12" lang="en" valign="middle">STATEMENT OF PROPOSED CURVE</th>
                            </tr>
			   <tr style="font-size: 90%">
                                <th lang="en" rowspan="2" valign="bottom">Direction of Curve</th>
                                <th lang="en" rowspan="2" valign="bottom">Deflection Angle<br/></th>
                                <th lang="en" rowspan="2" valign="bottom">Degree of Curve<br/></th>
                                <th lang="en" rowspan="2" valign="bottom">Radius</th>
                                <th lang="en" rowspan="2" valign="bottom">Leading Transition</th>
                                <th lang="en" rowspan="2" valign="bottom">Trailing Transition</th>
                                <th lang="en" rowspan="2" valign="bottom">Leading Shift</th>
                                <th lang="en" rowspan="2" valign="bottom">Trailing Shift</th>
                                <th lang="en" rowspan="2" valign="bottom">Tangent Length</th>
                                <th lang="en" rowspan="2" valign="bottom">Length of Circular Curve</th>
                                
				<th colspan="2">&#xa0; Proposed Chainages</th>
				
 			
			</tr>
			<tr style="font-size: 90%">	
				<th lang="en" valign="bottom">TS</th>
                                <th lang="en" valign="bottom">ST</th>
                         </tr>  
			<xsl:apply-templates/>
                        </thead>
                        
                    </table>
                                    </xsl:for-each>
                              
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
  





  <!-- Horizontal Curve Set Point Data -->
    <xsl:template match="CurvesetPoint[@pointType != 'POB' and @pointType != 'POE' and @pointType != 'PI']">
        <xsl:choose>
            
            <xsl:when test="@pointType = 'SPIRAL CIRCLE SPIRAL'">
                
<TR>




<!-- DIRECTTION OF CURVE -->


                    <td align="left" lang="en">
                        <xsl:if test="../../HorizontalElements/*[@elementNumber = current()/@curveSetStartElement]/@rotationDirection='cw'">Right</xsl:if>
                        <xsl:if test="../../HorizontalElements/*[@elementNumber = current()/@curveSetStartElement]/@rotationDirection = 'ccw'">Left</xsl:if>
                    </td>


<!-- DEFLECTION ANGLE or DELTA -->

                    <td align="right">
                        <xsl:value-of select="inr:angularFormat(number(../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@delta),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                    </td>

<!-- DEGREE OF CURVE -->


                    <td align="right">
                        <xsl:value-of select="inr:angularFormat(number(../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@degreeOfCurve),$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                    </td>


<!-- RADIUS -->

                    <td align="right">
                        <xsl:value-of select="inr:distanceFormat(number(../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@radius), $xslDistancePrecision)"/>
                    </td>

<!-- LEADING TRANSITION -->
                

                    <td align="right">
                        <xsl:value-of select="inr:distanceFormat(number(../../HorizontalElements/HorizontalSpiral[@elementNumber = current()/@curveSetStartElement]/@length), $xslDistancePrecision)"/>
                    </td>



<!-- TRAILING TRANSITION -->
                    <td align="right">
                        <xsl:value-of select="inr:distanceFormat(number(../../HorizontalElements/HorizontalSpiral[@elementNumber = current()/@curveSetStopElement]/@length), $xslDistancePrecision)"/>
                    </td>
<!-- LEADING SHIFT -->

                    <td align="right">
                        <xsl:value-of select="inr:distanceFormat(number(../../HorizontalElements/HorizontalSpiral[@elementNumber = current()/@curveSetStartElement]/@p), $xslDistancePrecision)"/>
                    </td>


<!-- TRAILING SHIFT -->
                    <td align="right">
                        <xsl:value-of select="inr:distanceFormat(number(../../HorizontalElements/HorizontalSpiral[@elementNumber = current()/@curveSetStopElement]/@p), $xslDistancePrecision)"/>
                    </td>

<!-- TANGENT LENGTH -->
                   <td align="right">
                        <xsl:value-of select="inr:distanceFormat(number(../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@tangentLength), $xslDistancePrecision)"/>
                    </td>

<!-- TOTAL LENGTH OF THE CURVE -->

                    <td align="right">
                        <xsl:value-of select="inr:distanceFormat(number(../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@length), $xslDistancePrecision)"/>
                    </td>

<!-- TS -->
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(../../HorizontalElements/HorizontalSpiral[@elementNumber = current()/@curveSetStartElement]/Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
                    </td>
<!-- ST -->
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(../../HorizontalElements/HorizontalSpiral[@elementNumber = current()/@curveSetStopElement]/End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
                    </td>


 </TR>            



         </xsl:when>
	</xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment with at least one curve in the <em>
                Include</em> field on the <em>Tools &gt; XML Reports &gt; Geometry</em> command to get 
                results from this report.
            </p>
            <p class="normal1" lang="en">
                This report is not suitable for XML data produced by versions earlier than V8.8.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>   
</xsl:stylesheet>
