<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Unique cross section surfaces -->
    <xsl:variable name="uniqueSurfaceName" select="//CrossSectionSurfaces/CrossSectionSurface[not (@name = preceding::CrossSectionSurface/@name)]/@name"/>
    <!-- Cross Sections - SDR33 Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/CrossSectionSet">
                    <xsl:text/>
                    <xsl:text>00NMSDR33    V03-0500000</xsl:text>
                    <xsl:value-of select="inr:columnFormat(string($xslAngularMethod), 17)"/>
                    <xsl:if test="//@linearUnits = 'Imperial'">222</xsl:if>
                    <xsl:if test="//@linearUnits = 'Metric'">111</xsl:if>
                    <xsl:text>11&#xd;</xsl:text>
                    <xsl:for-each select="$uniqueSurfaceName[../@type = 1]">
                        <xsl:text>10NMSTAKEOUT        12&#xd;</xsl:text>
                        <xsl:for-each select="//CrossSectionSurface[@name = current()]/CrossSectionPoints/CrossSectionPoint[CrossSectionFeatures/CrossSectionFeature/@name] | CrossSectionPoint[not (CrossSectionFeatures/CrossSectionFeature/@name) and @offset = 0.0]">
                            <xsl:variable name="lineNumber" select="position()"/>
                            <xsl:variable name="fmtNorthing" select="inr:northingFormat(number(@northing), 3)"/>
                            <xsl:variable name="fmtEasting" select="inr:eastingFormat(number(@easting), 3)"/>
                            <xsl:variable name="fmtElevation" select="inr:elevationFormat(number(@elevation), 3)"/>
                            <xsl:text>08KI</xsl:text>
                            <xsl:choose>
                                <xsl:when test="string-length($lineNumber) &gt; 12">
                                    <xsl:value-of select="substring($lineNumber, 1, 12)"/>
                                </xsl:when>
                                <xsl:when test="string-length($lineNumber) &lt; 12">
                                    <xsl:value-of select="$lineNumber"/>
                                    <xsl:value-of select="substring('           ', 1, 12 - string-length($lineNumber))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$lineNumber"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@northing), $xslNorthingPrecision, 16)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@easting), $xslEastingPrecision, 16)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), $xslElevationPrecision, 16)"/>
                            <xsl:text> &#xa0;</xsl:text>
                            <xsl:choose>
                                <xsl:when test="string-length(CrossSectionFeatures/CrossSectionFeature/@name) &gt; 28">
                                    <xsl:value-of select="substring(CrossSectionFeatures/CrossSectionFeature/@name, 1, 28)"/>
                                </xsl:when>
                                <xsl:when test="string-length(CrossSectionFeatures/CrossSectionFeature/@name) &lt; 28">
                                    <xsl:value-of select="CrossSectionFeatures/CrossSectionFeature/@name"/>
                                    <xsl:value-of select="substring('                            ', 1, 28 - string-length(CrossSectionFeatures/CrossSectionFeature/@name))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="CrossSectionFeatures/CrossSectionFeature/@name"/>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must have created cross sections along the&#xd;</xsl:text>
        <xsl:text>    alignment you wish to stake and the cross section set&#xd;</xsl:text>
        <xsl:text>    must have the features upon which you wish to report&#xd;</xsl:text>
        <xsl:text>    displayed.  You can create the XML data file from the&#xd;</xsl:text>
        <xsl:text>    Evaluation &gt; Cross Section &gt; Cross Section Report&#xd;</xsl:text>
        <xsl:text>    command or from the End-Area Volumes leaf of the&#xd;</xsl:text>
        <xsl:text>    Evaluation &gt; Cross Section &gt; Cross Sections&#xd;</xsl:text>
        <xsl:text>    command by toggling on the Create XML Report option&#xd;</xsl:text>
        <xsl:text>    on the General leaf.&#xd;&#xd;</xsl:text>
        <xsl:text>    This report works only with surfaces whose Type on the&#xd;</xsl:text>
        <xsl:text>    Surface &gt; Surface Properties &gt; Main command is set to&#xd;</xsl:text>
        <xsl:text>    Design.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
