<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Variable to hold cubic factor -->
    <xsl:variable name="cubicFactor">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">
                <xsl:choose>
                    <xsl:when test="$xslConvertToCY = 1">27</xsl:when>
                    <xsl:otherwise>1</xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>1</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Variable to store number of lines for first page.  Change this value to meet conditions. -->
    <xsl:variable name="firstPageLines" select="22"/>
    <!-- Variable to store number of lines for subsequent pages.  Change this value to meet conditions. -->
    <xsl:variable name="restPageLines" select="31"/>
    <!-- End Area Volume Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">End Area Volume Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">End Area Volume Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Cross Section Set Data -->
                            <xsl:for-each select="CrossSectionSet">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en" nowrap="nowrap">Cross Section Set Name:&#xa0; </th>
                                            <td align="left" colspan="3"><xsl:value-of select="@setName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" nowrap="nowrap">Alignment Name:&#xa0; </th>
                                            <td align="left" colspan="3"><xsl:value-of select="@alignmentName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%" nowrap="nowrap" valign="top">
                                                Input Grid Factor: &#xa0;
                                            </th>
                                            <td align="left" style="font-size: 80%" valign="top">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <th align="right" lang="en" style="font-size: 80%" nowrap="nowrap" valign="top">
                                                &#xa0; Note: &#xa0;
                                            </th>
                                            <td align="left" lang="en" style="font-size: 80%">
                                                All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">
                                                    <xsl:choose>
                                                        <xsl:when test="$xslConvertToCY = 1">
                                                            feet, square feet and cubic yards
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            feet, square feet and cubic feet
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">
                                                    meters, square meters and cubic meters
                                                </xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Volume Data -->
                                <table width="100%">
                                    <xsl:for-each select="CrossSectionStations">
                                        <tbody>
                                            <xsl:call-template name="firstPage">
                                                <xsl:with-param name="first" select="*/StationVolume"/>
                                            </xsl:call-template>
                                            <xsl:call-template name="grandTotal">
                                                <xsl:with-param name="allVolumes" select="*/StationVolume"/>
                                            </xsl:call-template>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- First Page -->
    <xsl:template name="firstPage">
        <xsl:param name="first"/>
        <xsl:param name="rest" select="$first[position() &gt; $firstPageLines]"/>
        <xsl:call-template name="columnHeadings"/>
        <xsl:for-each select="$first[position() &lt; ($firstPageLines + 1)]">
            <tr>
                <td align="left" nowrap="nowrap">
                    <xsl:value-of select="inr:stationFormat(number(../Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../Station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:distanceFormat(number(CutMaterial/@factor), $xslDistancePrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:areaFormat(number(CutMaterial/@area), $xslAreaPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(CutMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(CutMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:distanceFormat(number(FillMaterial/@factor), $xslDistancePrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:areaFormat(number(FillMaterial/@area), $xslAreaPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(FillMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(FillMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:distanceFormat(number(AddedCutMaterial/@factor), $xslDistancePrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(AddedCutMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(AddedCutMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:distanceFormat(number(AddedFillMaterial/@factor), $xslDistancePrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(AddedFillMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(AddedFillMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(@massOrdinate div $cubicFactor), $xslCubicPrecision)"/>
                </td>
            </tr>
        </xsl:for-each>
        <xsl:variable name="cutVolume" select="sum($first[position() &lt; ($firstPageLines + 1)]/CutMaterial/@volume)"/>
        <xsl:variable name="cutAdjustedVolume" select="sum($first[position() &lt; ($firstPageLines + 1)]/CutMaterial/@adjustedVolume)"/>
        <xsl:variable name="fillVolume" select="sum($first[position() &lt; ($firstPageLines + 1)]/FillMaterial/@volume)"/>
        <xsl:variable name="fillAdjustedVolume" select="sum($first[position() &lt; ($firstPageLines + 1)]/FillMaterial/@adjustedVolume)"/>
        <xsl:variable name="addedCutVolume" select="sum($first[position() &lt; ($firstPageLines + 1)]/AddedCutMaterial/@volume)"/>
        <xsl:variable name="addedCutAdjustedVolume" select="sum($first[position() &lt; ($firstPageLines + 1)]/AddedCutMaterial/@adjustedVolume)"/>
        <xsl:variable name="addedFillVolume" select="sum($first[position() &lt; ($firstPageLines + 1)]/AddedFillMaterial/@volume)"/>
        <xsl:variable name="addedFillAdjustedVolume" select="sum($first[position() &lt; ($firstPageLines + 1)]/AddedFillMaterial/@adjustedVolume)"/>
        <tr><td colspan="16"><hr/></td></tr>
        <tr>
            <td align="center" colspan="3">Page Total:</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($cutVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($cutAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td colspan="2">&#xa0;</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($fillVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($fillAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedCutVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedCutAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedFillVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedFillAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
        </tr>
        <tr><td colspan="16"><hr/></td></tr>
        <xsl:if test="$rest">
            <xsl:call-template name="middlePage">
                <xsl:with-param name="middle" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <!-- Subsequent Pages -->
    <xsl:template name="middlePage">
        <xsl:param name="middle"/>
        <xsl:param name="rest" select="$middle[position() &gt; $restPageLines]"/>
        <xsl:call-template name="columnHeadings"/>
        <xsl:for-each select="$middle[position() &lt; ($restPageLines + 1)]">
            <tr>
                <td align="left" nowrap="nowrap">
                    <xsl:value-of select="inr:stationFormat(number(../Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../Station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:distanceFormat(number(CutMaterial/@factor), $xslDistancePrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:areaFormat(number(CutMaterial/@area), $xslAreaPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(CutMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(CutMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:distanceFormat(number(FillMaterial/@factor), $xslDistancePrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:areaFormat(number(FillMaterial/@area), $xslAreaPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(FillMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(FillMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:distanceFormat(number(AddedCutMaterial/@factor), $xslDistancePrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(AddedCutMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(AddedCutMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:distanceFormat(number(AddedFillMaterial/@factor), $xslDistancePrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(AddedFillMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(AddedFillMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(@massOrdinate div $cubicFactor), $xslCubicPrecision)"/>
                </td>
            </tr>
        </xsl:for-each>
        <xsl:variable name="cutVolume" select="sum($middle[position() &lt; ($restPageLines + 1)]/CutMaterial/@volume)"/>
        <xsl:variable name="cutAdjustedVolume" select="sum($middle[position() &lt; ($restPageLines + 1)]/CutMaterial/@adjustedVolume)"/>
        <xsl:variable name="fillVolume" select="sum($middle[position() &lt; ($restPageLines + 1)]/FillMaterial/@volume)"/>
        <xsl:variable name="fillAdjustedVolume" select="sum($middle[position() &lt; ($restPageLines + 1)]/FillMaterial/@adjustedVolume)"/>
        <xsl:variable name="addedCutVolume" select="sum($middle[position() &lt; ($restPageLines + 1)]/AddedCutMaterial/@volume)"/>
        <xsl:variable name="addedCutAdjustedVolume" select="sum($middle[position() &lt; ($restPageLines + 1)]/AddedCutMaterial/@adjustedVolume)"/>
        <xsl:variable name="addedFillVolume" select="sum($middle[position() &lt; ($restPageLines + 1)]/AddedFillMaterial/@volume)"/>
        <xsl:variable name="addedFillAdjustedVolume" select="sum($middle[position() &lt; ($restPageLines + 1)]/AddedFillMaterial/@adjustedVolume)"/>
        <tr><td colspan="16"><hr/></td></tr>
        <tr>
            <td align="center" colspan="3">Page Total:</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($cutVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($cutAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td colspan="2">&#xa0;</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($fillVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($fillAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedCutVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedCutAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedFillVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedFillAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
        </tr>
        <tr><td colspan="16"><hr/></td></tr>
        <xsl:if test="$rest">
            <xsl:call-template name="middlePage">
                <xsl:with-param name="middle" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="grandTotal">
        <xsl:param name="allVolumes"/>
        <tr>
            <td align="center" colspan="3">Grand Total:</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($allVolumes[position() = last()]/CutMaterial/@cumulativeVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($allVolumes[position() = last()]/CutMaterial/@cumulativeAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td colspan="2">&#xa0;</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($allVolumes[position() = last()]/FillMaterial/@cumulativeVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($allVolumes[position() = last()]/FillMaterial/@cumulativeAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($allVolumes[position() = last()]/AddedCutMaterial/@cumulativeVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($allVolumes[position() = last()]/AddedCutMaterial/@cumulativeAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($allVolumes[position() = last()]/AddedFillMaterial/@cumulativeVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($allVolumes[position() = last()]/AddedFillMaterial/@cumulativeAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
        </tr>
        <tr><td colspan="16"><hr/></td></tr>
    </xsl:template>
    <xsl:template name="columnHeadings">
        <tr>
            <th class="underline" lang="en" rowspan="3" valign="bottom">Baseline<br/>Station</th>
            <th colspan="8" lang="en">- - - - - - - - - - - - - - - - Station Quantities - - - - - - - - - - - - - - - -</th>
            <th colspan="6" lang="en">- - - - - - - - - - - - Added Quantities - - - - - - - - - - - -</th>
            <th class="underline" lang="en" rowspan="3" valign="bottom"><br/>Mass<br/>Ordinate</th>
        </tr>
        <tr>
            <th colspan="4" lang="en">- - - - - - - - - - Cut - - - - - - - - - -</th>
            <th colspan="4" lang="en">- - - - - - - - - - Fill - - - - - - - - - -</th>
            <th colspan="3" lang="en">- - - - - - - - Cut - - - - - - - -</th>
            <th colspan="3" lang="en">- - - - - - - - Fill - - - - - - - -</th>
        </tr>
        <tr>
            <th class="underline" lang="en">Factor</th>
            <th class="underline" lang="en">Area</th>
            <th class="underline" lang="en">Volume</th>
            <th class="underline" lang="en">Adjusted</th>
            <th class="underline" lang="en">Factor</th>
            <th class="underline" lang="en">Area</th>
            <th class="underline" lang="en">Volume</th>
            <th class="underline" lang="en">Adjusted</th>
            <th class="underline" lang="en">Factor</th>
            <th class="underline" lang="en">Volume</th>
            <th class="underline" lang="en">Adjusted</th>
            <th class="underline" lang="en">Factor</th>
            <th class="underline" lang="en">Volume</th>
            <th class="underline" lang="en">Adjusted</th>
        </tr>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have created cross sections along your alignment and the cross section set must 
                have the surfaces and features upon which you wish to report displayed.
            </p>
            <p class="normal1" lang="en">
                You can create the XML data file from the <em>End-Area Volumes</em> leaf of the <em>
                Evaluation &gt; Cross Section &gt; Cross Sections</em> command by toggling on the <em>
                Create XML Report</em> option on the <em>General</em> leaf or from the <em>Evaluation &gt; 
                Cross Section &gt; Cross Section Report</em> command by toggling on the <em>Include Volumes
                </em> option on the <em>Main</em> tab.
            </p>
            <p class="normal1" lang="en">
                This report is not suitable for datasets containing material quantities or MDC.
            </p>
            <p class="normal1" lang="en">
                This report is an example of how to display volume totals on each page based on the number 
                of lines per page.&#xa0; The default is 22 lines for the first page and 31 lines for 
                subsequent pages, intended for landscape printing, but these values are highly dependent on 
                your printer and your page setup in Internet Explorer.&#xa0; You can change the number of 
                lines per page by changing the values in the <code>firstPageLines</code> and 
                <code>restPageLines</code> variables near the top of the style sheet, or you can change 
                your page layout until the pages look right.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
