<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Variable to hold cubic factor -->
    <xsl:variable name="cubicFactor">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">
                <xsl:choose>
                    <xsl:when test="$xslConvertToCY = 1">27</xsl:when>
                    <xsl:otherwise>1</xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>1</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Unique unclassified materials -->
    <xsl:variable name="uniqueUnclassifiedMaterial" select="//UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true'][not (@name = preceding::Material/@name)]/@name"/>
    <!-- Unique rock materials -->
    <xsl:variable name="uniqueRockMaterial" select="//RockMaterials/Material[@includeInMassOrdinate = 'true'][not (@name = preceding::Material/@name)]/@name"/>
    <!-- Unique designed materials -->
    <xsl:variable name="uniqueDesignedMaterial" select="//DesignedMaterials/Material[@includeInMassOrdinate = 'true'][not (@name = preceding::Material/@name)]/@name"/>
    <!-- Unique unsuitable materials -->
    <xsl:variable name="uniqueUnsuitableMaterial" select="//UnsuitableMaterials/Material[@includeInMassOrdinate = 'true'][not (@name = preceding::Material/@name)]/@name"/>
    <!-- Multiple Material Volumes Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Multiple Material Volumes Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Multiple Material Volumes Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Cross Section Set Data -->
                            <xsl:for-each select="CrossSectionSet">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Cross Section Set Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@setName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Alignment Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@alignmentName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">
                                                    <xsl:choose>
                                                        <xsl:when test="$xslConvertToCY = 1">
                                                            feet, square feet and cubic yards
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            feet, square feet and cubic feet
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">
                                                    meters, square meters and cubic meters
                                                </xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Volume Data -->
                                <table width="100%" style="font-size:80%">
                                    <thead style="display:table-header-group">
                                        <tr>
                                            <th class="underline" lang="en" valign="bottom">Station</th>
                                            <th class="underline" lang="en" valign="bottom">Normal<br/>Cut</th>
                                            <th class="underline" lang="en" valign="bottom">Factor</th>
                                            <th class="underline" lang="en" valign="bottom">Adjusted<br/>Normal<br/>Cut</th>
                                            <th class="underline" lang="en" valign="bottom">Adjusted<br/>Added<br/>Cut</th>
                                            <xsl:if test="//MDCMaterials">
                                                <th class="underline" lang="en" valign="bottom">Adjusted<br/>MDC Cut</th>
                                            </xsl:if>
                                            <xsl:for-each select="$uniqueUnclassifiedMaterial">
                                                <th class="underline" lang="en" valign="bottom">
                                                    Adjusted<br/><xsl:value-of select="."/>
                                                </th>
                                            </xsl:for-each>
                                            <xsl:for-each select="$uniqueRockMaterial">
                                                <th class="underline" lang="en" valign="bottom">
                                                    Adjusted<br/><xsl:value-of select="."/>
                                                </th>
                                            </xsl:for-each>
                                            <th class="underline" lang="en" valign="bottom">Total<br/>Adjusted<br/>Station Cut</th>
                                            <th class="underline" lang="en" valign="bottom">Normal<br/>Fill</th>
                                            <th class="underline" lang="en" valign="bottom">Factor</th>
                                            <th class="underline" lang="en" valign="bottom">Adjusted<br/>Normal<br/>Fill</th>
                                            <th class="underline" lang="en" valign="bottom">Adjusted<br/>Added<br/>Fill</th>
                                            <xsl:if test="//MDCMaterials">
                                                <th class="underline" lang="en" valign="bottom">Adjusted<br/>MDC Fill</th>
                                            </xsl:if>
                                            <xsl:for-each select="$uniqueDesignedMaterial">
                                                <th class="underline" lang="en" valign="bottom">
                                                    Adjusted<br/><xsl:value-of select="."/>
                                                </th>
                                            </xsl:for-each>
                                            <xsl:for-each select="$uniqueUnsuitableMaterial">
                                                <th class="underline" lang="en" valign="bottom">
                                                    Adjusted<br/><xsl:value-of select="."/>
                                                </th>
                                            </xsl:for-each>
                                            <th class="underline" lang="en" valign="bottom">Total<br/>Adjusted<br/>Station Fill</th>
                                            <th class="underline" lang="en" valign="bottom">Mass<br/>Ordinate</th>
                                        </tr>
                                    </thead>
                                    <xsl:for-each select="CrossSectionStations">
                                        <tbody>
                                            <xsl:apply-templates/>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template match="CrossSectionStation[StationVolume]">
        <xsl:variable name="currentStation" select="Station/@internalStation"/>
        <tr>
            <td align="right" nowrap="nowrap">
                <xsl:value-of select="inr:stationFormat(number(Station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number(StationVolume/CutMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(StationVolume/CutMaterial/@factor), $xslDistancePrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number(StationVolume/CutMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number(StationVolume/AddedCutMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <xsl:if test="//MDCMaterials">
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(StationVolume/Materials/MDCMaterials/Material/MDC/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
            </xsl:if>
            <xsl:for-each select="$uniqueUnclassifiedMaterial">
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(//Materials/*/Material[@name = current()][../../../../Station/@internalStation = $currentStation]/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
            </xsl:for-each>
            <xsl:for-each select="$uniqueRockMaterial">
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(//Materials/*/Material[@name = current()][../../../../Station/@internalStation = $currentStation]/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
            </xsl:for-each>
            <xsl:choose>
                <xsl:when test="//MDCMaterials">
                    <td align="right">
                        <xsl:value-of select="inr:cubicFormat(number((StationVolume/CutMaterial/@adjustedVolume + StationVolume/AddedCutMaterial/@adjustedVolume + StationVolume/Materials/MDCMaterials/Material/MDC/@adjustedVolume + sum(StationVolume/Materials/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume) + sum(StationVolume/Materials/RockMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor), $xslCubicPrecision)"/>
                    </td>
                </xsl:when>
                <xsl:otherwise>
                    <td align="right">
                        <xsl:value-of select="inr:cubicFormat(number((StationVolume/CutMaterial/@adjustedVolume + StationVolume/AddedCutMaterial/@adjustedVolume + sum(StationVolume/Materials/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume) + sum(StationVolume/Materials/RockMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor), $xslCubicPrecision)"/>
                    </td>
                </xsl:otherwise>
            </xsl:choose>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number(StationVolume/FillMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(StationVolume/FillMaterial/@factor), $xslDistancePrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number(StationVolume/FillMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number(StationVolume/AddedFillMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <xsl:if test="//MDCMaterials">
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(StationVolume/Materials/MDCMaterials/Material/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
            </xsl:if>
            <xsl:for-each select="$uniqueDesignedMaterial">
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(//Materials/*/Material[@name = current()][../../../../Station/@internalStation = $currentStation]/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
            </xsl:for-each>
            <xsl:for-each select="$uniqueUnsuitableMaterial">
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(//Materials/*/Material[@name = current()][../../../../Station/@internalStation = $currentStation]/Replaced/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
            </xsl:for-each>
            <xsl:choose>
                <xsl:when test="//MDCMaterials">
                    <td align="right">
                        <xsl:value-of select="inr:cubicFormat(number((StationVolume/FillMaterial/@adjustedVolume + StationVolume/AddedFillMaterial/@adjustedVolume + StationVolume/Materials/MDCMaterials/Material/@adjustedVolume + sum(StationVolume/Materials/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@adjustedVolume) + sum(StationVolume/Materials/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor), $xslCubicPrecision)"/>
                    </td>
                </xsl:when>
                <xsl:otherwise>
                    <td align="right">
                        <xsl:value-of select="inr:cubicFormat(number((StationVolume/FillMaterial/@adjustedVolume + StationVolume/AddedFillMaterial/@adjustedVolume + sum(StationVolume/Materials/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@adjustedVolume) + sum(StationVolume/Materials/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor), $xslCubicPrecision)"/>
                    </td>
                </xsl:otherwise>
            </xsl:choose>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number(StationVolume/@massOrdinate div $cubicFactor), $xslCubicPrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have created cross sections along your alignment and the cross section set must 
                have the surfaces and features upon which you wish to report displayed.
            </p>
            <p class="normal1" lang="en">
                You can create the XML data file from the <em>End-Area Volumes</em> leaf of the <em>
                Evaluation &gt; Cross Section &gt; Cross Sections</em> command by toggling on the <em>
                Create XML Report</em> option on the <em>General</em> leaf or from the <em>Evaluation &gt; 
                Cross Section &gt; Cross Section Report</em> command by toggling on the <em>Include Volumes
                </em> option on the <em>Main</em> tab.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
