<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Horizontal Events Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Horizontal Events Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Horizontal Events Report</h2>
                                <p lang ="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor: &#xa0;</th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note: &#xa0;</strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <table class="margin" width="90%">
                                    <colgroup span="6">
                                        <col width="15%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                    </colgroup>
                                    <xsl:for-each select="HorizontalAlignment">
                                        <thead style="display:table-header-group">
                                            <tr>
                                                <th align="right" colspan="2" lang="en"><br />Alignment Name: &#xa0;</th>
                                                <td align="left" colspan="3" valign="bottom"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Alignment Description: &#xa0;</th>
                                                <td align="left" colspan="3"><xsl:value-of select="@description"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en" valign="top">Alignment Style: &#xa0;</th>
                                                <td align="left" colspan="3" valign="bottom"><xsl:value-of select="@style"/><br/>&#xa0;</td>
                                            </tr>
                                            <tr>
                                                <th class="underline" lang="en">Type</th>
                                                <th class="underline" lang="en">Station</th>
                                                <th class="underline" lang="en">Northing</th>
                                                <th class="underline" lang="en">Easting</th>
                                                <th class="underline" lang="en">Elevation</th>
                                                <th class="underline" lang="en">Grade</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <xsl:for-each select="HorizontalEventPoints/*/HorizontalEventPoint">
                                                <tr>
                                                    <td class="sidepad">
                                                        <xsl:choose>
                                                            <xsl:when test="@eventType = 'stationEvent'">S+O</xsl:when>
                                                            <xsl:when test="@eventType = 'xyEvent'">N+E</xsl:when>
                                                            <xsl:otherwise/>
                                                        </xsl:choose>
                                                    </td>
                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:stationFormat(number(GeometryPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(GeometryPoint/station/@externalStationName))"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision)"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision)"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:elevationFormat(number(GeometryPoint/@elevation), $xslElevationPrecision)"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:gradeFormat(number(@grade), $xslGradeFormat, $xslGradePrecision)"/>
                                                    </td>
                                                </tr>
                                            </xsl:for-each>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                You must toggle on the <em>Include Horizontal Event Points</em> option to get complete 
                results from this report.
            </p>
            <p class="normal1" lang="en">
                <em>Station Limits</em> only apply to computed data, ie, event points by interval.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
