<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>

    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <title lang="en">Horizontal Regression Points Review Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <h2 lang="en">Horizontal Regression Points Review Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>

                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>

                                <xsl:for-each select="HorizontalAlignment">
                                    <table class="margin" width="90%">

                                        <thead>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Alignment Name:&#xa0; </th>
                                                <td align="left" colspan="4"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Alignment Description:&#xa0; </th>
                                                <td align="left" colspan="4"><xsl:value-of select="@description"/></td>
                                            </tr>
                                        </thead>

                                        <xsl:for-each select="HorizontalEventPoints/HorizontalRegressionPoints">
                                            <tbody>
                                                <tr><td colspan="12">&#xa0;</td></tr>
                                                <tr>
                                                    <th class="underline" lang="en" align="center">Name</th>
                                                    <th class="underline" lang="en" align="right">Northing</th>
                                                    <th class="underline" lang="en" align="right">Easting</th>
                                                    <th class="underline" lang="en" align="right">Elevation</th>
                                                    <th class="underline" lang="en" align="right">Instantaneous Radius</th>
                                                    <th class="underline" lang="en" align="right">Tangential Direction</th>
                                                    <th class="underline" lang="en" align="center">Include in Analysis</th>
                                                    <th class="underline" lang="en" align="center">Fixity</th>
                                                    <th class="underline" lang="en" align="right">Fixed Offset</th>
                                                    <th class="underline" lang="en" align="center">Point Type</th>
                                                    <th class="underline" lang="en" align="right">Station</th>
                                                    <th class="underline" lang="en" align="right">Computed Offset</th>
                                                </tr>
                                                <xsl:for-each select="HorizontalRegressionPoint">
                                                    <tr>
                                                        <td class="sidepad" align="center">
                                                            <xsl:value-of select="HorizontalEventPoint/GeometryPoint/@name"/>
                                                        </td>
                                                        <td class="sidepad" align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(HorizontalEventPoint/GeometryPoint/@northing), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td class="sidepad" align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(HorizontalEventPoint/GeometryPoint/@easting), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td class="sidepad" align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(HorizontalEventPoint/GeometryPoint/@elevation), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td class="sidepad" align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td class="sidepad" align="right">
                                                            <xsl:value-of select="inr:directionFormat(number(@tangential), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                                                        </td>
                                                        <td class="sidepad" align="center">
                                                            <xsl:value-of select="@statusIncludeExclude"/>
                                                        </td>
                                                        <td class="sidepad" align="center">
                                                            <xsl:value-of select="@statusFixFree"/>
                                                        </td>
                                                        <td class="sidepad" align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@fixedOffset), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td class="sidepad" align="right">
                                                            <xsl:value-of select="HorizontalEventPoint/GeometryPoint/@type"/>
                                                        </td>
                                                        <td class="sidepad" align="right">
                                                            <xsl:value-of select="inr:stationFormat(number(HorizontalEventPoint/GeometryPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(centerLinePoint/point/station/@externalStationName))"/>
                                                        </td>
                                                        <td class="sidepad" align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(HorizontalEventPoint/GeometryPoint/@offset), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                </xsl:for-each>
                                            </tbody>
                                        </xsl:for-each>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                This report requires horizontal regression points for a complete report and you must toggle 
                on the <em>Include Horizontal Event Points</em> option.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2012 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
