<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Variables to hold unit strings -->
    <xsl:variable name="linearUnit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">ft</xsl:when>
            <xsl:otherwise>m</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="areaUnit1">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">sq ft</xsl:when>
            <xsl:otherwise>sq m</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="areaUnit2">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">ac</xsl:when>
            <xsl:otherwise>hec</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Traverse with Curve Data ASCII -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <xsl:text/>
                    <!-- Report Title -->
                    <xsl:text>                        Traverse with Curve Data Report&#xd;&#xd;</xsl:text>
                    <xsl:value-of select="inr:date()"/>
                    <xsl:text>&#xd;</xsl:text>
                    <!-- Project Data -->
                    <xsl:for-each select="GeometryProject">
                        <xsl:text>   Project: </xsl:text>
                        <xsl:value-of select="@name"/>
                        <!-- Horizontal Alignment Data -->
                        <xsl:for-each select="HorizontalAlignment">
                            <xsl:text>&#xd; Alignment: </xsl:text>
                            <xsl:value-of select="@name"/>
                            <xsl:text>&#xd;&#xd;</xsl:text>
                            <xsl:text>OCCUPIED    BEARING        DISTANCE     NORTHING      EASTING      ELEVATION&#xd;</xsl:text>
                            <xsl:text>--------    -------        --------   ------------  ------------  ------------&#xd;&#xd;</xsl:text>
                            <xsl:apply-templates/>
                            <xsl:if test="@area &gt; 0">
                                <xsl:text>&#xd;AREA   (</xsl:text><xsl:value-of select="$areaUnit1"/><xsl:text>) = </xsl:text><xsl:value-of select="inr:columnDoubleFormat(number(@area), $xslAreaPrecision, 12)"/>
                                <xsl:choose>
                                    <xsl:when test="//@linearUnits = 'Imperial'">
                                        <xsl:text>&#xd;AREA      (</xsl:text><xsl:value-of select="$areaUnit2"/><xsl:text>) = </xsl:text><xsl:value-of select="inr:columnDoubleFormat(number(@area div 43560), $xslAreaPrecision, 12)"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>&#xd;AREA    (</xsl:text><xsl:value-of select="$areaUnit2"/><xsl:text>) = </xsl:text><xsl:value-of select="inr:columnDoubleFormat(number(@area div 10000), $xslAreaPrecision, 12)"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:text>&#xd;PERIMETER (</xsl:text><xsl:value-of select="$linearUnit"/><xsl:text>) = </xsl:text><xsl:value-of select="inr:columnDoubleFormat(number(@perimeter), $xslDistancePrecision, 12)"/>
                            </xsl:if>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine">
        <xsl:choose>
            <xsl:when test="Start/@name">
                <xsl:value-of select="inr:columnFormat(string(Start/@name), 7)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnFormat(string(Start/@type), 26)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 17)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 14)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@elevation), $xslElevationPrecision, 14)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 22)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 13)"/>
        <xsl:text>&#xd;&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:choose>
                <xsl:when test="End/@name">
                    <xsl:value-of select="inr:columnFormat(string(End/@name), 7)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="inr:columnFormat(string(End/@type), 26)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 17)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 14)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@elevation), $xslElevationPrecision, 14)"/>
            <xsl:text>&#xd;&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:choose>
            <xsl:when test="Start/@name">
                <xsl:value-of select="inr:columnFormat(string(Start/@name), 7)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnFormat(string(Start/@type), 26)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 17)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 14)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@elevation), $xslElevationPrecision, 14)"/>
        <xsl:text>&#xd;         Delta:</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(inr:angularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)), 16)"/>
        <xsl:text>&#xd;        Radius:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@radius), $xslDistancePrecision, 14)"/>
        <xsl:text>&#xd;           Arc:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 14)"/>
        <xsl:text>&#xd;         Chord:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@chord), $xslDistancePrecision, 14)"/>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 16)"/>
        <xsl:text>&#xd;       Tangent:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@tangentLength), $xslDistancePrecision, 14)"/>
        <xsl:text>&#xd;&#xd;</xsl:text>
        <xsl:choose>
            <xsl:when test="Center/@name">
                <xsl:value-of select="inr:columnFormat(string(Center/@name), 7)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:text>  Radius Point:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(Center/@northing), $xslNorthingPrecision, 28)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Center/@easting), $xslEastingPrecision, 14)"/>
        <xsl:text>&#xd;&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:choose>
                <xsl:when test="End/@name">
                    <xsl:value-of select="inr:columnFormat(string(End/@name), 7)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="inr:columnFormat(string(End/@type), 26)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 17)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 14)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@elevation), $xslElevationPrecision, 14)"/>
            <xsl:text>&#xd;&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <xsl:choose>
            <xsl:when test="Start/@name">
                <xsl:value-of select="inr:columnFormat(string(Start/@name), 7)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnFormat(string(Start/@type), 26)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 17)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 14)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@elevation), $xslElevationPrecision, 14)"/>
        <xsl:text>&#xd;  Start Radius:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@startRadius), $xslDistancePrecision, 14)"/>
        <xsl:text>&#xd;    End Radius:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@endRadius), $xslDistancePrecision, 14)"/>
        <xsl:text>&#xd;       Tangent:</xsl:text>
        <xsl:choose>
            <xsl:when test="@compound = 'false'">
                <xsl:choose>
                    <xsl:when test="@startRadius &gt; @endRadius">
                        <xsl:value-of select="inr:columnDoubleFormat(number(@shortTangent), $xslDistancePrecision, 14)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:columnDoubleFormat(number(@longTangent), $xslDistancePrecision, 14)"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="@startRadius &gt; @endRadius">
                        <xsl:value-of select="inr:columnDoubleFormat(number(@longTangent), $xslDistancePrecision, 14)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:columnDoubleFormat(number(@shortTangent), $xslDistancePrecision, 14)"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:choose>
                <xsl:when test="End/@name">
                    <xsl:value-of select="inr:columnFormat(string(End/@name), 7)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="inr:columnFormat(string(End/@type), 26)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 17)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 14)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@elevation), $xslElevationPrecision, 14)"/>
            <xsl:text>&#xd;&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2007 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
