<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Figure Name and Description Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:value-of select="@name"/>
                        <xsl:for-each select="HorizontalElements">
                            <xsl:apply-templates/>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine">
        <xsl:if test="position() = 1">
            <xsl:text> ( </xsl:text>
        </xsl:if>
        <xsl:value-of select="Start/@name"/>
        <xsl:choose>
            <xsl:when test="position() mod 10 = 0">
                <xsl:text>&#xd; </xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text> </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="position() = last()">
            <xsl:value-of select="End/@name"/>
            <xsl:text> ) </xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:if test="position() = 1">
            <xsl:text> ( </xsl:text>
        </xsl:if>
        <xsl:value-of select="Start/@name"/>
        <xsl:text> C</xsl:text>
        <xsl:value-of select="Center/@name"/>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">L</xsl:when>
            <xsl:otherwise>R</xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="position() mod 10 = 0">
                <xsl:text>&#xd; </xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text> </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="position() = last()">
            <xsl:value-of select="End/@name"/>
            <xsl:text> ) </xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <xsl:if test="position() = 1">
            <xsl:text> ( </xsl:text>
        </xsl:if>
        <xsl:value-of select="Start/@name"/>
        <xsl:text> S</xsl:text>
        <xsl:value-of select="PI/@name"/>
        <xsl:choose>
            <xsl:when test="position() mod 10 = 0">
                <xsl:text>&#xd; </xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text> </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="position() = last()">
            <xsl:value-of select="End/@name"/>
            <xsl:text> ) </xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    Your horizontal alignment must have points with names&#xd;</xsl:text>
        <xsl:text>    to get valid results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    Cogo point names and alignment point names must follow&#xd;</xsl:text>
        <xsl:text>    the strict ICS naming conventions for this report to be&#xd;</xsl:text>
        <xsl:text>    usable as an ICS input file.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
