<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl" />
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Distance Keepers Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Distance Keepers Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Distance Keepers Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr />
                                <table class="margin" cellpadding="2" cellspacing="1" width="75%">
                                    <tbody>
                                        <xsl:for-each select="HorizontalAlignment">
                                            <tr>
                                                <th align="left" lang="en">Horizontal:</th>
                                                <td colspan="2"><xsl:value-of select="@name" /></td>
                                            </tr>
                                            <tr>
                                                <th align="right" class="underline" lang="en" valign="bottom"><br />Station</th>
                                                <th align="right" class="underline" lang="en" valign="bottom">Left Back</th>
                                                <th align="right" class="underline" lang="en" valign="bottom">Left Ahead</th>
                                                <th align="right" class="underline" lang="en" valign="bottom">Right Back</th>
                                                <th align="right" class="underline" lang="en" valign="bottom">Right Ahead</th>
                                            </tr>
                                            <xsl:variable name="currentLeftBackJoint" select="DistanceKeepers/DistanceKeeper/@leftBackJoint" />
                                            <xsl:for-each select="DistanceKeepers/DistanceKeeper[$currentLeftBackJoint]">
                                                <xsl:if test="number(@leftBackKeeperToKeeper) = 0.0">
                                                    <tr>
                                                        <td>&#xa0;</td>
                                                        <td align="right"><xsl:value-of select="@leftBackJoint" /></td>
                                                        <td>&#xa0;</td>
                                                        <td align="right"><xsl:value-of select="@rightBackJoint" /></td>
                                                        <td>&#xa0;</td>
                                                    </tr>
                                                </xsl:if>
                                                <tr>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:stationFormat(number(station/@externalStation), $xslStationFormat,$xslStationPrecision, string(station/@externalStationName))" />
                                                    </td>
                                                    <td align="right">
                                                        <xsl:if test="number(@leftBackKeeperToKeeper) = 0.0">
                                                            <xsl:value-of select="inr:distanceFormat(number(@leftBackJointToKeeper) - (number(@leftBackJointLength) div 2), $xslDistancePrecision)" />
                                                        </xsl:if>
                                                        <xsl:if test="number(@leftBackKeeperToKeeper) != 0.0">
                                                            <xsl:value-of select="inr:distanceFormat(number(@leftBackKeeperToKeeper), $xslDistancePrecision)" />
                                                        </xsl:if>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:if test="number(@leftAheadKeeperToKeeper) = 0.0">
                                                            <xsl:value-of select="inr:distanceFormat(number(@leftAheadJointToKeeper) - (number(@leftAheadJointLength) div 2), $xslDistancePrecision)" />
                                                        </xsl:if>
                                                        <xsl:if test="number(@leftAheadKeeperToKeeper) != 0.0">
                                                            <xsl:value-of select="inr:distanceFormat(number(@leftAheadKeeperToKeeper), $xslDistancePrecision)" />
                                                        </xsl:if>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:if test="number(@rightBackKeeperToKeeper) = 0.0">
                                                            <xsl:value-of select="inr:distanceFormat(number(@rightBackJointToKeeper) - (number(@rightBackJointLength) div 2), $xslDistancePrecision)" />
                                                        </xsl:if>
                                                        <xsl:if test="number(@rightBackKeeperToKeeper) != 0.0">
                                                            <xsl:value-of select="inr:distanceFormat(number(@rightBackKeeperToKeeper), $xslDistancePrecision)" />
                                                        </xsl:if>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:if test="number(@rightAheadKeeperToKeeper) = 0.0">
                                                            <xsl:value-of select="inr:distanceFormat(number(@rightAheadJointToKeeper) - (number(@rightAheadJointLength) div 2), $xslDistancePrecision)" />
                                                        </xsl:if>
                                                        <xsl:if test="number(@rightAheadKeeperToKeeper) != 0.0">
                                                            <xsl:value-of select="inr:distanceFormat(number(@rightAheadKeeperToKeeper), $xslDistancePrecision)" />
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <xsl:if test="number(@leftAheadKeeperToKeeper) = 0.0">
                                                    <tr>
                                                        <td>&#xa0;</td>
                                                        <td align="right"><xsl:value-of select="@leftAheadJoint" /></td>
                                                        <td>&#xa0;</td>
                                                        <td align="right"><xsl:value-of select="@rightAheadJoint" /></td>
                                                        <td>&#xa0;</td>
                                                    </tr>
                                                    <tr>
                                                        <td colspan="5">&#xa0;</td>
                                                    </tr>
                                                </xsl:if>
                                            </xsl:for-each>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must select a horizontal alignment that has rails in the <em>Horizontal Alignment</em> 
                field on the <em>General</em> tab of the <em>Geometry &gt; Light Rail Manufacturing &gt; 
                Reports</em> command.&#xa0; You must also toggle on the <em>Include Distance Keepers</em> 
                option.
            </p>
            <p class="normal1" lang="en">
                Your rails must have keypoints, joints, switches, crossings and distance keepers defined to 
                get results from this report.
            </p>
            <h4 lang="en">Tips</h4>
            <p class="normal1" lang="en">
                To access the <em>Light Rail Manufacturing</em> commands, select the <em>Tools &gt; 
                Application Add-Ins</em> command and toggle on the <em>Light Rail Manufacturing 
                Add-In</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
