<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl" />
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Rail Elevations Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Rail Elevations Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Rail Elevations Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()" /><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()" />
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Left & Right Rail Elevations -->
                                <table class="margin" cellpadding="2" cellspacing="1" width="90%">
                                    <thead style="display:table-header-group">
                                        <tr>
                                            <th class="underline" lang="en" valign="bottom">Station</th>
                                            <th class="underline" lang="en" valign="bottom">Point Type</th>
                                            <th class="underline" lang="en" valign="bottom">Rail</th>
                                            <th class="underline" lang="en" valign="bottom">Offset</th>
                                            <th class="underline" lang="en" valign="bottom">Northing</th>
                                            <th class="underline" lang="en" valign="bottom">Easting</th>
                                            <th class="underline" lang="en" valign="bottom">Elevation</th>
                                            <th class="underline" lang="en" valign="bottom">
                                                Cant<br/>
                                                <xsl:if test="//@linearUnits = 'Imperial'">(in)</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">(mm)</xsl:if>
                                            </th>
                                        </tr>
                                        <tr><td colspan="8">&#xa0;</td></tr>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="HorizontalAlignment[IncrementalRailPoints]">
                                            <tr>
                                                <td colspan="8">
                                                    <strong>Horizontal Alignment:&#xa0; </strong><xsl:value-of select="@name"/>
                                                </td>
                                            </tr>
                                            <tr><td colspan="8">&#xa0;</td></tr>
                                            <xsl:for-each select="IncrementalRailPoints/IncrementalRailPoint/IncrementalPoints">
                                                <xsl:for-each select="IncrementalPoint">
                                                    <tr>
                                                        <xsl:choose>
                                                            <xsl:when test="position() = 1">
                                                                <td align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:stationFormat(number(../../CenterPoint/station/@externalStation), $xslStationFormat,$xslStationPrecision, string(CenterPoint/station/@externalStationName))"/>
                                                                </td>
                                                                <td align="center"><xsl:value-of select="../../CenterPoint/@type"/></td>
                                                            </xsl:when>
                                                            <xsl:otherwise>
                                                                <td colspan="2">&#xa0;</td>
                                                            </xsl:otherwise>
                                                        </xsl:choose>
                                                        <td class="sidepad">
                                                            <xsl:value-of select="../../../RailNames/RailName[@parentIndex = current()/@parentIndex]/@name"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@offset), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:if test="//@linearUnits = 'Imperial'">
                                                                <xsl:value-of select="inr:distanceFormat(number(@cant * 12), 1)"/>
                                                            </xsl:if>
                                                            <xsl:if test="//@linearUnits = 'Metric'">
                                                                <xsl:value-of select="inr:distanceFormat(number(@cant * 1000), 0)"/>
                                                            </xsl:if>
                                                        </td>
                                                    </tr>
                                                </xsl:for-each>
                                                <tr><td colspan="8">&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must select a horizontal alignment that has rails in the <em>Horizontal Alignment</em> 
                field on the <em>General</em> tab of the <em>Geometry &gt; Light Rail Manufacturing &gt; 
                Reports</em> command.&#xa0; You must also toggle on the <em>Incremental Stations</em> 
                option and define an <em>Interval</em>.
            </p>
            <p class="normal1" lang="en">
                Your rails must have keypoints, joints, switches and crossings defined to get results from 
                this report.
            </p>
            <h4 lang="en">Tips</h4>
            <p class="normal1" lang="en">
                To access the <em>Light Rail Manufacturing</em> commands, select the <em>Tools &gt; 
                Application Add-Ins</em> command and toggle on the <em>Light Rail Manufacturing 
                Add-In</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
