<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- HALGN GENIO Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <xsl:for-each select="GeometryProject">
                        <xsl:text/>
                        <xsl:text>MOSS&#xd;</xsl:text>
                        <xsl:text>EDIT,DESIGN&#xd;</xsl:text>
                        <xsl:for-each select="HorizontalAlignment">
                            <xsl:variable name="nameString" select="@name"/>
                            <xsl:text>004,3=</xsl:text><xsl:value-of select="$nameString"/><xsl:text>&#xd;</xsl:text>
                            <xsl:text>004,3=GC</xsl:text><xsl:value-of select="substring-after($nameString, 'MC')"/><xsl:text>&#xd;</xsl:text>
                            <xsl:text>999&#xd;</xsl:text>
                            <xsl:text>HALGN,DESIGN,DESIGN&#xd;</xsl:text>
                            <xsl:variable name="FstStn" select=".//HorizontalComputedEventPoints/HorizontalEventPoint/GeometryPoint/station[position()=1]/@internalStation"/>
                            <xsl:variable name="NxtStn" select=".//HorizontalComputedEventPoints/HorizontalEventPoint[position() = 2]/GeometryPoint/station/@internalStation"/>
                            <xsl:variable name="StnInterval" select="number($NxtStn - $FstStn)"/>
                            <xsl:text>300,LB=</xsl:text>
                            <xsl:value-of select="$nameString"/>
                            <xsl:text>,SC=</xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(.//Start/station/@externalStation), $xslDistancePrecision)"/>
                            <xsl:text>,CF=</xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(.//End/station/@externalStation), $xslDistancePrecision)"/>
                            <xsl:text>,CE=</xsl:text>
                            <xsl:if test="boolean($StnInterval)=true()"><xsl:value-of select="$StnInterval"/></xsl:if>
                            <xsl:if test="boolean($StnInterval)=false()">0</xsl:if>
                            <xsl:text>,TL=</xsl:text>
                            <xsl:if test="//@linearUnits = 'Imperial'">0.500&#xd;</xsl:if>
                            <xsl:if test="//@linearUnits = 'Metric'">0.100&#xd;</xsl:if>
                            <xsl:apply-templates/>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Linear Data -->
    <xsl:template match="HorizontalLine">
        <xsl:text>301,</xsl:text>
        <xsl:number count="HorizontalLine | HorizontalCircle"/>
        <xsl:text>,SX,X1=</xsl:text>
        <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
        <xsl:text>,Y1=</xsl:text>
        <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
        <xsl:text>,X2=</xsl:text>
        <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
        <xsl:text>,Y2=</xsl:text>
        <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">999&#xd;</xsl:if>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:text>301,</xsl:text>
        <xsl:number count="HorizontalLine | HorizontalCircle"/>
        <xsl:if test="@rotationDirection='cw'"><xsl:text>,RE,</xsl:text></xsl:if>
        <xsl:if test="@rotationDirection = 'ccw'"><xsl:text>,LE,</xsl:text></xsl:if>
        <xsl:text>RA=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">999&#xd;</xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>

