<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <title lang="en">Station Base Cross Slope</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <h2 lang="en">Station Base Cross Slope Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>

                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@name"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@description"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@file"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right">Horizontal Baseline Alignment:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="HorizontalAlignment/@name"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right">Vertical Alignment:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="HorizontalAlignment/VerticalAlignment/@name"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr />

                                <table class="margin" cellpadding="2" cellspacing="1" width="90%">
                                    <thead>
                                        <tr>
                                            <th class="underline" align="right" lang="en">Station</th>
                                            <th class="underline" align="right" lang="en">Ground Elevation</th>
                                            <th class="underline" align="right" lang="en">Design Elevation</th>
                                            <th class="underline" align="right" lang="en">Northing</th>
                                            <th class="underline" align="right" lang="en">Easting</th>
                                            <th class="underline" align="right" lang="en">Gradient</th>
                                            <th class="underline" align="right" lang="en">Cross Slope</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="//StationOffsetPoint">
                                            <xsl:if test="not(@offsetAlignmentName = preceding-sibling::*/@offsetAlignmentName)">
                                                <tr>
                                                    <td colspan="4" lang="en">
                                                        <strong>
                                                            <br/>Offset Alignment: &#xa0;
                                                        </strong>
                                                        <xsl:value-of select="@offsetAlignmentName"/>
                                                        <br/>
                                                    </td>
                                                </tr>
                                            </xsl:if>
                                            <tr>
                                                <td class="sidepad" align="right" nowrap="nowrap">
                                                    <xsl:value-of select="inr:stationFormat(number(centerLinePoint/point/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(centerLinePoint/point/station/@externalStationName))"/>
                                                </td>
                                                <td class="sidepad" align="right">
                                                    <xsl:value-of select="inr:elevationFormat(number(centerLinePoint/@existingElevation), $xslElevationPrecision)"/>
                                                </td>
                                                <td class="sidepad" align="right">
                                                    <xsl:value-of select="inr:elevationFormat(number(centerLinePoint/point/@elevation), $xslElevationPrecision)"/>
                                                </td>
                                                <td class="sidepad" align="right">
                                                    <xsl:value-of select="inr:northingFormat(number(centerLinePoint/point/@northing), $xslNorthingPrecision)"/>
                                                </td>
                                                <td class="sidepad" align="right">
                                                    <xsl:value-of select="inr:eastingFormat(number(centerLinePoint/point/@easting), $xslEastingPrecision)"/>
                                                </td>
                                                <td class="sidepad" align="right">
                                                    <xsl:value-of select="inr:gradeFormat(number(centerLinePoint/@instantaneousGrade), $xslGradeFormat, $xslGradePrecision)"/>
                                                </td>
                                                <td class="sidepad" align="right">
                                                    <xsl:value-of select="inr:gradeFormat(number(centerLinePoint/@crossSlope), $xslGradeFormat, $xslGradePrecision)"/>
                                                </td>
                                            </tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You should use Civil Tools and Station Base Report.  Select a baseline and two additional geometric entities.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2013 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
