<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Variables to hold range point names.  You must change these to match your data. -->
    <xsl:variable name="leftRangePointName">Edge_Driving_Top_L</xsl:variable>
    <xsl:variable name="rightRangePointName">Edge_Driving_Top_R</xsl:variable>
    <!-- Superelevation ASCII Import Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/RoadwayDesignProject/SuperStations">
                    <xsl:text/>
                    <xsl:text>Station|Finished Grade Left|Finished Grade Right&#xd;</xsl:text>
                    <xsl:for-each select="SuperStation/SuperControlValues">
                        <xsl:for-each select="SuperControlValue">
                            <xsl:if test="position() = 1">
                                <xsl:value-of select="inr:stationFormat(number(../../@externalStation), $xslStationFormat, $xslStationPrecision, string(../../@externalStationName))"/>
                                <xsl:text>|</xsl:text>
                            </xsl:if>
                            <xsl:if test="@name = $leftRangePointName">
                                <xsl:value-of select="@crossSlope"/>
                                <xsl:text>|</xsl:text>
                            </xsl:if>
                            <xsl:if test="@name = $rightRangePointName">
                                <xsl:value-of select="@crossSlope"/>
                            </xsl:if>
                        </xsl:for-each>
                        <xsl:text>&#xd;</xsl:text>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must have defined superelevation for the horizontal&#xd;</xsl:text>
        <xsl:text>    alignment and corridor upon which you wish to report by&#xd;</xsl:text>
        <xsl:text>    selecting the Modeler &gt; Roadway Designer &gt; Super-&#xd;</xsl:text>
        <xsl:text>    elevation &gt; Create Superelevation Wizard command.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must choose either All Processed Stations or&#xd;</xsl:text>
        <xsl:text>    Specified Interval and toggle on the Include Super-&#xd;</xsl:text>
        <xsl:text>    elevation Event Points option in the Report At group on&#xd;</xsl:text>
        <xsl:text>    the Modeler &gt; Roadway Designer &gt; Superelevation &gt;&#xd;</xsl:text>
        <xsl:text>    Superelevation Report command.  If you wish to report&#xd;</xsl:text>
        <xsl:text>    on only the critical points, enter an Interval greater&#xd;</xsl:text>
        <xsl:text>    than the length of your alignment.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must select only the two superelevated points&#xd;</xsl:text>
        <xsl:text>    representing the left and right range points in the&#xd;</xsl:text>
        <xsl:text>    Available Superelevated Points list and you must modify&#xd;</xsl:text>
        <xsl:text>    the two variables at the top of this style sheet to&#xd;</xsl:text>
        <xsl:text>    specify the names of the two selected points to get&#xd;</xsl:text>
        <xsl:text>    results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2007 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
