<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Feature Styles Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Feature Styles Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="CivilIni">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Feature Styles Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <hr/>
                            <xsl:for-each select="FeatureStyleCollection">
                                <table cellpadding="1" cellspacing="1" style="font-size:80%">
                                    <thead style="display:table-header-group">
                                        <tr>
                                            <th class="underline" lang="en" valign="bottom">Name</th>
                                            <th class="underline" lang="en" valign="bottom">Description</th>
                                            <th class="underline" lang="en" valign="bottom">Alpha Code</th>
                                            <th class="underline" lang="en" valign="bottom">Numeric Code</th>
                                            <th class="underline" lang="en" valign="bottom">Pay Item</th>
                                            <th class="underline" lang="en" valign="bottom">Surface Named Symbology</th>
                                            <th class="underline" lang="en" valign="bottom">Geometry Point Named Symbology</th>
                                            <th class="underline" lang="en" valign="bottom">Geometry Line Named Symbology</th>
                                            <th class="underline" lang="en" valign="bottom">Geometry Arc Named Symbology</th>
                                            <th class="underline" lang="en" valign="bottom">Geometry Spiral Named Symbology</th>
                                            <th class="underline" lang="en" valign="bottom">Survey Named Symbology</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="FeatureStyle">
                                            <xsl:sort select="@ItemName"/>
                                            <tr>
                                                <td valign="top" style="white-space:nowrap;"><xsl:value-of select="@ItemName"/></td>
                                                <td valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="@Description">
                                                            <xsl:value-of select="@Description"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="SurveyFeature/AlphaCode/@Code">
                                                            <xsl:for-each select="SurveyFeature/AlphaCode">
                                                                <xsl:value-of select="@Code"/><br/>
                                                            </xsl:for-each>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;<br/></xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="SurveyFeature/@NumericCode">
                                                            <xsl:value-of select="SurveyFeature/@NumericCode"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="SurfaceFeature/@PayItemName">
                                                            <xsl:value-of select="SurfaceFeature/@PayItemName"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="SurfaceFeature/NamedSymbologyName/@Name">
                                                            <xsl:value-of select="SurfaceFeature/NamedSymbologyName/@Name"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="GeometryPointFeature/NamedSymbologyName/@Name">
                                                            <xsl:value-of select="GeometryPointFeature/NamedSymbologyName/@Name"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="GeometryLineFeature/NamedSymbologyName/@Name">
                                                            <xsl:value-of select="GeometryLineFeature/NamedSymbologyName/@Name"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="GeometryArcFeature/NamedSymbologyName/@Name">
                                                            <xsl:value-of select="GeometryArcFeature/NamedSymbologyName/@Name"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="GeometrySpiralFeature/NamedSymbologyName/@Name">
                                                            <xsl:value-of select="GeometrySpiralFeature/NamedSymbologyName/@Name"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="SurveyFeature/NamedSymbologyName/@Name">
                                                            <xsl:value-of select="SurveyFeature/NamedSymbologyName/@Name"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                            </tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                To use this report, you must open a Preferences file by selecting <em>File &gt; Open</em> 
                on the <em>Report Browser</em> menu and setting the <em>Files of type</em> field to 
                <em>Preferences (*.xin)</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2009 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
